@@ -2,7 +2,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
-extern int h_errno;		/* For netdb.h */
 #include <time.h>
 #include <sys/time.h>
 #include <signal.h>
@@ -37,6 +36,8 @@ static int YIFF_CONNECT_TO(const char *address, int port);
 static void YIFF_COPY_EVENTS(YEvent *tar, YEvent *src);
 static void YIFF_FREE_CON(YConnection *con);
 
+void YShutdownSocket(int socket, int how, time_t timeout);
+void YCloseSocketWait(int socket, time_t timeout);
 
 YConnection *YOpenConnection(
 	const char *start_arg,
@@ -51,7 +52,7 @@ int YSetAudioModeValues(
 	int direction,
 	int allow_fragmenting,
 	int num_fragments,
-	int fragment_size	/* In bytes. */
+	int fragment_size	/* In bytes */
 );
 int YChangeAudioModePreset(YConnection *con, const char *name);
 YAudioModeValuesStruct **YGetAudioModes(YConnection *con, int *count);
@@ -148,7 +149,7 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block);
 void YPutBackEvent(YConnection *con, YEvent *event);
 
 
-/* Checks if c is a white space. */
+/* Checks if c is a white space */
 #ifndef ISBLANK
 # define ISBLANK(c)	(((c) == ' ') || ((c) == '\t'))
 #endif
@@ -187,48 +188,46 @@ extern void YSetEventToBeDisconnect(YEvent *event);
 
 
 /*
- *	Returns socket fd or -1 on error.
+ *	Connects to the specified address and port.
+ *
+ *	Returns the socket or -1 on error.
  */
 static int YIFF_CONNECT_TO(const char *address, int port)
 {
 	int s;
-	struct hostent *host;		/* Host pointer. */
+	struct hostent *host;		/* Host pointer */
 	struct sockaddr_in haddr;
 
-
 	if(address == NULL)
-	    return(-1);
+	    return(-2);
 
-
-	/* Get host address data. */
+	/* Get host address data */
 	host = gethostbyname(address);
 	if(host == NULL)
 	    return(-1);
 
-	/* Get a socket. */
+	/* Create a new socket */
 	s = socket(AF_INET, SOCK_STREAM, 0);
 	if(s < 0)
 	    return(-1);
 
-	haddr.sin_family = AF_INET;		/* In hbo. */   
-	haddr.sin_port = htons(port);		/* In nbo. */
+	haddr.sin_family = AF_INET;		/* In hbo */   
+	haddr.sin_port = htons(port);		/* In nbo */
 	haddr.sin_addr = *((struct in_addr *)host->h_addr);
-	memset(&haddr.sin_zero, 0, 8);	/* Zero the rest of struct. */
+	memset(&haddr.sin_zero, 0x00, 8);	/* Zero the rest of struct */
 
-	/* Connect. */
-	if(
-	    connect(
-		s,
-		(struct sockaddr *)&haddr,
-		sizeof(struct sockaddr)
-	    ) == -1
-	)
+	/* Connect */
+	if(connect(
+	    s,
+	    (struct sockaddr *)&haddr,
+	    sizeof(struct sockaddr)
+	) == -1)
 	    return(-1);
 
-	/* Set socket to non-blocking. */
-/*
+#if 0
+	/* Set socket to non-blocking */
 	fcntl(s, F_SETFL, O_NONBLOCK);
- */
+#endif
 
 	return(s);
 }
@@ -263,6 +262,38 @@ static void YIFF_FREE_CON(YConnection *con)
 	free(con);
 }
 
+
+/*
+ *	Shuts down the socket.
+ */
+void YShutdownSocket(int socket, int how, time_t timeout)
+{
+	if(socket < 0)
+	    return;
+
+	shutdown(socket, how);
+}
+
+/*
+ *	Calls recv() until it returns 0 and then closes the socket.
+ */
+void YCloseSocketWait(int socket, time_t timeout)
+{
+	char buf[1024];
+
+	if(socket < 0)
+	    return;
+
+	while(recv(
+	    socket,
+	    buf, sizeof(buf),
+	    MSG_NOSIGNAL
+	) > 0);
+
+	close(socket);
+}
+
+
 /*
  *	Attempts to connect to the Y server at the address and port
  *	specified by con_arg.
@@ -296,7 +327,7 @@ YConnection *YOpenConnection(const char *start_arg, const char *con_arg)
 	/* Is the connection argument string NULL? */
 	if(con_arg == NULL)
 	{
-	    /* Look for the "RECORDER" enviroment variable. */
+	    /* Look for the "RECORDER" enviroment variable */
 	    strptr = getenv("RECORDER");
 	    if(strptr == NULL)
 	    {
@@ -311,26 +342,26 @@ YConnection *YOpenConnection(const char *start_arg, const char *con_arg)
 	    }
 	}
 
-	/* Parse address from connect string. */
+	/* Parse address from connect string */
 	strncpy(addr, con_arg, 1024);
 	addr[1024 - 1] = '\0';
 
 	strptr = strchr(addr, ':');
 	if(strptr != NULL)
 	{
-	    /* Null terminate address string. */
+	    /* Null terminate address string */
 	    (*strptr) = '\0';
 
-	    /* Increment strptr to get port number. */
+	    /* Increment strptr to get port number */
 	    strptr++;
 	    while(ISBLANK(*strptr))
 		strptr++;
-	    /* Get port number. */
+	    /* Get port number */
 	    port = atoi(strptr);
 	}
 	else
 	{
-	    /* Set default port number. */
+	    /* Set default port number */
 	    port = DEF_PORT;
 	}
 
@@ -339,7 +370,7 @@ YConnection *YOpenConnection(const char *start_arg, const char *con_arg)
 	 */
 
 
-	/* Attempt to connect to Y server (initial try). */
+	/* Attempt to connect to Y server (initial try) */
 	fd = YIFF_CONNECT_TO(addr, port);
 	if(fd < 0)
 	{
@@ -356,7 +387,7 @@ YConnection *YOpenConnection(const char *start_arg, const char *con_arg)
 	    }
 	    else
 	    {
-		/* Run the Y server. */
+		/* Run the Y server */
 		Exec(start_arg);
 	    }
 
@@ -376,7 +407,7 @@ YConnection *YOpenConnection(const char *start_arg, const char *con_arg)
 		    break;
 		}
 
-		/* Pause for one second in between tries. */
+		/* Pause for one second in between tries */
 		sleep(1);
 	    }
 
@@ -398,24 +429,25 @@ YConnection *YOpenConnection(const char *start_arg, const char *con_arg)
 	 */
 
 
-	/* Allocate a new YConnection structure. */
+	/* Allocate a new YConnection structure */
 	con = (YConnection *)calloc(1, sizeof(YConnection));
 	if(con == NULL)
 	{
-	    close(fd);
+	    YShutdownSocket(fd, SHUT_RDWR, 30l);
+	    YCloseSocketWait(fd, 30l);
 	    return(NULL);
 	}
 
-	/* Set up connection values. */
+	/* Set up connection values */
 	con->fd = fd;
 	con->we_started_server = yiff_we_started_server;
 	con->prev_generated_yid = YIDNULL;
 
-	/* Reset queued events array. */
+	/* Reset queued events array */
 	con->total_queued_events = 0;
 	con->queued_event = NULL;
 
-	/* Allocate recieve buffer. */
+	/* Allocate recieve buffer */
 	con->buf_len = YNetRecvBufLen;
 	con->buf_cont = 0;
 	con->buf = (u_int8_t *)calloc(
@@ -441,13 +473,13 @@ YConnection *YOpenConnection(const char *start_arg, const char *con_arg)
  */
 int YSetAudioModeValues(
 	YConnection *con,
-	int sample_size,	/* 8 or 16. */
-	int channels,		/* 1 or 2. */
-	int sample_rate,	/* In hz. */
-	int direction,		/* 0 for play, 1 for record. */
+	int sample_size,	/* 8 or 16 */
+	int channels,		/* 1 or 2 */
+	int sample_rate,	/* In hz */
+	int direction,		/* 0 for play, 1 for record */
 	int allow_fragmenting,
 	int num_fragments,
-	int fragment_size	/* In bytes. */
+	int fragment_size	/* In bytes */
 )
 {
 	int i;
@@ -459,7 +491,7 @@ int YSetAudioModeValues(
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send mode change values. */
+	/* Send mode change values */
 	if(YNetSendAudioChangeValues(
 	    con,
 	    sample_size,
@@ -472,7 +504,7 @@ int YSetAudioModeValues(
 	) <= 0)
 	    return(-1);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -492,7 +524,7 @@ int YSetAudioModeValues(
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -519,11 +551,11 @@ int YChangeAudioModePreset(YConnection *con, const char *name)
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send change audio mode. */
+	/* Send change audio mode */
 	if(YNetSendAudioChangePreset(con, name) <= 0)
 	    return(-1);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -545,7 +577,7 @@ int YChangeAudioModePreset(YConnection *con, const char *name)
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }  
@@ -578,11 +610,11 @@ YAudioModeValuesStruct **YGetAudioModes(YConnection *con, int *count)
 	if(con->fd < 0)   
 	    return(NULL);
 
-	/* Send get audio modes listing. */
+	/* Send get audio modes listing */
 	if(YNetSendListAudioModes(con) <= 0)
 	    return(NULL);
 
-	/* Wait for response to get listing. */
+	/* Wait for response to get listing */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -652,7 +684,7 @@ YAudioModeValuesStruct **YGetAudioModes(YConnection *con, int *count)
 		    return(ptr);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -754,11 +786,11 @@ int YGetServerStats(YConnection *con, YEventServerStats *buf)
 	    return(-1);
 
 
-	/* Send request for server stats. */
+	/* Send request for server stats */
 	if(YNetSendGetServerStats(con) <= 0)
 	    return(-1);
 
-	/* Wait for server stats event to come in. */
+	/* Wait for server stats event to come in */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -779,7 +811,7 @@ int YGetServerStats(YConnection *con, YEventServerStats *buf)
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -838,11 +870,11 @@ int YSetCycle(YConnection *con, long us)
 	if(us < 1)
 	    us = 1;
 
-	/* Send set cycle. */
+	/* Send set cycle */
 	if(YNetSendCycleChange(con, us) <= 0)
 	    return(-1);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -858,7 +890,7 @@ int YSetCycle(YConnection *con, long us)
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -893,7 +925,7 @@ void YSyncAll(YConnection *con, Boolean block)
 	if(!block)
 	    return;
 
-	/* Wait for server sync response. */
+	/* Wait for server sync response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -909,7 +941,7 @@ void YSyncAll(YConnection *con, Boolean block)
 		    return;
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -935,11 +967,11 @@ int YGetAudioStats(YConnection *con, YEventAudioStats *buf)
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send request for audio stats. */
+	/* Send request for audio stats */
 	if(YNetSendGetAudioStats(con) <= 0)
 	    return(-1);
 
-	/* Wait for audio stats event to come in. */
+	/* Wait for audio stats event to come in */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -960,7 +992,7 @@ int YGetAudioStats(YConnection *con, YEventAudioStats *buf)
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -989,11 +1021,11 @@ int YAddHost(YConnection *con, YIPUnion *ip)
 	    return(-1);
 
 
-	/* Send add host. */
+	/* Send add host */
 	if(YNetSendSetHost(con, YSetHostAdd, ip) <= 0)
 	    return(-1);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1009,7 +1041,7 @@ int YAddHost(YConnection *con, YIPUnion *ip)
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -1039,11 +1071,11 @@ int YRemoveHost(YConnection *con, YIPUnion *ip)
 	    return(-1);
 
 
-	/* Send remove host. */
+	/* Send remove host */
 	if(YNetSendSetHost(con, YSetHostRemove, ip) <= 0)
 	    return(-1);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1059,7 +1091,7 @@ int YRemoveHost(YConnection *con, YIPUnion *ip)
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -1083,7 +1115,7 @@ int YSetMixerChannel(
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Sanitize values. */
+	/* Sanitize values */
 	if(mixer_channel_code < 0)
 	    return(-1);
 
@@ -1097,7 +1129,7 @@ int YSetMixerChannel(
 	if(value2 > 1) 
 	    value2 = 1;
 
-	/* Send set mixer device. */
+	/* Send set mixer device */
 	if(YNetSendSetMixerChannel(
 	    con,
 	    mixer_channel_code,
@@ -1105,7 +1137,7 @@ int YSetMixerChannel(
 	) <= 0)
 	    return(-1);
 
-	/* Do not catch response, calling function may want to have it. */
+	/* Do not catch response, calling function may want to have it */
 
 	return(0);
 }
@@ -1126,7 +1158,7 @@ int YSetMixerChannelQuad(
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Sanitize values. */
+	/* Sanitize values */
 	if(mixer_channel_code < 0)
 	    return(-1);
 
@@ -1150,7 +1182,7 @@ int YSetMixerChannelQuad(
 	if(value4 > 1)
 	    value4 = 1;
 
-	/* Send set mixer device. */
+	/* Send set mixer device */
 	if(YNetSendSetMixerChannel(
 	    con,
 	    mixer_channel_code,
@@ -1158,7 +1190,7 @@ int YSetMixerChannelQuad(
 	) <= 0)
 	    return(-1);
 
-	/* Do not catch response, calling function may want to have it. */
+	/* Do not catch response, calling function may want to have it */
 
 	return(0);
 }
@@ -1182,12 +1214,12 @@ int YGetMixerChannel(
 	    return(-1);
 
 
-	/* Send request for mixer device values. */
+	/* Send request for mixer device values */
 	if(YNetSendGetMixerChannel(con, mixer_channel_code) <= 0)
 	    return(-1);
 
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1211,7 +1243,7 @@ int YGetMixerChannel(
 		    return(-1);
  		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -1241,12 +1273,12 @@ int YGetMixerChannelQuad(
 	    return(-1);
 
 
-	/* Send request for mixer device values. */
+	/* Send request for mixer device values */
 	if(YNetSendGetMixerChannel(con, mixer_channel_code) <= 0)
 	    return(-1);
 
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1274,7 +1306,7 @@ int YGetMixerChannelQuad(
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -1300,10 +1332,10 @@ YID YStartPlaySoundObjectSimple(YConnection *con, const char *path)
 			YPlayValuesFlagVolume |
 			YPlayValuesFlagSampleRate;
 
-	value.yid = YIDNULL;		/* Ignored by server. */
-	value.position = 0;		/* Ignored by server. */
-	value.length = 0;		/* Ignored by server. */
-	value.repeats = 0;		/* Ignored by server. */
+	value.yid = YIDNULL;		/* Ignored by server */
+	value.position = 0;		/* Ignored by server */
+	value.length = 0;		/* Ignored by server */
+	value.repeats = 0;		/* Ignored by server */
 	value.total_repeats = 1;
 	value.left_volume = 1.0;
 	value.right_volume = 1.0;
@@ -1322,7 +1354,7 @@ YID YStartPlaySoundObjectSimple(YConnection *con, const char *path)
  */
 YID YStartPlaySoundObject(
 	YConnection *con,
-	const char *path,	/* Path on disk on server's computer. */
+	const char *path,	/* Path on disk on server's computer */
 	YEventSoundPlay *value
 )
 {
@@ -1351,10 +1383,10 @@ YID YStartPlaySoundObject(
 			YPlayValuesFlagVolume |
 			YPlayValuesFlagSampleRate;
 
-	v2.yid = YIDNULL;	/* Ignored by server. */
-	v2.position = 0;	/* Ignored by server. */
-	v2.length = 0;	/* Ignored by server. */
-	v2.repeats = 0;	/* Ignored by server. */
+	v2.yid = YIDNULL;	/* Ignored by server */
+	v2.position = 0;	/* Ignored by server */
+	v2.length = 0;	/* Ignored by server */
+	v2.repeats = 0;	/* Ignored by server */
 	v2.total_repeats = 1;
 	v2.left_volume = 1.0;
 	v2.right_volume = 1.0;
@@ -1384,7 +1416,7 @@ YID YStartPlaySoundObject(
 	    v2.back_left_volume = CLIP(value->back_left_volume, 0.0, 1.0);
 	    v2.back_right_volume = CLIP(value->back_right_volume, 0.0, 1.0);
 	}
-	/* Set volume structure. */
+	/* Set volume structure */
 	volume.left = (Coefficient)v2.left_volume *
 	    (Coefficient)((u_int16_t)-1);
 	volume.right = (Coefficient)v2.right_volume *
@@ -1400,11 +1432,11 @@ YID YStartPlaySoundObject(
 	}
 
 
-	/* Increment yid dispense number and get new yid. */
+	/* Increment yid dispense number and get new yid */
 	con->prev_generated_yid++;
 	yid = con->prev_generated_yid;
 
-	/* Send request to start playing. */
+	/* Send request to start playing */
 	if(YNetSendSoundPlay(
 	    con, yid, path,
 	    v2.position,
@@ -1414,7 +1446,7 @@ YID YStartPlaySoundObject(
 	) <= 0)
 	    return(YIDNULL);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1430,7 +1462,7 @@ YID YStartPlaySoundObject(
 		    }
 		    else
 		    {
-			/* Put back event so client can receive it. */
+			/* Put back event so client can receive it */
 			YPutBackEvent(con, &event);
 		    }
 		    break;
@@ -1442,13 +1474,13 @@ YID YStartPlaySoundObject(
 		    return(YIDNULL);
  		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
 	}
 
-	/* Return with the yid of the play object. */
+	/* Return with the yid of the play object */
 	return(yid);
 }
 
@@ -1477,11 +1509,11 @@ int YGetSoundObjectAttributes(
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send request for sound object attributes. */
+	/* Send request for sound object attributes */
 	if(YNetSendGetSoundObjectAttributes(con, path) <= 0)
 	    return(-1);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1491,7 +1523,7 @@ int YGetSoundObjectAttributes(
 		    const char *ev_path_ptr = event.sndobjattributes.path;
 		    if(*ev_path_ptr == '\0')
 		    {
-			/* Empth path implies failed. */
+			/* Empth path implies failed */
 			return(-1);
 		    }
 		    /* Returned path stored in the event needs to
@@ -1522,7 +1554,7 @@ int YGetSoundObjectAttributes(
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -1548,7 +1580,7 @@ void YSetPlaySoundObjectValues(
 	value->flags |= YPlayValuesFlagYID;
 	value->yid = yid;
 
-	/* Send set play sound object values. */
+	/* Send set play sound object values */
 	if(YNetSendSetSoundObjectPlayValues(con, value) <= 0)
 	    return;
 
@@ -1576,11 +1608,11 @@ int YGetPlaySoundObjectValues(
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send request for sound object values. */
+	/* Send request for sound object values */
 	if(YNetSendGetSoundObjectPlayValues(con, yid) <= 0)
 	    return(-1);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1602,7 +1634,7 @@ int YGetPlaySoundObjectValues(
 		    return(-1);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -1641,14 +1673,14 @@ void YDestroyPlaySoundObject(YConnection *con, YID yid)
  */
 int YSendClientMessage(
 	YConnection *con,
-	Boolean notify_self,    /* Send ourself this YClientMessage event too. */
-	int format,             /* One of YClientMessageFormat*. */
+	Boolean notify_self,    /* Send ourself this YClientMessage event too */
+	int format,             /* One of YClientMessageFormat* */
 	int type,               /* One of YClientMessageType*, note that
 				 * clients can also define their own types.
 				 * so unexpected values may appear.
 				 */
-	const char *message,    /* Message. */
-	int length              /* Length of message in bytes. */
+	const char *message,    /* Message */
+	int length              /* Length of message in bytes */
 )
 {
 	if(con == NULL)
@@ -1657,7 +1689,7 @@ int YSendClientMessage(
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send client message. */
+	/* Send client message */
 	if(YNetSendClientMessage(
 	    con, notify_self, format, type, message, length
 	) <= 0)
@@ -1694,11 +1726,11 @@ void *YSHMOpenSound(YConnection *con, int *length, int *id)
 	if(con->fd < 0)
 	    return(NULL);
 
-	/* Send request for sound object attributes. */
+	/* Send request for sound object attributes */
 	if(YNetSendYSHMSoundOpen(con) <= 0)
 	    return(NULL);
 
-	/* Wait for response. */
+	/* Wait for response */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1733,7 +1765,7 @@ void *YSHMOpenSound(YConnection *con, int *length, int *id)
 		    return(NULL);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -1769,7 +1801,7 @@ int YPlayAudioCDTrack(YConnection *con, int track_number)
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send play audio CD track. */
+	/* Send play audio CD track */
 	if(YNetSendAudioCDPlayTrack(con, track_number) <= 0)
 	    return(-1);
 
@@ -1792,7 +1824,7 @@ int YStopAudioCD(YConnection *con)
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send stop audio CD. */
+	/* Send stop audio CD */
 	if(YNetSendAudioCDStop(con) <= 0)
 	    return(-1);
 
@@ -1815,7 +1847,7 @@ int YEjectAudioCD(YConnection *con)
 	if(con->fd < 0)
 	    return(-1);
 
-	/* Send eject audio CD. */
+	/* Send eject audio CD */
 	if(YNetSendAudioCDEject(con) <= 0)
 	    return(-1);
 
@@ -1851,11 +1883,11 @@ YAudioCDTrackStruct **YGetAudioCDTracks(
 	if(con->fd < 0)   
 	    return(NULL);
 
-	/* Send get audio CD tracks listing. */
+	/* Send get audio CD tracks listing */
 	if(YNetSendListAudioCDTracks(con) <= 0)
 	    return(NULL);
 
-	/* Wait for response to get listing. */
+	/* Wait for response to get listing */
 	for(i = 0; i < DEF_EVENT_FETCH_RETRIES; i++)
 	{
 	    if(YGetNextEvent(con, &event, True) > 0)
@@ -1867,7 +1899,7 @@ YAudioCDTrackStruct **YGetAudioCDTracks(
 		    YEventAudioCDStats *acd_stats = &event.audiocdstats;
 		    if(acd_stats->track_number <= 0)
 		    {
-			/* End of listing. */
+			/* End of listing */
 			break;
 		    }
 		    else
@@ -1917,7 +1949,7 @@ YAudioCDTrackStruct **YGetAudioCDTracks(
 		    return(ptr);
 		}
 
-		/* Put back event and discount this loop. */
+		/* Put back event and discount this loop */
 		YPutBackEvent(con, &event);
 		i--;
 	    }
@@ -1955,7 +1987,7 @@ void YCloseConnection(YConnection *con, Boolean no_shutdown)
 	if(con == NULL)
 	    return;
 
-	/* If we started the server, then we should shut it down. */
+	/* If we started the server, then we should shut it down */
 	if(con->we_started_server &&
 	   !no_shutdown
 	)
@@ -1964,7 +1996,7 @@ void YCloseConnection(YConnection *con, Boolean no_shutdown)
 	    {
 		YNetSendShutdown(con, 0);
 
-	        /* Wait for shutdown event (for 30 seconds). */
+	        /* Wait for shutdown event (for 30 seconds) */
 	        for(i = 0; i < 60; i++)
 	        {
 		    if(YGetNextEvent(con, &event, False) > 0)
@@ -1978,18 +2010,16 @@ void YCloseConnection(YConnection *con, Boolean no_shutdown)
 			}
 		    }
 
-		    /* Resend shutdown command. */
+		    /* Resend shutdown command */
 		    YNetSendShutdown(con, 0);
 
 		    usleep(500000);
 		}
 
-		/* Close connection as needed. */
-		if(con->fd > -1)
-		{
-		    close(con->fd);
-		    con->fd = -1;
-		}
+		/* Close the connection */
+		YShutdownSocket(con->fd, SHUT_WR, 30l);
+		YCloseSocketWait(con->fd, 30l);
+		con->fd = -1;
 	    }
 	}
 	else
@@ -1998,16 +2028,14 @@ void YCloseConnection(YConnection *con, Boolean no_shutdown)
 	    {
 		YNetSendDisconnect(con, 0);
 
-		/* Close connection. */
-		if(con->fd > -1)
-		{
-		    close(con->fd);
-		    con->fd = -1;
-		}
+		/* Close the connection */
+		YShutdownSocket(con->fd, SHUT_WR, 30l);
+		YCloseSocketWait(con->fd, 30l);
+		con->fd = -1;
 	    }
 	}
 
-	/* Free connection structure and its resources. */
+	/* Delete the connection */
 	YIFF_FREE_CON(con);
 	con = NULL;
 }
@@ -2025,7 +2053,6 @@ void YShutdownServer(YConnection *con)
 	int i;
 	YEvent event;
 
-
 	if(con == NULL)
 	    return;
 
@@ -2034,7 +2061,7 @@ void YShutdownServer(YConnection *con)
 	{
 	    YNetSendShutdown(con, 0);
 
-	    /* Wait for YShutdown or YDisconnect event (for 30 seconds). */
+	    /* Wait for YShutdown or YDisconnect event (for 30 seconds) */
 	    for(i = 0; i < 60; i++)
 	    {
 		if(YGetNextEvent(con, &event, False) > 0)
@@ -2048,21 +2075,19 @@ void YShutdownServer(YConnection *con)
 		    }
 		}
 
-	        /* Resend shutdown command. */
+	        /* Resend shutdown command */
 		YNetSendShutdown(con, 0);
 
-		usleep(500000);	/* Wait half a second. */
+		usleep(500000);	/* Wait half a second */
 	    }
 
-	    /* Close connection as needed. */
-	    if(con->fd > -1)
-	    {
-		close(con->fd);
-		con->fd = -1;
-	    }
+	    /* Close the connection */
+	    YShutdownSocket(con->fd, SHUT_WR, 30l);
+	    YCloseSocketWait(con->fd, 30l);
+	    con->fd = -1;
 	}
 
-	/* Free connection structure and its resources as needed. */
+	/* Delete the connection */
 	YIFF_FREE_CON(con);
 	con = NULL;
 }
@@ -2092,13 +2117,13 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block)
 	if(con->fd < 0)
 	{
 	    /* Connection descriptor is -1 so return event as a
-	     * YDisconnect event.
+	     * YDisconnect event
 	     */
 	    YSetEventToBeDisconnect(event);
 	    return(1);
 	}
 
-	/* Sanitize total queued events. */
+	/* Sanitize total queued events */
 	if(con->total_queued_events < 0)
 	    con->total_queued_events = 0;
 
@@ -2114,9 +2139,7 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block)
 	    /* Non-error (got 0 or more events) and connection still
 	     * valid?
 	     */
-	    if((status < 0) ||
-	       (con->fd < 0)
-	    )
+	    if((status < 0) || (con->fd < 0))
 	    {
 		/* Either a serious recieve error occured or the
 		 * connection has been disconnected by YNetRecv().
@@ -2124,11 +2147,11 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block)
 		 * The socket should now be -1, force close if it is
 		 * not.
 		 */
-		if(con->fd > -1)
-		{
-		    close(con->fd);
-		    con->fd = -1;
-		}
+
+		/* Close the connection */
+		YShutdownSocket(con->fd, SHUT_RDWR, 30l);
+		YCloseSocketWait(con->fd, 30l);
+		con->fd = -1;
 
 		/* We need to make sure the event returned is either
 		 * a YDisconnect or YShutdown.
@@ -2137,9 +2160,9 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block)
 		/* Are there any queued events to be reported? */
 		if(con->total_queued_events > 0)
 		{
-		    /* Yes we got atleast one. */
+		    /* Yes we got atleast one */
 
-		    /* Copy OLDEST queued event to event structure. */
+		    /* Copy OLDEST queued event to event structure */
 		    YIFF_COPY_EVENTS(event, &(con->queued_event[0]));
 
 		    /* Don't shift events in queue, instead dealloate
@@ -2157,7 +2180,7 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block)
 		}
 		else
 		{
-		    /* No events queued, so report a YDisconnect. */
+		    /* No events queued, so report a YDisconnect */
 		    YSetEventToBeDisconnect(event);
 		}
 
@@ -2167,13 +2190,13 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block)
 	    /* Got atleast one complete event? */
 	    if(con->total_queued_events > 0)
 	    {
-		/* Yes we got atleast one. */
+		/* Yes we got atleast one */
 
-	        /* Copy OLDEST queued event to event structure. */
+	        /* Copy OLDEST queued event to event structure */
 	        YIFF_COPY_EVENTS(event, &(con->queued_event[0]));
 
 
-	        /* Decrement number of and shift queued events. */
+	        /* Decrement number of and shift queued events */
 	        con->total_queued_events--;
 
 		tar_event_ptr = &(con->queued_event[0]);
@@ -2191,7 +2214,7 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block)
 		        src_event_ptr
 		    );
 
-		/* Reallocate queued event pointers. */
+		/* Reallocate queued event pointers */
 		if(con->total_queued_events > 0)
 		{
 		    con->queued_event = (YEvent *)realloc(
@@ -2210,7 +2233,7 @@ int YGetNextEvent(YConnection *con, YEvent *event, Boolean block)
 		    con->total_queued_events = 0;
 		}
 
-		/* Report that we got event. */
+		/* Report that we got event */
 	        return(1);
 	    }
 	    else
@@ -2250,15 +2273,15 @@ void YPutBackEvent(
 	    return;
 
 
-	/* Sanitize total queued events. */
+	/* Sanitize total queued events */
 	if(con->total_queued_events < 0)
 	    con->total_queued_events = 0;
 
-	/* Increment total. */
+	/* Increment total */
 	n = con->total_queued_events;
 	con->total_queued_events++;
 
-	/* Check if exceeded maximum allowed queued events. */
+	/* Check if exceeded maximum allowed queued events */
 	if(con->total_queued_events > YQueuedEventsMax)
 	{
 	    fprintf(stderr,
@@ -2271,7 +2294,7 @@ void YPutBackEvent(
 	    return;
 	}
 
-	/* Allocate a new queued event. */
+	/* Allocate a new queued event */
 	con->queued_event = (YEvent *)realloc(
 	    con->queued_event,
 	    con->total_queued_events * sizeof(YEvent)
@@ -2283,6 +2306,6 @@ void YPutBackEvent(
 	}
 
 
-	/* Copy input event values to new queued event position. */
+	/* Copy input event values to new queued event position */
 	YIFF_COPY_EVENTS(&con->queued_event[n], event);
 }
