@@ -7,7 +7,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
-extern int h_errno;             /* For netdb.h */
 #include <time.h>
 #include <sys/time.h>
 #include <unistd.h>
@@ -31,6 +30,11 @@ extern int h_errno;             /* For netdb.h */
 #include "../include/Y2/Ylib.h"
 #include "../include/Y2/Yclientnet.h"
 
+
+extern void YShutdownSocket(int socket, int how, time_t timeout);
+extern void YCloseSocketWait(int socket, time_t timeout);
+
+
 static u_int64_t htonl64(u_int64_t x);
 
 static void YNetPrintError(
@@ -229,10 +233,10 @@ void YSetEventToBeDisconnect(YEvent *event)
 	if(event == NULL)
 	    return;
 
-	/* Explicitly change event type to YDisconnect. */
+	/* Explicitly change event type to YDisconnect */
 	event->type = YDisconnect;
 
-	/* Set disconnect reason code. */
+	/* Set disconnect reason code */
 	event->disconnect.reason = 0;
 }
 
@@ -298,7 +302,7 @@ int YNetSendAudioChangePreset(
 	    audio_mode_name,
 	    name_len
 	);
-	/* Do not null terminate string. */
+	/* Do not null terminate string */
 
 	/* Since this is a variable length segment we need to
 	 * recalculate the segment length after the formatting
@@ -354,7 +358,7 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 {
 	if(minor_op_code == YAudioChangeValues)
 	{
-	    /* Parse Audio mode values. */
+	    /* Parse Audio mode values */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u16_samplesize> <u16_channels> <u32_samplerate>
@@ -383,7 +387,7 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YAudioChangePreset)
 	{
-	    /* Parse change preset Audio mode. */
+	    /* Parse change preset Audio mode */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <...audiomodename...>
@@ -413,7 +417,7 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 		audio->mode_name[0] = '\0';
 	    }
 
-	    /* Clear rest of event members. */
+	    /* Clear rest of event members */
 	    audio->preset = True;
 
 	    audio->sample_size = 0;
@@ -645,7 +649,7 @@ int YNetParseMixerChannel(YCNP_STD_INPUTS_PROTO)
 
 	    mixer->code = ntohs(*(u_int16_t *)(&buf[8]));
 
-	    /* Get mixer values, check availibility with defination. */
+	    /* Get mixer values, check availibility with defination */
 	    if(YMixerValues > 0)
 		mixer->value[0] =
 		    (Coefficient)ntohl(*(u_int32_t *)(&buf[10])) /
@@ -716,7 +720,7 @@ int YNetSendSoundPlay(
 	    path,
 	    path_len
 	);
-	/* Do not null terminate string. */
+	/* Do not null terminate string */
 
 	/* Since this is a variable length segment we need to
 	 * recalculate the segment length after the formatting
@@ -732,7 +736,7 @@ int YNetSendSoundPlay(
  */
 int YNetParseSoundPlay(YCNP_STD_INPUTS_PROTO)
 {
-	if(True)	/* No minor op codes. */
+	if(True)	/* No minor op codes */
 	{
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_flags> <u32_yid>
@@ -841,7 +845,7 @@ int YNetSendGetSoundObjectAttributes(
 	    path,
 	    path_len
 	);
-	/* Do not null terminate string. */
+	/* Do not null terminate string */
 
 	/* Since this is a variable length segment we need to
 	 * recalculate the segment length after the formatting
@@ -953,7 +957,7 @@ int YNetSendSync(YConnection *con, long cycle_ahead_us)
 	const YDataLength this_seg_len = 8 + 4;
 	char buf[this_seg_len];
 
-	/* Sanitize cycle_ahead_us. */
+	/* Sanitize cycle_ahead_us */
 	if(cycle_ahead_us < 0)
 	    cycle_ahead_us = 0;
 
@@ -1091,7 +1095,7 @@ int YNetParseServerStats(YCNP_STD_INPUTS_PROTO)
 {
 	if(minor_op_code == YServerStatsGet)
 	{
-	    /* Parse server stats get. */
+	    /* Parse server stats get */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -1102,7 +1106,7 @@ int YNetParseServerStats(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YServerStatsSet)
 	{
-	    /* Parse server stats set. */      
+	    /* Parse server stats set */      
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_protocolvermaj> <u32_protocolvermin>
@@ -1127,13 +1131,13 @@ int YNetParseServerStats(YCNP_STD_INPUTS_PROTO)
 
 	    sstat->start_time = (u_int64_t)htonl64(*(u_int64_t *)(&buf[18]));
 
-	    /* Begin parsing strings. */
+	    /* Begin parsing strings */
 	    if(chunk_length > base_seg_len)
 	    {
 		const char	*s = (const char *)&buf[base_seg_len],
 				*s_end = (const char *)&buf[chunk_length];
 
-		/* Vendor name. */
+		/* Vendor name */
 		char c, *ts = sstat->vendor_name;
 		int i = 0, tlen = YVendorNameMax;
 		while((s < s_end) && (i < tlen))
@@ -1148,7 +1152,7 @@ int YNetParseServerStats(YCNP_STD_INPUTS_PROTO)
 		else
 		    ts[tlen - 1] = '\0';
 
-		/* Server name. */
+		/* Server name */
 		ts = sstat->server_name;
 		i = 0; tlen = YServerNameMax;
 		s++;
@@ -1164,7 +1168,7 @@ int YNetParseServerStats(YCNP_STD_INPUTS_PROTO)
 		else
 		    ts[tlen - 1] = '\0';
 
-		/* Sound name. */
+		/* Sound name */
 		ts = sstat->sound_name;
 		i = 0; tlen = YSoundNameMax;
 		s++;
@@ -1181,7 +1185,7 @@ int YNetParseServerStats(YCNP_STD_INPUTS_PROTO)
 		    ts[tlen - 1] = '\0';
 	    }
 
-	    /* More items to be added in future. */
+	    /* More items to be added in future */
 
 	}
 
@@ -1212,7 +1216,7 @@ int YNetParseListAudioModes(YCNP_STD_INPUTS_PROTO)
 {
 	if(minor_op_code == YListAudioModesGet)
 	{
-	    /* Parse list audio modes get. */
+	    /* Parse list audio modes get */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -1223,7 +1227,7 @@ int YNetParseListAudioModes(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YListAudioModesSet)
 	{
-	    /* Parse list audio modes set. */
+	    /* Parse list audio modes set */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_samplerate> <u32_channels>
@@ -1352,7 +1356,7 @@ int YNetParseSoundObjectPlayValues(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YSoundObjectPlayValuesSet)
 	{
-	    /* Parse sound object play values set. */
+	    /* Parse sound object play values set */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_flags> <u32_yid>
@@ -1600,7 +1604,7 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YAudioCDPlayTrack)
 	{
-	    /* Parse audio CD play track. */
+	    /* Parse audio CD play track */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_track_number>
@@ -1618,7 +1622,7 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YAudioCDStop)
 	{
-	    /* Parse audio CD stop. */
+	    /* Parse audio CD stop */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -1635,7 +1639,7 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YAudioCDEject)
 	{
-	    /* Parse audio CD eject. */
+	    /* Parse audio CD eject */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -1681,7 +1685,7 @@ int YNetParseListAudioCDTracks(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YAudioCDTracksListSet)
 	{
-	    /* Parse list audio CD track set. */
+	    /* Parse list audio CD track set */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_track_number>
@@ -1750,7 +1754,7 @@ static int YNetParse(
 	    break;
 
 	  case YListHosts:
-/* Work on this later. */
+/* Work on this later */
 	    break;
 
 	  case YMixerChannel:
@@ -1758,7 +1762,7 @@ static int YNetParse(
 	    break;
 
 	  case YListMixers:
-/* Work on this later. */
+/* Work on this later */
 	    break;
 
 	  case YSoundObjectPlay:
@@ -1815,7 +1819,7 @@ static int YNetParse(
 
 
 	  default:
-	    /* Unknown op code, so set event type to 0. */
+	    /* Unknown op code, so set event type to 0 */
 	    event->type = 0;
 	    break;
 	}
@@ -1852,14 +1856,13 @@ int YNetRecv(YConnection *con)
 
 	YEvent *event_ptr;
 
-
 	if(con->buf == NULL)
 	    return(-1);
 
 	if(con->buf_cont < 0)
 	    con->buf_cont = 0;
 
-	/* Make sure that con->buf_len is greater than con->buf_cont. */
+	/* Make sure that con->buf_len is greater than con->buf_cont */
 	if((con->buf_len - con->buf_cont) <= 0)
 	{
 	    /* Buffer overflowed and unable to parse, so reset it
@@ -1875,17 +1878,18 @@ int YNetRecv(YConnection *con)
 		con->buf_len
 	    );
 
-	    /* Force disconnect. */
+	    /* Force disconnect */
 	    if(con->fd > -1)
 	    {
-		close(con->fd);
+		YShutdownSocket(con->fd, SHUT_RDWR, 30l);
+		YCloseSocketWait(con->fd, 30l);
 		con->fd = -1;
 	    }
 
 	    return(-1);
 	}
 
-	/* Check if there are any data to recieve. */
+	/* Check if there are any data to recieve */
 	timeout.tv_sec = 0;
 	timeout.tv_usec = 0;
 	FD_ZERO(&readfds);
@@ -1897,49 +1901,49 @@ int YNetRecv(YConnection *con)
 	if(!FD_ISSET(con->fd, &readfds))
 	    return(0);
 
-
-	buf_ptr = &(con->buf[con->buf_cont]);
+	buf_ptr = con->buf + con->buf_cont;
 	bytes_read = recv(
 	    con->fd,
 	    buf_ptr,
 	    con->buf_len - con->buf_cont,
-	    0
+	    MSG_NOSIGNAL
 	);
 	if(bytes_read == 0)
 	{
-	    /* select() indicated there was data to be read but actual
-	     * recieving of data returned no data. This implies the
-	     * connection was reset by the peer.
-	     */
-
-	    /* Force disconnect. */
+	    /* Shutdown and close the socket */
 	    if(con->fd > -1)
 	    {
+		YShutdownSocket(con->fd, SHUT_RDWR, 30l);
 		close(con->fd);
 		con->fd = -1;
 	    }
 
 	    return(-1);
 	}
-	else if(bytes_read <= 0)
+	else if(bytes_read < 0)
 	{
-	    /* Handle error. */
-	    switch(errno)
+	    /* Handle error */
+	    const int error_code = errno;
+	    switch(error_code)
 	    {
 	      /* These errors are okay, return 0 indicating no data
-	       * read but also no error.
+	       * read but also no error
 	       */
 	      case EWOULDBLOCK:
+#if (EAGAIN != EWOULDBLOCK)
+	      case EAGAIN:
+#endif
 	      case EINTR:
 		return(0);
 		break;
 
-	      /* All other errors, force disconnect and return -1. */
+	      /* All other errors, force disconnect and return -1 */
 	      default:
-		/* Force disconnect. */
+		/* Force disconnect */
 		if(con->fd > -1)
 		{
-		    close(con->fd);
+		    YShutdownSocket(con->fd, SHUT_RDWR, 30l);
+		    YCloseSocketWait(con->fd, 30l);
 		    con->fd = -1;
 		}
 		return(-1);
@@ -1947,7 +1951,7 @@ int YNetRecv(YConnection *con)
 	    }
 	}
 
-	/* Increment byte count indicating contents in buffer. */
+	/* Increment byte count indicating contents in buffer */
 	con->buf_cont += bytes_read;
 	/* Sanitize buf_cont to the number of bytes allocated in the
 	 * buffer. This will be checked on the next loop if they
@@ -1991,11 +1995,12 @@ int YNetRecv(YConnection *con)
 		    chunk_length,
 		    major_op_code,
 		    minor_op_code,
- "Recieved a segment with header specified chunk length less than 8 bytes"
+"Recieved a segment with header specified chunk length less than 8 bytes"
 		);
 		if(con->fd > -1)
 		{
-		    close(con->fd);
+		    YShutdownSocket(con->fd, SHUT_RDWR, 30l);
+		    YCloseSocketWait(con->fd, 30l);
 		    con->fd = -1;
 		}
 		return(-1);
@@ -2009,20 +2014,21 @@ int YNetRecv(YConnection *con)
 		break;
 
 
-	    /* Increment total number of queued events. */
+	    /* Increment total number of queued events */
 	    if(con->total_queued_events < 0)
 		con->total_queued_events = 0;
 	    con->total_queued_events++;
 	    if(con->total_queued_events > YQueuedEventsMax)
 	    {
-		/* Queued events overflowed. */
+		/* Queued events overflowed */
 
 		con->total_queued_events = YQueuedEventsMax;
 
-		/* Need to force close connection for this. */
+		/* Need to force close connection for this */
 		if(con->fd > -1)
 		{
-		    close(con->fd);
+                    YShutdownSocket(con->fd, SHUT_RDWR, 30l);
+                    YCloseSocketWait(con->fd, 30l);
 		    con->fd = -1;
 		}
 
@@ -2034,27 +2040,28 @@ int YNetRecv(YConnection *con)
 
 		return(-1);
 	    }
-	    /* Allocate a new queued event. */
+	    /* Allocate a new queued event */
 	    con->queued_event = (YEvent *)realloc(
 		con->queued_event,
 		con->total_queued_events * sizeof(YEvent)
 	    );
 	    if(con->queued_event == NULL)
 	    {
-		/* Memory allocation error. */
+		/* Memory allocation error */
 
 		con->total_queued_events = 0;
 
-		/* Need to force close connection for this. */
+		/* Need to force close connection for this */
 		if(con->fd > -1)
 		{
-		    close(con->fd);
+                    YShutdownSocket(con->fd, SHUT_RDWR, 30l);
+                    YCloseSocketWait(con->fd, 30l);
 		    con->fd = -1;
 		}
 
 		return(-1);
 	    }
-	    /* Get pointer to newly allocated queued event segment. */
+	    /* Get pointer to newly allocated queued event segment */
 	    event_ptr = &(con->queued_event[
 		con->total_queued_events - 1
 	    ]);
@@ -2073,14 +2080,14 @@ int YNetRecv(YConnection *con)
 	    );
 	    segments_handled++;
 
-	    /* Shift the buffer. */
+	    /* Shift the buffer */
 	    for(i = 0, n = chunk_length;
 		n < con->buf_cont;
 		i++, n++
 	    )
 		con->buf[i] = con->buf[n];
 
-	    /* Decrease buffer contents. */
+	    /* Decrease buffer contents */
 	    con->buf_cont = (YDataLength)con->buf_cont -
 		(YDataLength)chunk_length;
 	    if(con->buf_cont < 0)
@@ -2088,7 +2095,7 @@ int YNetRecv(YConnection *con)
 
 
 	    /* Post event handling; check special case if the event we
-	     * just parsed is either YDisconnect or YShutdown.
+	     * just parsed is either YDisconnect or YShutdown
 	     */
 	    if((event_ptr->type == YDisconnect) ||
 	       (event_ptr->type == YShutdown)
@@ -2099,7 +2106,8 @@ int YNetRecv(YConnection *con)
 		 */
 		if(con->fd > -1)
 		{
-		    close(con->fd);
+                    YShutdownSocket(con->fd, SHUT_RDWR, 30l);
+                    YCloseSocketWait(con->fd, 30l);
 		    con->fd = -1;
 		}
 	    }
@@ -2107,7 +2115,7 @@ int YNetRecv(YConnection *con)
 
 
 	/* Return number of segments handled which implies number of
-	 * events that were handled.
+	 * events that were handled
 	 */
 	return(segments_handled);
 }
