@@ -37,6 +37,12 @@ int AFWLoadSegment(
 void AFWClose(AFWDataStruct *af_data, Audio *audio);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Coppies the data to the previous data pointer.
  *	Reallocating it as needed.
@@ -148,7 +154,7 @@ int AFWOpen(const char *path, AFWDataStruct *af_data)
 	    /* Copy other data from library specific structure to
 	     * our afw data structure.
 	     */
-            af_data->file_format = AFWFileFormatWav;
+	    af_data->file_format = AFWFileFormatWav;
 	    af_data->sndobj_format = SndObjTypeDSP;
 	    af_data->entire_length = wd.data_chunk_size;
 	    af_data->buffer = NULL;
@@ -156,13 +162,13 @@ int AFWOpen(const char *path, AFWDataStruct *af_data)
 
 	    af_data->block_align = wd.block_align;
 	    af_data->block_length = ((wd.bits_per_sample == 16) ?
-                2 : 1
+		2 : 1
 	    );
 
 	    af_data->sample_size = wd.bits_per_sample;
-            af_data->channels = wd.channels;
-            af_data->sample_rate = wd.samples_per_sec;
-            af_data->bytes_per_sec = wd.bytes_per_sec;
+	    af_data->channels = wd.channels;
+	    af_data->sample_rate = wd.samples_per_sec;
+	    af_data->bytes_per_sec = wd.bytes_per_sec;
 	}
 	/* Is it a VOC file? */
 	else if(VocReadHeader(path, fp, &vd) == VocSuccess)
@@ -179,102 +185,102 @@ int AFWOpen(const char *path, AFWDataStruct *af_data)
 	    else
 		vd_ptr = (voc_data_struct *)af_data->ptr;
 
-            memcpy(vd_ptr, &vd, sizeof(voc_data_struct));
+	    memcpy(vd_ptr, &vd, sizeof(voc_data_struct));
 
-            /* Copy other data from library specific structure to
-             * our afw data structure.
-             */
+	    /* Copy other data from library specific structure to
+	     * our afw data structure.
+	     */
 	    af_data->file_format = AFWFileFormatVoc;
-            af_data->sndobj_format = SndObjTypeDSP;
-            af_data->entire_length = vd.total_data_len;
-            af_data->buffer = NULL;
-            af_data->length = 0;
+	    af_data->sndobj_format = SndObjTypeDSP;
+	    af_data->entire_length = vd.total_data_len;
+	    af_data->buffer = NULL;
+	    af_data->length = 0;
 
 	    /* Get block align and length. */
-            af_data->block_align = 0;
-            af_data->block_length = 1;
+	    af_data->block_align = 0;
+	    af_data->block_length = 1;
 	    for(i = 0; i < vd.total_datablocks; i++)
 	    {
 		if(vd.datablock[i] == NULL)
 		    continue;
 		if(vd.datablock[i]->type != VocBlockTypeSoundData)
-                    continue;
+		    continue;
 
-                af_data->block_align = 0;
-                af_data->block_length =
+		af_data->block_align = 0;
+		af_data->block_length =
 		    ((vd.datablock[i]->bits == 16) ? 2 : 1);
 
-                af_data->sample_size = 8;
-                af_data->channels = 1;
-                af_data->sample_rate =
+		af_data->sample_size = 8;
+		af_data->channels = 1;
+		af_data->sample_rate =
 		    vd.datablock[i]->sample_rate;
-                af_data->bytes_per_sec = af_data->sample_rate;
+		af_data->bytes_per_sec = af_data->sample_rate;
 	    }
 	}
-        /* Is it a MIDI file? */
-        else if(MidiRead(path, fp, &md) == MidiSuccess)
-        {
-            fp = NULL;          /* Do not referance the fp again. */
+	/* Is it a MIDI file? */
+	else if(MidiRead(path, fp, &md) == MidiSuccess)
+	{
+	    fp = NULL;          /* Do not referance the fp again. */
 
-            /* Load as a MIDI file. */
-            af_data->ptr = calloc(1, sizeof(MidiDataStruct));
-            if(af_data->ptr == NULL)
-                return(-1);
+	    /* Load as a MIDI file. */
+	    af_data->ptr = calloc(1, sizeof(MidiDataStruct));
+	    if(af_data->ptr == NULL)
+		return(-1);
 	    else
 		md_ptr = (MidiDataStruct *)af_data->ptr;
 
-            memcpy(md_ptr, &md, sizeof(MidiDataStruct));
+	    memcpy(md_ptr, &md, sizeof(MidiDataStruct));
 
-            /* Copy other data from library specific structure to   
-             * our afw data structure.
-             */
-            af_data->file_format = AFWFileFormatMidi;
-            af_data->sndobj_format = SndObjTypeMIDI;
-            af_data->entire_length = 0;
-            af_data->buffer = NULL;
-            af_data->length = 0;
+	    /* Copy other data from library specific structure to   
+	     * our afw data structure.
+	     */
+	    af_data->file_format = AFWFileFormatMidi;
+	    af_data->sndobj_format = SndObjTypeMIDI;
+	    af_data->entire_length = 0;
+	    af_data->buffer = NULL;
+	    af_data->length = 0;
 
-            af_data->block_align = 0;
-            af_data->block_length = 0;
+	    af_data->block_align = 0;
+	    af_data->block_length = 0;
 
-            af_data->sample_size = 0;
-            af_data->channels = 0;
-            af_data->sample_rate = 0;
-            af_data->bytes_per_sec = 0;
-        }
+	    af_data->sample_size = 0;
+	    af_data->channels = 0;
+	    af_data->sample_rate = 0;
+	    af_data->bytes_per_sec = 0;
+	}
 	/* Is it a RAW file? (This needs to be checked last). */
-        else if(RawReadHeader(path, fp, &rd) == RawSuccess)
-        {
+	else if(RawReadHeader(path, fp, &rd) == RawSuccess)
+	{
 	    fp = NULL;		/* Do not referance the fp again. */
 
-            /* Load as a RAW file. */
-            af_data->ptr = calloc(1, sizeof(raw_data_struct));
-            if(af_data->ptr == NULL)
-                return(-1);
+	    /* Load as a RAW file. */
+	    af_data->ptr = calloc(1, sizeof(raw_data_struct));
+	    if(af_data->ptr == NULL)
+		return(-1);
 	    else
 		rd_ptr = (raw_data_struct *)af_data->ptr;
 
-            memcpy(rd_ptr, &rd, sizeof(raw_data_struct));
+	    memcpy(rd_ptr, &rd, sizeof(raw_data_struct));
 
-            /* Copy other data from library specific structure to
-             * our afw data structure.
-             */
-            af_data->file_format = AFWFileFormatRaw;
-            af_data->sndobj_format = SndObjTypeDSP;
-            af_data->entire_length = rd.data_length;
-            af_data->buffer = NULL;
-            af_data->length = 0;
+	    /* Copy other data from library specific structure to
+	     * our afw data structure.
+	     */
+	    af_data->file_format = AFWFileFormatRaw;
+	    af_data->sndobj_format = SndObjTypeDSP;
+	    af_data->entire_length = rd.data_length;
+	    af_data->buffer = NULL;
+	    af_data->length = 0;
 
-            af_data->block_align = rd.block_align;
-            af_data->block_length = (rd.sample_size == 16) ?
+	    af_data->block_align = rd.block_align;
+	    af_data->block_length = (rd.sample_size == 16) ?
 		2 : 1;
 
-            af_data->sample_size = rd.sample_size;
-            af_data->channels = rd.channels;
-            af_data->sample_rate = rd.sample_rate;
-            af_data->bytes_per_sec = rd.sample_rate *
-                ((rd.sample_size == 16) ? 2 : 1);
-        }
+	    af_data->sample_size = rd.sample_size;
+	    af_data->channels = rd.channels;
+	    af_data->sample_rate = rd.sample_rate;
+	    af_data->bytes_per_sec = rd.sample_rate *
+		((rd.sample_size == 16) ? 2 : 1);
+	}
 
 	/* If fp is not NULL, then that implies it did not match
 	 * any file type supported.
@@ -319,15 +325,15 @@ int AFWOpen(const char *path, AFWDataStruct *af_data)
  *	is still playing then 0 is returned.
  */
 int AFWLoadSegment(
-        AFWDataStruct *af_data,
-        YDataPosition position,
-        YDataLength length,
+	AFWDataStruct *af_data,
+	YDataPosition position,
+	YDataLength length,
 	Audio *audio
 )
 {
 	int status;
 	pid_t pid;
-        raw_data_struct *raw_data;
+	raw_data_struct *raw_data;
 	wav_data_struct *wav_data;
 	voc_data_struct *voc_data;
 	MidiDataStruct *midi_data;
@@ -345,7 +351,7 @@ int AFWLoadSegment(
 	{
 	    /* It is a MIDI Sound Object. */
 
-            status = 0;
+	    status = 0;
 
 	    /* Get pointer to MIDI Audio. */
 	    if(audio == NULL)
@@ -364,8 +370,8 @@ int AFWLoadSegment(
 	      case AFWFileFormatMidi:
 	        midi_data = (MidiDataStruct *)af_data->ptr;
 
-                /* Get pid of actual current MIDI play (if any). */
-                pid = MIDIIOWIsPlaying(midi_audio_ptr);
+		/* Get pid of actual current MIDI play (if any). */
+		pid = MIDIIOWIsPlaying(midi_audio_ptr);
 
 		/* Was this MIDI being played? */
 		if(af_data->pid > 0)
@@ -391,7 +397,7 @@ int AFWLoadSegment(
 		    {
 			/* Midi play process has finished. */
 			status = -3;
-                        af_data->pid = 0;
+			af_data->pid = 0;
 		    }
 		}
 		else
@@ -400,7 +406,7 @@ int AFWLoadSegment(
 		     * start playing this MIDI.
 		     */
 
-                    /* Is a MIDI currently being played? */
+		    /* Is a MIDI currently being played? */
 		    if(pid > 0)
 		    {
 			/* An MIDI is still being played, stop it. */
@@ -425,9 +431,9 @@ int AFWLoadSegment(
 		}
 		break;
 
-              default:
-                status = -1;
-                break;
+	      default:
+		status = -1;
+		break;
 	    }
 
 	    return(status);
@@ -436,38 +442,38 @@ int AFWLoadSegment(
 	{
 	    /* It is a DSP Sound Object. */
 
-	    /*   Do not free buffer on af_data, it will be freed by
-	     * the call to the library.
+	    /* Do not free the buffer on our af_data, it is shared and
+	     * will be free'ed by the call to the library function.
 	     */
 	    af_data->length = 0;
 
 	    /* Load audio segment by the sound object file format. */
-            switch(af_data->file_format)
-            {
-              case AFWFileFormatRaw:
-                raw_data = (raw_data_struct *)af_data->ptr;
-                status = RawReadPartialData(
-                    raw_data,
-                    position,   
-                    length,
-                    RawReadSigned8
-                );
-                if(status == RawSuccess)
-                {
+	    switch(af_data->file_format)
+	    {
+	      case AFWFileFormatRaw:
+		raw_data = (raw_data_struct *)af_data->ptr;
+		status = RawReadPartialData(
+		    raw_data,
+		    position,   
+		    length,
+		    RawReadSigned8
+		);
+		if(status == RawSuccess)
+		{
 		    AFWCopyDataAlloc(
 			raw_data->data,
 			raw_data->data_len,
 			&af_data->buffer,
 			&af_data->length
 		    );
-                }
-                else
-                {
-                    af_data->buffer = NULL;
-                }
-                break;
+		}
+		else
+		{
+		    af_data->buffer = NULL;
+		}
+		break;
 
-              case AFWFileFormatWav:
+	      case AFWFileFormatWav:
 	        wav_data = (wav_data_struct *)af_data->ptr;
 	        status = WavReadPartialData(
 		    wav_data,
@@ -477,50 +483,50 @@ int AFWLoadSegment(
 	        );
 	        if(status == WavSuccess)
 	        {
-                    AFWCopyDataAlloc(
-                        wav_data->data,
-                        wav_data->data_len,
-                        &af_data->buffer,
-                        &af_data->length
-                    );
+		    AFWCopyDataAlloc(
+			wav_data->data,
+			wav_data->data_len,
+			&af_data->buffer,
+			&af_data->length
+		    );
 	        }
 	        else
-                {
-                    af_data->buffer = NULL;
-                }
-                break;
+		{
+		    af_data->buffer = NULL;
+		}
+		break;
 
-              case AFWFileFormatVoc:
-                voc_data = (voc_data_struct *)af_data->ptr;
+	      case AFWFileFormatVoc:
+		voc_data = (voc_data_struct *)af_data->ptr;
 	        status = VocReadPartialData(
 		    voc_data,
 		    position,
 		    length,
 		    VocReadSigned8
 	        );
-                if(status == VocSuccess)
-                {
-                    AFWCopyDataAlloc(
-                        voc_data->data,
-                        voc_data->data_len,
-                        &af_data->buffer,
-                        &af_data->length
-                    );
-                }
-                else
-                {
-                    af_data->buffer = NULL;
-                }
-                break;
+		if(status == VocSuccess)
+		{
+		    AFWCopyDataAlloc(
+			voc_data->data,
+			voc_data->data_len,
+			&af_data->buffer,
+			&af_data->length
+		    );
+		}
+		else
+		{
+		    af_data->buffer = NULL;
+		}
+		break;
 
-              case AFWFileFormatMP3:
-                return(-1);
-                break;
+	      case AFWFileFormatMP3:
+		return(-1);
+		break;
  
-              default:
+	      default:
 	        return(-1);
-                break;
-            }
+		break;
+	    }
 	}
 	else
 	{
@@ -551,7 +557,7 @@ void AFWClose(AFWDataStruct *af_data, Audio *audio)
 	switch(af_data->file_format)
 	{
 	  case AFWFileFormatRaw:
-            RawDestroyData((raw_data_struct *)af_data->ptr);
+	    RawDestroyData((raw_data_struct *)af_data->ptr);
 	    break;
 
 	  case AFWFileFormatWav:
@@ -559,17 +565,17 @@ void AFWClose(AFWDataStruct *af_data, Audio *audio)
 	    break;
 
 	  case AFWFileFormatVoc:
-            VocDestroyData((voc_data_struct *)af_data->ptr);
+	    VocDestroyData((voc_data_struct *)af_data->ptr);
 	    break;
 
 	  case AFWFileFormatMP3:
 	    break;
 
-          case AFWFileFormatMidi:
-            /* Get pointer to MIDI Audio. */
-            if(audio != NULL)
-            {
-                midi_audio_ptr = &audio->midi_audio;
+	  case AFWFileFormatMidi:
+	    /* Get pointer to MIDI Audio. */
+	    if(audio != NULL)
+	    {
+		midi_audio_ptr = &audio->midi_audio;
 
 		/* Stop MIDI play if it is playing this. */
 		pid = MIDIIOWIsPlaying(midi_audio_ptr);
@@ -586,8 +592,8 @@ void AFWClose(AFWDataStruct *af_data, Audio *audio)
 	    /* Reset pid. */
 	    af_data->pid = 0;
 
-            MidiDestroy((MidiDataStruct *)af_data->ptr);
-            break;
+	    MidiDestroy((MidiDataStruct *)af_data->ptr);
+	    break;
 
 	  default:
 	    break;
