@@ -11,7 +11,7 @@ extern int errno;
 
 #include <netinet/in.h>
 #include <sys/socket.h>
-#include <arpa/inet.h>		/* For inet_ntoa. */
+#include <arpa/inet.h>		/* For inet_ntoa */
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -65,6 +65,8 @@ void YiffResetTimers(void);
 #define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
 #define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
 
+#define STRDUP(s)	(((s) != NULL) ? strdup(s) : NULL)
+
 #define MINSC(a,b)	((a < b) ? (char)127 : (char)(a))
 #define MAXSC(a,b)	((a > b) ? (char)-128 : (char)(a))
 
@@ -102,8 +104,8 @@ int listen_socket;
 /*
  *	Local timings:
  */
-#define MIN_NEXT_SOUND_DELTA	100	/* In microseconds. */
-static time_t next_sound_delta_us;	/* In microseconds. */
+#define MIN_NEXT_SOUND_DELTA	100	/* In microseconds */
+static time_t next_sound_delta_us;	/* In microseconds */
 
 
 /*
@@ -133,17 +135,17 @@ void YiffHangupHandle(void)
 {
 	int i;
 
-	/* Reload YIFF sound server configuration. */
+	/* Reload YIFF sound server configuration */
 	RCLoadFromFile(fname.rcfile);
 
-	/* Delete all playstacks and notify owner connections about it. */
+	/* Delete all playstacks and notify owner connections about it */
 	for(i = 0; i < total_playstacks; i++)
 	    YiffDestroyPlaystack(i);
 
-	/* Notify all connections about YSHM sound closing. */
+	/* Notify all connections about YSHM sound closing */
 	YNetDoNotifyAllYSHMSoundClose();
 
-	/* Close sound device. */
+	/* Close sound device */
 	YSoundShutdown(recorder);
 
 
@@ -152,7 +154,7 @@ void YiffHangupHandle(void)
 	 */
 
 
-	/* Initialize recorder. */
+	/* Initialize recorder */
 	if(YSoundInit(recorder, &option.audio))
 	{
 	    fprintf(stderr,
@@ -165,7 +167,7 @@ To terminate type: `kill -s INT %i'\n",
 	    return;
 	}
 
-	/* Load mixer settings from file. */
+	/* Load mixer settings from file */
 	if(MixerRCLoadFromFile(fname.mixerrcfile, recorder))
 	{
 	    /* Could not load settings from file, so reset mixer
@@ -174,17 +176,17 @@ To terminate type: `kill -s INT %i'\n",
 	    YiffResetMixer();
 	}
 
-	/* Update timers (to help sync audio device). */
+	/* Update timers (to help sync audio device) */
 	YiffUpdateTimers(); 
 
-	/* Need to sync audio device right after initialization. */
+	/* Need to sync audio device right after initialization */
 	YSoundSync(recorder, 0);  
 
-	/* Reset global next sound delta (use min). */
+	/* Reset global next sound delta (use min) */
 	next_sound_delta_us = MIN_NEXT_SOUND_DELTA;
 
 
-	/* Schedual next refresh. */
+	/* Schedual next refresh */
 	next.refresh.ms = cur_time.ms + option.refresh_int.ms;
 	next.refresh.us = 0;
 
@@ -217,7 +219,7 @@ void YiffSignalHandler(int sig)
 	    break;
 
 	  case SIGSEGV:
-	    /* Increment segfault counter. */
+	    /* Increment segfault counter */
 	    segfault_count++;
 	    if(segfault_count >= 2)
 		exit(-1);
@@ -343,7 +345,7 @@ int YiffInit(int argc, char **argv)
 	 */
 	if(status)
 	{
-	    /* Fork process into background. */
+	    /* Fork process into background */
 	    switch(fork())
 	    {
 	      case -1:
@@ -351,24 +353,24 @@ int YiffInit(int argc, char **argv)
 		return(-1);
 		break;
 
-	      case 0:   /* Child. */
+	      case 0:   /* Child */
 		break;
 
-	      default:  /* Parent. */
+	      default:  /* Parent */
 		exit(0);
 		break;
 	    }
 	}
 
 
-	/* Get current working dir. */
+	/* Get current working dir */
 	getcwd(cwd, PATH_MAX);
 	cwd[PATH_MAX - 1] = '\0';
 
 
-	/* Reset global variables. */
+	/* Reset global variables */
 
-	/* Options. */
+	/* Options */
 	option.debug = False;
 	option.port = DEF_PORT;
 
@@ -406,16 +408,16 @@ int YiffInit(int argc, char **argv)
 	option.audio.flip_stereo = False;
 	option.audio.direction = AUDIO_DIRECTION_PLAY;
 
-	option.refresh_int.ms = 30000;		/* 30 seconds. */
+	option.refresh_int.ms = 30000;		/* 30 seconds */
 	option.refresh_int.us = 0;
 
 	option.midi_play_cmd = strdup(DEF_MIDI_CMD);
 
 #ifdef ALSA_RUN_CONFORM
-	option.midi_device_number = -1;	/* Set to -1 to mark as unset. */
+	option.midi_device_number = -1;	/* Set to -1 to mark as unset */
 #endif	/* ALSA_RUN_CONFORM */
 
-	/* File names. */
+	/* File names */
 	strncpy(fname.rcfile, DEF_RCFILE_NAME, PATH_MAX + NAME_MAX);
 	fname.rcfile[PATH_MAX + NAME_MAX - 1] = '\0';
 
@@ -439,16 +441,16 @@ int YiffInit(int argc, char **argv)
 	strncpy(fname.mixer, DEF_MIXER, PATH_MAX + NAME_MAX);
 	fname.mixer[PATH_MAX + NAME_MAX - 1] = '\0';
 
-	/* Statistics. */
+	/* Statistics */
 	ystats.pid = getpid();
 	ystats.start_time = time(NULL);
 	ystats.cycle_load = 0.0;
 
 
-	/* Delete any existing sound paths (shouldn't be any). */
+	/* Delete any existing sound paths (shouldn't be any) */
 	SoundPathDeleteAll();
 
-	/* Allocate current directory as first sound path. */
+	/* Allocate current directory as first sound path */
 	i = SoundPathAllocate();
 	if(SoundPathIsAllocated(i))
 	{
@@ -459,7 +461,7 @@ int YiffInit(int argc, char **argv)
 	}
 
 
-	/* Delete any existing yhosts (shouldn't be any). */
+	/* Delete any existing yhosts (shouldn't be any) */
 	YHostDeleteAll();
 
 	/* Add localhost (127.0.0.1) to list of allowed hosts to
@@ -473,14 +475,14 @@ int YiffInit(int argc, char **argv)
 
 
 	/* ****************************************************** */
-	/* Parse arguments. */
+	/* Parse arguments */
 	for(i = 1; i < argc; i++)
 	{
 	    arg_ptr = argv[i];
 	    if(arg_ptr == NULL)
 		continue;
 
-	    /* Help. */
+	    /* Help */
 	    if(strcasepfx(arg_ptr, "--h") ||
 	       strcasepfx(arg_ptr, "-h") ||
 	       strcasepfx(arg_ptr, "-?") ||
@@ -490,7 +492,7 @@ int YiffInit(int argc, char **argv)
 		printf(PROG_HELP_MESG);
 		return(-4);
 	    }
-	    /* Version. */
+	    /* Version */
 	    else if(strcasepfx(arg_ptr, "--ver") ||
 		    strcasepfx(arg_ptr, "-ver")
 	    )
@@ -499,7 +501,7 @@ int YiffInit(int argc, char **argv)
 		printf("%s\n", PROG_COPYRIGHT);
 		return(-4);
 	    }
-	    /* Device. */
+	    /* Device */
 	    else if(strcasepfx(arg_ptr, "--d") ||
 		    strcasepfx(arg_ptr, "-d")
 	    )
@@ -522,7 +524,7 @@ int YiffInit(int argc, char **argv)
 		}
 	    }
 #ifdef ALSA_RUN_CONFORM
-	    /* MIDI device port number. */
+	    /* MIDI device port number */
 	    else if(strcasepfx(arg_ptr, "--midi_port"))
 	    {
 		i++;
@@ -540,7 +542,7 @@ int YiffInit(int argc, char **argv)
 		}
 	    }
 #endif	/* ALSA_RUN_CONFORM */
-	    /* Mixer settings file. */
+	    /* Mixer settings file */
 	    else if(strcasepfx(arg_ptr, "--mixer_rc") ||
 		    strcasepfx(arg_ptr, "-mixer_rc")
 	    )
@@ -560,7 +562,7 @@ int YiffInit(int argc, char **argv)
 		    );
 		}
  	    }
-	    /* Mixer. */
+	    /* Mixer */
 	    else if(strcasepfx(arg_ptr, "--m") ||
 		    strcasepfx(arg_ptr, "-m")
 	    )
@@ -582,7 +584,7 @@ int YiffInit(int argc, char **argv)
 		    );
 		}
 	    }
-	    /* Port. */
+	    /* Port */
 	    else if(strcasepfx(arg_ptr, "--po") ||
 		    strcasepfx(arg_ptr, "-po")
 	    )
@@ -602,7 +604,7 @@ int YiffInit(int argc, char **argv)
 		    );
 		}
 	    }
-	    /* Sound path. */
+	    /* Sound path */
 	    else if(strcasepfx(arg_ptr, "--pa") ||
 		    strcasepfx(arg_ptr, "-pa")
 	    )
@@ -616,7 +618,7 @@ int YiffInit(int argc, char **argv)
 		    if(SoundPathIsAllocated(n))
 		    {
 			free(soundpath[n]->path);
-			soundpath[n]->path = StringCopyAlloc(arg_ptr);
+			soundpath[n]->path = STRDUP(arg_ptr);
 
 			if(stat(soundpath[n]->path, &stat_buf))
 			{
@@ -643,7 +645,7 @@ int YiffInit(int argc, char **argv)
 		    );
 		}
 	    }
-	    /* All else, it's the rcfile. */
+	    /* All else, it's the rcfile */
 	    else if(((*arg_ptr) != '\0') &&
 		    ((*arg_ptr) != '-') &&
 		    ((*arg_ptr) != '+')
@@ -655,7 +657,7 @@ int YiffInit(int argc, char **argv)
 	}
 
 	/* ****************************************************** */
-	/* Load configuration. */
+	/* Load configuration */
 	status = RCLoadFromFile(fname.rcfile);
 	if(status)
 	    return(-1);
@@ -663,7 +665,7 @@ int YiffInit(int argc, char **argv)
 	/*   Need to set current mode and options values to match
 	 *   default Audio mode.
 	 */
-	n = 0;	/* Default audio mode is the first one. */
+	n = 0;	/* Default audio mode is the first one */
 	if(YModeIsAllocated(n))
 	{
 	    /* Set new Audio parameters to option's Audio structure
@@ -673,7 +675,7 @@ int YiffInit(int argc, char **argv)
 	    YMode *ymode_ptr = ymode[n];
 
 
-	    /* Audio modes are always considered user set. */
+	    /* Audio modes are always considered user set */
 	    audio_ptr->cycle_set = CYCLE_SET_USER;
 
 	    audio_ptr->cycle.ms = ymode_ptr->cycle.ms;
@@ -688,11 +690,11 @@ int YiffInit(int argc, char **argv)
 	    audio_ptr->write_ahead.ms = ymode_ptr->write_ahead.ms;
 	    audio_ptr->write_ahead.us = ymode_ptr->write_ahead.us;
 
-	    /* This will be reset by YSoundInit(). */
+	    /* This will be reset by YSoundInit() */
 	    audio_ptr->cycle_ahead_left.ms = 0;
 	    audio_ptr->cycle_ahead_left.us = 0;
 
-	    /* This will be reset by YSoundInit(). */
+	    /* This will be reset by YSoundInit() */
 	    audio_ptr->cumulative_latency.ms = 0;
 	    audio_ptr->cumulative_latency.us = 0;
 
@@ -700,7 +702,7 @@ int YiffInit(int argc, char **argv)
 	    audio_ptr->channels = ymode_ptr->channels;
 	    audio_ptr->sample_rate = ymode_ptr->sample_rate;
 
-	    /* This will be recalculated by YSoundInit(). */
+	    /* This will be recalculated by YSoundInit() */
 	    audio_ptr->bytes_per_second = 0;
 
 #ifdef OSS_BUFFRAG
@@ -740,7 +742,7 @@ int YiffInit(int argc, char **argv)
 
 
 	/* ****************************************************** */
-	/* Set signals to watch. */
+	/* Set signals to watch */
 	signal(SIGHUP, YiffSignalHandler);
 	signal(SIGINT, YiffSignalHandler);
 	signal(SIGKILL, YiffSignalHandler);
@@ -750,12 +752,12 @@ int YiffInit(int argc, char **argv)
 
 
 	/* ****************************************************** */
-	/* Reset timers. */
+	/* Reset timers */
 	YiffResetTimers();
 
 
 	/* ****************************************************** */
-	/* Allocate recorder structure and initialize sound. */
+	/* Allocate recorder structure and initialize sound */
 	recorder = (Recorder *)calloc(1, sizeof(Recorder));
 	if(recorder == NULL)
 	{
@@ -770,7 +772,7 @@ int YiffInit(int argc, char **argv)
 	    return(-1);
 
 
-	/* Load mixer settings from file. */
+	/* Load mixer settings from file */
 	if(MixerRCLoadFromFile(fname.mixerrcfile, recorder))
 	{
 	    /* Could not load settings from file, so reset mixer
@@ -781,7 +783,7 @@ int YiffInit(int argc, char **argv)
 
 
 	/* ****************************************************** */
-	/* Set up listening socket. */
+	/* Set up listening socket */
 	listen_socket = socket(AF_INET, SOCK_STREAM, 0);
 	if(listen_socket < 0)
 	{
@@ -802,7 +804,7 @@ int YiffInit(int argc, char **argv)
 	addr.sin_addr.s_addr = INADDR_ANY;
 	memset(&addr.sin_zero, 0, 8);
 
-	/* Bind the socket. */
+	/* Bind the socket */
 	status = bind(
 	    listen_socket,
 	    (struct sockaddr *)&addr,
@@ -837,22 +839,22 @@ int YiffInit(int argc, char **argv)
 	    return(-1);
 	}
 
-	/* Set listening port socket to nonblocking. */
+	/* Set listening port socket to nonblocking */
 	fcntl(listen_socket, F_SETFL, O_NONBLOCK);
 
 
 	/* ********************************************************** */
-	/* Update timers (to help sync audio device). */
+	/* Update timers (to help sync audio device) */
 	YiffUpdateTimers();
 
-	/* Need to sync audio device right after initialization. */
+	/* Need to sync audio device right after initialization */
 	YSoundSync(recorder, 0);
 
-	/* Reset global next sound delta (use min). */
+	/* Reset global next sound delta (use min) */
 	next_sound_delta_us = MIN_NEXT_SOUND_DELTA;
 
 
-	/* schedual next refresh. */
+	/* schedual next refresh */
 	next.refresh.ms = cur_time.ms + option.refresh_int.ms;
 	next.refresh.us = 0;
 
@@ -868,11 +870,11 @@ void YiffShutdown(void)
 	YConnection *con;
 
 
-	/* Save mixer settings. */
+	/* Save mixer settings */
 	MixerRCSaveToFile(fname.mixerrcfile, recorder);
 
 
-	/* Notify all connections about YSHM sound closing. */
+	/* Notify all connections about YSHM sound closing */
 	YNetDoNotifyAllYSHMSoundClose();
 
 	/* Notify all connections about shutdown by sending a
@@ -888,25 +890,23 @@ void YiffShutdown(void)
 	}
 
 
-	/* Free all sound paths. */
+	/* Free all sound paths */
 	SoundPathDeleteAll();
 
-	/* Free all play stacks. */
+	/* Free all play stacks */
 	PlayStackDeleteAll();
 
-	/* Deallocate recorder structure and shutdown sound. */
+	/* Deallocate recorder structure and shutdown sound */
 	YSoundShutdown(recorder);
 	free(recorder);
 	recorder = NULL;
 
 
-	/* Close listening socket. */
+	/* Close the listening socket */
 	if(listen_socket > -1)
 	{
-#ifndef SHUT_RDWR
-# define SHUT_RDWR	2
-#endif
 	    shutdown(listen_socket, SHUT_RDWR);
+	    close(listen_socket);
 	    listen_socket = -1;
 	}
 
@@ -918,16 +918,16 @@ void YiffShutdown(void)
 	 */
 	ConnectionDeleteAll();
 
-	/* Free all yhosts. */
+	/* Free all yhosts */
 	YHostDeleteAll();
 
-	/* Free all ymodes. */
+	/* Free all ymodes */
 	YModeDeleteAll();
 
 
-	/* Begin deallocating options. */
+	/* Begin deallocating options */
 
-	/* Free midi play command. */
+	/* Free midi play command */
 	free(option.midi_play_cmd);
 	option.midi_play_cmd = NULL;
 }
@@ -958,7 +958,7 @@ int YiffCheckNewConnection(int socket)
 	if(!FD_ISSET(socket, &readfds))
 	    return(0);
 
-	/* Handle new connection. */
+	/* Handle new connection */
 	sin_size = sizeof(struct sockaddr_in);
 	new_socket = accept(
 	    socket,
@@ -967,23 +967,23 @@ int YiffCheckNewConnection(int socket)
 	);
 	if(new_socket == -1)
 	    return(-1);
-	/* Set new socket non-blocking. */
+	/* Set new socket non-blocking */
 	fcntl(new_socket, F_SETFL, O_NONBLOCK);
 
 
-	/* Allocate a new connection structure. */
+	/* Allocate a new connection structure */
 	i = ConnectionAllocate();
 	con_ptr = ConnectionGetPtr(i);
 	if(con_ptr == NULL)
 	{
-	    close(new_socket);
+	    YShutdownSocket(new_socket, SHUT_RDWR, 30l);
+	    YCloseSocketWait(new_socket, 30l);
 	    new_socket = -1;
-
 	    return(-1);
 	}	
 
 
-	/* Set up connection. */
+	/* Set up connection */
 	con_ptr->socket = new_socket;
 	con_ptr->ip.whole = foreign_addr.sin_addr.s_addr;
 
@@ -999,7 +999,7 @@ printf("Server: Got connection from %i.%i.%i.%i.\n",
 	/* Is incoming connection's host allowed? */
 	if(!YHostInList(&con_ptr->ip))
 	{
-/*
+#if 0
 	    fprintf(
  "Y Server: Connection %i.%i.%i.%i denied, not in allowed YHosts list.\n",
 		 con_ptr->ip.charaddr[0],
@@ -1007,14 +1007,15 @@ printf("Server: Got connection from %i.%i.%i.%i.\n",
 		 con_ptr->ip.charaddr[2],
 		 con_ptr->ip.charaddr[3]
 	    );
- */
+#endif
 
-	    /* Send disconnect reason. */
+	    /* Send disconnect reason */
 	    YNetSendDisconnect(i, 0);
 
-	    /* Close and delete connection. */
-	    close(con_ptr->socket);
-	    con_ptr->socket = -1;
+	    /* Close and delete connection */
+            YShutdownSocket(con_ptr->socket, SHUT_RDWR, 30l);
+            YCloseSocketWait(con_ptr->socket, 30l);
+            con_ptr->socket = -1;  
 	    ConnectionDelete(i);
 	}
 
@@ -1030,16 +1031,14 @@ printf("Server: Got connection from %i.%i.%i.%i.\n",
 void YiffCloseConnection(YConnectionNumber con_num)
 {
 	int i;
-	YConnection *con_ptr;
+	YConnection *con;
 	PlayStack *ps;
 
-
-	con_ptr = ConnectionGetPtr(con_num);
-	if(con_ptr == NULL)
+	con = ConnectionGetPtr(con_num);
+	if(con == NULL)
 	    return;
 
-
-	/* Delete all playstacks associated with this connection. */
+	/* Delete all playstacks associated with this connection */
 	for(i = 0; i < total_playstacks; i++)
 	{
 	    ps = playstack[i];
@@ -1051,15 +1050,13 @@ void YiffCloseConnection(YConnectionNumber con_num)
 	}
 
 
-	/* Notify connection about disconnect. */
-	if(con_ptr->socket > -1)
-	    YNetSendDisconnect(con_num, 0);
-
-	/* Close connection. */
-	if(con_ptr->socket > -1)
+	/* Close connection as needed */
+	if(con->socket > -1)
 	{
-	    close(con_ptr->socket);
-	    con_ptr->socket = -1;
+	    YNetSendDisconnect(con_num, 0);
+            YShutdownSocket(con->socket, SHUT_RDWR, 30l);
+            YCloseSocketWait(con->socket, 30l);
+            con->socket = -1;
 	}
 
 
@@ -1079,10 +1076,10 @@ void YiffManageConnections(void)
 	YConnection *con;
 
 
-	/* Check for and handle any new incoming connections. */
+	/* Check for and handle any new incoming connections */
 	YiffCheckNewConnection(listen_socket);
 
-	/* Handle each connection for incoming data. */
+	/* Handle each connection for incoming data */
 	for(i = 0; i < total_yconnections; i++)
 	{
 	    con = yconnection[i];
@@ -1108,7 +1105,7 @@ void YiffManageConnections(void)
  */
 int YiffReadNextDSP(
 	PlayStack *ps_ptr,
-	int bytes_per_cycle	/* Actual bytes per cycle. */
+	int bytes_per_cycle	/* Actual bytes per cycle */
 )
 {
 	int status = 0;
@@ -1123,7 +1120,7 @@ int YiffReadNextDSP(
 	)
 	    return(-1);
 
-	/* Get pointer to audio file wrapper data structure. */
+	/* Get pointer to audio file wrapper data structure */
 	afw_ptr = &ps_ptr->afw_data;
 
 
@@ -1162,7 +1159,7 @@ int YiffReadNextDSP(
 		}
 	    }
 
-	    /* Increment position as if we're still reading. */
+	    /* Increment position as if we're still reading */
 	    ps_ptr->position += bytes_per_cycle;
 	    if(ps_ptr->position >= ps_ptr->data_length)
 	    {
@@ -1177,10 +1174,10 @@ int YiffReadNextDSP(
 	}
 
 
-	/* Record actual length of Sound buffer in bytes. */
+	/* Record actual length of Sound buffer in bytes */
 	actual_bytes_per_cycle = bytes_per_cycle;
 
-	/* Calculate the sample rate deviance adjusted bytes per cycle. */
+	/* Calculate the sample rate deviance adjusted bytes per cycle */
 	sample_rate_dev_coeff = (Coefficient)ps_ptr->applied_sample_rate /
 	    (Coefficient)MAX(recorder->audio.sample_rate, 1);
 	if(sample_rate_dev_coeff < 1.0)
@@ -1188,10 +1185,10 @@ int YiffReadNextDSP(
 	bytes_per_cycle = (int)((Coefficient)bytes_per_cycle *
 	    sample_rate_dev_coeff
 	);
-	/* Round up bytes_per_cycle to an even number if it is odd. */
+	/* Round up bytes_per_cycle to an even number if it is odd */
 	if(bytes_per_cycle & 1)
 	    bytes_per_cycle++;
-	/* Bytes per cycle cannot be less than actual bytes per cycle. */
+	/* Bytes per cycle cannot be less than actual bytes per cycle */
 	if(bytes_per_cycle < actual_bytes_per_cycle)
 	    bytes_per_cycle = actual_bytes_per_cycle;
 
@@ -1229,13 +1226,13 @@ int YiffReadNextDSP(
 	/* Is this play stack repeating just once? */
 	if(ps_ptr->total_repeats == 1)
 	{
-	    /* Play stack plays once without any repeats. */
+	    /* Play stack plays once without any repeats */
 
 	    /* Gone through entire segment of data (check inclusive)? */
 	    if(ps_ptr->position >= ps_ptr->data_length)
 		return(-1);
 
-	    /* Read next buffer segment. */
+	    /* Read next buffer segment */
 	    if(
 		AFWLoadSegment(
 		    afw_ptr,
@@ -1265,11 +1262,11 @@ int YiffReadNextDSP(
 	     */
 	    bytes_per_cycle = bytes_read;
 
-	    /* Increment play stack position. */
+	    /* Increment play stack position */
 	    ps_ptr->position += bytes_read;
 
 
-	    /* Copy read buffer segment to playstack DSP buffer. */
+	    /* Copy read buffer segment to playstack DSP buffer */
 	    if((afw_ptr->buffer != NULL) &&
 	       (bytes_read > 0)
 	    )
@@ -1287,7 +1284,7 @@ int YiffReadNextDSP(
 	}
 	else
 	{
-	    /* Play stack repeats more than once or infinatly. */
+	    /* Play stack repeats more than once or infinatly */
 
 	    int total_bytes_read;
 
@@ -1313,7 +1310,7 @@ int YiffReadNextDSP(
 		{
 		    ps_ptr->position = 0;
 
-		    /* Increment repeats. */
+		    /* Increment repeats */
 		    ps_ptr->repeats++;
 
 		    /* Repeats exceeded? */
@@ -1330,7 +1327,7 @@ int YiffReadNextDSP(
 		    }
 		}
 
-		/* Read next segment. */
+		/* Read next segment */
 		if(
 		    AFWLoadSegment(
 			afw_ptr,
@@ -1344,10 +1341,10 @@ int YiffReadNextDSP(
 		    break;
 		}
 
-		/* Get number of bytes read. */
+		/* Get number of bytes read */
 		bytes_read = MAX(afw_ptr->length, 0);
 
-		/* Copy segment of read buffer to tmp buffer. */
+		/* Copy segment of read buffer to tmp buffer */
 		if((afw_ptr->buffer != NULL) &&
 		   (bytes_read > 0)
 		)
@@ -1357,7 +1354,7 @@ int YiffReadNextDSP(
 			MIN(bytes_read, bytes_per_cycle - total_bytes_read)
 		    );
 
-		/* Increment positions. */
+		/* Increment positions */
 		total_bytes_read += bytes_read;
 		ps_ptr->position += bytes_read;
 	    }
@@ -1372,7 +1369,7 @@ int YiffReadNextDSP(
 	}
 
 
-	/* Shrink buffer if due to applied sample rate. */
+	/* Shrink buffer if due to applied sample rate */
 	if((bytes_per_cycle > actual_bytes_per_cycle) &&
 	   (ps_ptr->dsp_buf != NULL)
 	)
@@ -1380,14 +1377,14 @@ int YiffReadNextDSP(
 	    if(recorder->audio.sample_size == 16)
 		YiffShortenBuffer16(
 		    (u_int16_t *)ps_ptr->dsp_buf,
-		    ps_ptr->dsp_buf_len,	/* Buffer len (in u_int8_t). */
-		    actual_bytes_per_cycle	/* Shorten len (in u_int8_t). */
+		    ps_ptr->dsp_buf_len,	/* Buffer len (in u_int8_t) */
+		    actual_bytes_per_cycle	/* Shorten len (in u_int8_t) */
 		);
 	    else
 		YiffShortenBuffer8(
 		    (u_int8_t *)ps_ptr->dsp_buf,
-		    ps_ptr->dsp_buf_len,	/* Buffer len. */
-		    actual_bytes_per_cycle	/* Shorten len. */
+		    ps_ptr->dsp_buf_len,	/* Buffer len */
+		    actual_bytes_per_cycle	/* Shorten len */
 		);
 
 	    /* Need to reduce playstack's dsp buffer data length since
@@ -1446,7 +1443,7 @@ int YiffCreatePlaystack(
 	)
 	    return(-1);
 
-	/* Allocate new playstack. */
+	/* Allocate new playstack */
 	i = PlayStackAllocate();
 	ps_ptr = PlayStackGetPtr(i);
 	if(ps_ptr == NULL)
@@ -1483,7 +1480,7 @@ int YiffCreatePlaystack(
 	if(ps_ptr->applied_sample_rate < recorder->audio.sample_rate)
 	    ps_ptr->applied_sample_rate = recorder->audio.sample_rate;
 
-	/* Get bytes per cycle. */
+	/* Get bytes per cycle */
 	bytes_per_cycle = recorder->sound.buffer_length;
 	if(bytes_per_cycle <= 0)
 	{
@@ -1493,7 +1490,7 @@ int YiffCreatePlaystack(
 	    );
 	}
 
-	/* Open audio file. */
+	/* Open audio file */
 	if(AFWOpen(path, &ps_ptr->afw_data))
 	{
 	    /* Unable to open audio file, delete playstack and send
@@ -1515,19 +1512,19 @@ int YiffCreatePlaystack(
 	ps_ptr->block_length = ps_ptr->afw_data.block_length;
 
 
-	/* Check sound object's type. */
+	/* Check sound object's type */
 	if(ps_ptr->afw_data.sndobj_format == SndObjTypeDSP)
 	{
-	    /* DSP Sound Object. */  
+	    /* DSP Sound Object */  
 
-	    /* Read next play stack position. */
+	    /* Read next play stack position */
 	    YiffReadNextDSP(ps_ptr, bytes_per_cycle);
 	}
 	else if(ps_ptr->afw_data.sndobj_format == SndObjTypeMIDI)
 	{
-	    /* MIDI Sound Object. */
+	    /* MIDI Sound Object */
 
-	    /* Check if another playstack is playing this sound. */
+	    /* Check if another playstack is playing this sound */
 	    for(i = 0, ptr = playstack;
 		i < total_playstacks;
 		i++, ptr++
@@ -1539,24 +1536,24 @@ int YiffCreatePlaystack(
 		if((*ptr)->afw_data.sndobj_format != SndObjTypeMIDI)
 		    continue;
 
-		/* Skip this playstack. */
+		/* Skip this playstack */
 		if(*ptr == ps_ptr)
 		    continue;
 
-/* Let's let the AFW handle this and we respond properly to the AFW. */
+/* Let's let the AFW handle this and we respond properly to the AFW */
 	    }
 
-	    /* Begin playing MIDI. */
+	    /* Begin playing MIDI */
 	    AFWLoadSegment(
 		&ps_ptr->afw_data,
-		0,		/* Position n/a. */
-		0,		/* Length n/a. */
+		0,		/* Position n/a */
+		0,		/* Length n/a */
 		&recorder->audio
 	    );
 	}
 
 
-	/* Notify connection of successful create. */
+	/* Notify connection of successful create */
 	YNetSendSoundObjectPlay(
 	    ps_ptr->owner, ps_ptr->yid,
 	    ps_ptr->position, ps_ptr->data_length,
@@ -1578,16 +1575,16 @@ void YiffDestroyPlaystack(int n)
 	PlayStack *ps_ptr;
 
 
-	/* Check if playstack n is allocated. */
+	/* Check if playstack n is allocated */
 	if(PlayStackIsAllocated(n))
 	    ps_ptr = playstack[n];
 	else
 	    return;
 
-	/* Check if playstack owner connection is connected. */
+	/* Check if playstack owner connection is connected */
 	if(ConnectionIsConnected(ps_ptr->owner))
 	{
-	    /* Notify owner of this sound object being destroyed. */
+	    /* Notify owner of this sound object being destroyed */
 	    YNetSendSoundObjectKill(ps_ptr->owner, ps_ptr->yid);
 	}
 
@@ -1613,12 +1610,12 @@ void YiffManageSound(void)
 	    /* Record or play? */
 	    if(recorder->audio.direction == AUDIO_DIRECTION_RECORD)
 	    {
-		/* Record. */
+		/* Record */
 
 	    }
 	    else	/* AUDIO_DIRECTION_PLAY */
 	    {
-		/* Play. */
+		/* Play */
 		int i, status, bytes_per_cycle;
 		AFWDataStruct *afw_ptr;
 		PlayStack *ps_ptr;
@@ -1635,7 +1632,7 @@ void YiffManageSound(void)
 	        bytes_per_cycle = recorder->sound.buffer_length;
 	        tar_buf = recorder->sound.buffer;
 
-	        /* Manage each playstack. */
+	        /* Manage each playstack */
 	        for(i = 0; i < total_playstacks; i++)
 	        {
 		    ps_ptr = playstack[i];
@@ -1643,10 +1640,10 @@ void YiffManageSound(void)
 		        continue;
 
 		    afw_ptr = &ps_ptr->afw_data;
-		    /* Check sound object type. */
+		    /* Check sound object type */
 		    if(afw_ptr->sndobj_format == SndObjTypeDSP)
 		    {
-			/* DSP Sound Object. */
+			/* DSP Sound Object */
 
 		        /* Mix loaded DSP data on play stack to the 
 			 * Sound buffer (target buffer).
@@ -1668,7 +1665,7 @@ void YiffManageSound(void)
 		            );
 		        }
 
-			/* Read next play stack position. */
+			/* Read next play stack position */
 			status = YiffReadNextDSP(ps_ptr, bytes_per_cycle);
 			if(status == -1)
 			{
@@ -1679,7 +1676,7 @@ void YiffManageSound(void)
 		    }
 		    else if(afw_ptr->sndobj_format == SndObjTypeMIDI)
 		    {
-		        /* MIDI Sound Object. */
+		        /* MIDI Sound Object */
 
 			/*   Call AFWLoadSegment() for MIDI Sound Objects,
 			 *   this will check if it is still being played.
@@ -1691,25 +1688,25 @@ void YiffManageSound(void)
 			 */
 			status = AFWLoadSegment(
 			    afw_ptr,
-			    0,			/* Position n/a. */
-			    0,			/* Length n/a. */
+			    0,			/* Position n/a */
+			    0,			/* Length n/a */
 			    &recorder->audio
 			);
 			if(status == -1)
 			{
-			    /* General error, destroy it. */
+			    /* General error, destroy it */
 			    YiffDestroyPlaystack(i);
 			    continue;
 			}
 			else if(status == -2)
 			{
-			    /* Another play started, thus this one must stop. */
+			    /* Another play started, thus this one must stop */
 			    YiffDestroyPlaystack(i);
 			    continue;
 			}
 			else if(status == -3)
 			{
-			    /* Playback stopped normally, repeat as needed. */
+			    /* Playback stopped normally, repeat as needed */
 			    ps_ptr->repeats++;
 
 			    /* Repeats exceeded? */
@@ -1721,32 +1718,32 @@ void YiffManageSound(void)
 				continue;
 			    }
 
-			    /* Begin playing midi object again. */
+			    /* Begin playing midi object again */
 			    if(AFWLoadSegment(
 				afw_ptr,
-				0,	/* Position n/a. */
-				0,	/* Length n/a. */
+				0,	/* Position n/a */
+				0,	/* Length n/a */
 				&recorder->audio
 			    ))
 			    {
-				/* Definate error in playing MIDI object. */
+				/* Definate error in playing MIDI object */
 				YiffDestroyPlaystack(i);
 				continue;
 			    }
 			}
 			else
 			{
-			    /* Still playing MIDI object, do nothing. */
+			    /* Still playing MIDI object, do nothing */
 			}
 
 		    }
 		    else
 		    {
-			/* Unsupported sound object type. */
+			/* Unsupported sound object type */
 		    }
 		}
 
-		/* Shift target buffer from being signed 8 to unsigned 8. */
+		/* Shift target buffer from being signed 8 to unsigned 8 */
 	        for(i = 0, tmp_ptr = tar_buf;
 		    i < bytes_per_cycle;
 		    i++
@@ -1779,7 +1776,7 @@ void YiffUpdateTimers(void)
 	{
 	    if(recorder != NULL)
 	    {
-	        /* Get audio cycle in microseconds. */
+	        /* Get audio cycle in microseconds */
 		audio_cycle_us = (recorder->audio.compensated_cycle.ms *
 		    1000) + recorder->audio.compensated_cycle.us;
 
@@ -1800,13 +1797,13 @@ void YiffUpdateTimers(void)
 		    ((cur_time.ms * 1000) + cur_time.us)) - cycle_ahead_us
 		    - 100;
 
-		/* Sanitize. */
+		/* Sanitize */
 		if(next_sound_delta_us > audio_cycle_us)
 		    next_sound_delta_us = audio_cycle_us;
 		if(next_sound_delta_us < MIN_NEXT_SOUND_DELTA)
 		    next_sound_delta_us = MIN_NEXT_SOUND_DELTA;
 
-		/* Stats: calculate cycle_load. */
+		/* Stats: calculate cycle_load */
 		if(audio_cycle_us != 0)
 		    ystats.cycle_load = (double)(audio_cycle_us -
 		        next_sound_delta_us) /
@@ -1820,7 +1817,7 @@ if(cycle_ahead_us > 0)
 	);
  */
 
-		/* Decrease cycle_ahead_left as needed. */
+		/* Decrease cycle_ahead_left as needed */
 		cycle_ahead_us = MAX(cycle_ahead_us -
 		    ((recorder->audio.compensated_cycle.ms * 1000) +
 			recorder->audio.compensated_cycle.us),
@@ -1848,12 +1845,12 @@ fprintf(stderr, "===> %ld (%ld %ld) us\n",
 		 */
 		next_sound_delta_us = 8000;
 
-		/* Status: calculate cycle_load. */
+		/* Status: calculate cycle_load */
 		ystats.cycle_load = 0.00;
 	    }
 
 
-	    /* Update cur_time as usual. */
+	    /* Update cur_time as usual */
 	    cur_time.ms = new_millitime.ms;
 	    cur_time.us = new_millitime.us;
 	}
@@ -1868,18 +1865,18 @@ fprintf(stderr, "===> %ld (%ld %ld) us\n",
  */
 void YiffResetTimers(void)
 {
-	/* Directly get current time (for syncing audio device). */
+	/* Directly get current time (for syncing audio device) */
 	GetCurrentTime(&cur_time);
 
-	/* Reset next schedual timers. */
+	/* Reset next schedual timers */
 	next.refresh.ms = 0;
 	next.refresh.us = 0;
 
 
-	/* Sync audio device. */
+	/* Sync audio device */
 	YSoundSync(recorder, 0);
 
-	/* How long to sleep before handling sound again (use min). */
+	/* How long to sleep before handling sound again (use min) */
 	next_sound_delta_us = MIN_NEXT_SOUND_DELTA;
 
 
@@ -1895,7 +1892,7 @@ int main(int argc, char *argv[])
 
 	runlevel = 1;
 
-	/* Initialize everything. */
+	/* Initialize everything */
 	status = YiffInit(argc, argv);
 	switch(status)
 	{
@@ -1947,30 +1944,30 @@ int main(int argc, char *argv[])
 	runlevel = 2;
 	while(runlevel > 1)
 	{
-	    /* Get new time just after usleep(). */
+	    /* Get new time just after usleep() */
 	    GetCurrentTime(&cur_time);
 
 
-	    /* Manage sound. */
+	    /* Manage sound */
 	    YiffManageSound();
 
-	    /* Manage connections. */
+	    /* Manage connections */
 	    YiffManageConnections();
 
 
 	    /* Time to refresh resources? */
 	    if(next.refresh.ms < cur_time.ms)
 	    {
-		/* Refresh resources. */
+		/* Refresh resources */
 		if(recorder != NULL)
 		{
-		    /* Sync audio device. */
+		    /* Sync audio device */
 		    YSoundSync(recorder, 0);
 		}
 		next.refresh.ms = cur_time.ms + option.refresh_int.ms;
 	    }
 
-	    /* Update timings. */
+	    /* Update timings */
 	    YiffUpdateTimers();  
 
 	    /* Sleep for a calculated amount of time, this time is
@@ -1979,7 +1976,7 @@ int main(int argc, char *argv[])
 	    usleep(next_sound_delta_us);
 	}
 
-	/* Shutdown everything. */
+	/* Shutdown everything */
 	YiffShutdown();
 
 	runlevel = 0;
