@@ -18,7 +18,14 @@ int MidiIsFileMidi(const char *filename);
 int MidiRead(const char *filename, FILE *fp, MidiDataStruct *md);
 void MidiDestroy(MidiDataStruct *md);
 
-/*
+
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
+#if 0
 void swap32(int32_t *i)
 {
 	int32_t tmp;
@@ -35,39 +42,27 @@ void swap32(int32_t *i)
 	tar[2] = src[1];
 	tar[1] = src[2];
 	tar[0] = src[3];
-
-	return;
 }
-*/
-
+#endif
 
 void swapu32(u_int32_t *i)
 {
-        u_int32_t tmp;
-        u_int8_t *src, *tar;
+	u_int32_t tmp = *i;
+	u_int8_t *src = (u_int8_t *)&tmp,
+		 *tar = (u_int8_t *)i;
 
-        if(i == NULL)
-            return;
-
-        tmp = *i;
-        src = (u_int8_t *)&tmp;
-        tar = (u_int8_t *)i;
-
-        tar[3] = src[0];
-        tar[2] = src[1];
-        tar[1] = src[2];
-        tar[0] = src[3];
-
-        return;
+	tar[3] = src[0];
+	tar[2] = src[1];
+	tar[1] = src[2];
+	tar[0] = src[3];
 }
 
-
+#if 0
 /*
  *	Reads variable-length number from FILE pointer fp,
  *	fp will be incremented to the point just after the bytes
  *	making up the variable-length number.
  */
-/*
 int MidiFGetVarlenNumber(FILE *fp)
 {
 	int c, p = 0, val = 0;
@@ -89,34 +84,33 @@ int MidiFGetVarlenNumber(FILE *fp)
 
 	return(val);
 }
- */
+#endif
 
+#if 0
 /*
  *      Reads variable-length number from buffer pointer buf.
  *	Will not read more than max bytes.
  */
-/*
 int MidiGetVarlenNumber(const char *buf, int max)
 {
-        int p = 0, val = 0;
+	int p = 0, val = 0;
 
 
-        if(buf == NULL)
-            return(0);
+	if(buf == NULL)
+	    return(0);
  
-        do
-        {
-            val += (((u_int8_t)*buf & 0x7f) << (p * 8));
+	do
+	{
+	    val += (((u_int8_t)*buf & 0x7f) << (p * 8));
 
-            buf++;
-            p++;
-        }
-        while(((u_int8_t)*buf & 0x80) && (p <= max));
+	    buf++;
+	    p++;
+	}
+	while(((u_int8_t)*buf & 0x80) && (p <= max));
 
-
-        return(val);
+	return(val);
 }
- */
+#endif
 
 /*
  *	Returns MidiSuccess if filename is a MIDI file or
@@ -134,14 +128,14 @@ int MidiIsFileMidi(const char *filename)
 	    return(MidiBadValue);
 
 
-        /* Check if file exists. */
-        if(stat(filename, &stat_buf))
-            return(MidiBadValue);
+	/* Check if file exists. */
+	if(stat(filename, &stat_buf))
+	    return(MidiBadValue);
 
-        /* Open file. */
-        fp = fopen(filename, "rb");
-        if(fp == NULL)
-            return(MidiBadValue);
+	/* Open file. */
+	fp = fopen(filename, "rb");
+	if(fp == NULL)
+	    return(MidiBadValue);
 
 
 	/* Read first few bytes. */
@@ -157,11 +151,11 @@ int MidiIsFileMidi(const char *filename)
 	chunk_type_name[MidiChunkTypeNameLen] = '\0';
 
 	/* Close file. */
-        fclose(fp);
-        
+	fclose(fp);
+	
 
 	if(!strcmp(chunk_type_name, MidiChunkTypeNameHeader) ||
-           !strcmp(chunk_type_name, MidiChunkTypeNameTrack)
+	   !strcmp(chunk_type_name, MidiChunkTypeNameTrack)
 	)
 	    return(MidiSuccess);
 	else
@@ -189,56 +183,55 @@ int MidiRead(const char *filename, FILE *fp, MidiDataStruct *md)
 
 	char chunk_type_name[MidiChunkTypeNameLen + 1];
 	u_int32_t chunk_len;
-	MidiChunkStruct *chunk_ptr;
+	MidiChunkStruct *chunk;
 
 	u_int8_t *buf_ptr;
 	int buf_len;
 
 
-	/* Error checks. */
 	if(md == NULL)
 	    return(MidiNoBuffers);
 	if(fp == NULL)
 	    return(MidiNoAccess);
 
-        /* Rewind fp to beginning of midi file. */
-        rewind(fp);
+	/* Rewind fp to beginning of midi file. */
+	rewind(fp);
 
 
 	/* Reset values. */
 	memset(md, 0x00, sizeof(MidiDataStruct));
 
-        /* Get size of file. */
-        if(fstat(fileno(fp), &stat_buf))
-            return(MidiNoAccess);
+	/* Get size of file. */
+	if(fstat(fileno(fp), &stat_buf))
+	    return(MidiNoAccess);
 
-        filesize = stat_buf.st_size;
-        if(filesize == 0)
-            return(MidiNoAccess);
+	filesize = stat_buf.st_size;
+	if(filesize == 0)
+	    return(MidiErrorNotMidi);
 
 
 	/* Check if this is a midi file by reading the first few bytes. */
-        (*chunk_type_name) = '\0';
-        for(i = 0; i < MidiChunkTypeNameLen; i++)
-        {
-            c = fgetc(fp);
-            if(c == EOF)
-                break;
+	*chunk_type_name = '\0';
+	for(i = 0; i < MidiChunkTypeNameLen; i++)
+	{
+	    c = fgetc(fp);
+	    if(c == EOF)
+		break;
 
-            chunk_type_name[i] = (char)c;
-        }
-        chunk_type_name[MidiChunkTypeNameLen] = '\0';
-        if(strcmp(chunk_type_name, MidiChunkTypeNameHeader) &&
-           strcmp(chunk_type_name, MidiChunkTypeNameTrack)
-        )
-            return(MidiErrorNotMidi);
+	    chunk_type_name[i] = (char)c;
+	}
+	chunk_type_name[MidiChunkTypeNameLen] = '\0';
+	if(strcmp(chunk_type_name, MidiChunkTypeNameHeader) &&
+	   strcmp(chunk_type_name, MidiChunkTypeNameTrack)
+	)
+	    return(MidiErrorNotMidi);
 
 
-        /* Begin reading midi file header. */
+	/* Begin reading midi file header. */
 
-        /* Record file name. */
-        if(filename != NULL)
-            md->filename = strdup(filename);
+	/* Record file name. */
+	if(filename != NULL)
+	    md->filename = strdup(filename);
 
 
 	/* Read each chunk in the file. */
@@ -252,10 +245,10 @@ int MidiRead(const char *filename, FILE *fp, MidiDataStruct *md)
 	    for(i = 0; i < MidiChunkTypeNameLen; i++)
 	    {
 		c = fgetc(fp);
-                if(c == EOF)
+		if(c == EOF)
 		{
 		    need_break = 1;
-                    break;
+		    break;
 		}
 
 		chunk_type_name[i] = (char)c;
@@ -268,21 +261,20 @@ int MidiRead(const char *filename, FILE *fp, MidiDataStruct *md)
 	    fread(&chunk_len, sizeof(u_int32_t), 1, fp);
 	    swapu32(&chunk_len);
 
-	    /* Chunk length on file does not include chunk type and
-             * length bytes so add + 8 to it.
+	    /* Chunk length specified in the file data does not include
+	     * chunk type and length bytes so add 8 to chunk_len.
 	     */
-	    chunk_len += (MidiChunkTypeNameLen + sizeof(u_int32_t));
-
+	    chunk_len += (MidiChunkTypeNameLen + sizeof(u_int32_t)); 
 
 	    /* Allocate raw data buffer and read raw chunk data into it. */
 	    buf_len = (int)chunk_len - 8;
 	    if(buf_len > 0)
 	    {
 	        buf_ptr = (u_int8_t *)malloc(buf_len * sizeof(u_int8_t));
-		if(buf_ptr == NULL)
+		if(buf_ptr != NULL)
+		    fread(buf_ptr, sizeof(u_int8_t), buf_len, fp);
+		else
 		    break;
-
-		fread(buf_ptr, sizeof(u_int8_t), buf_len, fp);
 	    }
 	    else
 	    {
@@ -293,7 +285,7 @@ int MidiRead(const char *filename, FILE *fp, MidiDataStruct *md)
 
 	    /* Allocate a new chunk structure. */
 	    i = md->total_chunks;
-	    md->total_chunks += 1;
+	    md->total_chunks++;
 	    md->chunk = (MidiChunkStruct **)realloc(
 		md->chunk,
 		md->total_chunks * sizeof(MidiChunkStruct *)
@@ -301,19 +293,16 @@ int MidiRead(const char *filename, FILE *fp, MidiDataStruct *md)
 	    if(md->chunk == NULL)
 	    {
 		md->total_chunks = 0;
-		continue;
+		break;
 	    }
-
-	    md->chunk[i] = (MidiChunkStruct *)calloc(
-		1,
-		sizeof(MidiChunkStruct)
+	    md->chunk[i] = chunk = (MidiChunkStruct *)calloc(
+		1, sizeof(MidiChunkStruct)
 	    );
-	    if(md->chunk[i] == NULL)
+	    if(chunk == NULL)
 	    {
 		md->total_chunks -= 1;
-		continue;
+		break;
 	    }
-	    chunk_ptr = md->chunk[i];
 
 
 
@@ -321,58 +310,60 @@ int MidiRead(const char *filename, FILE *fp, MidiDataStruct *md)
 
 	    /* Chunk type. */
 	    if(!strcmp(chunk_type_name, MidiChunkTypeNameHeader))
-		chunk_ptr->type = MidiChunkTypeHeader;
+		chunk->type = MidiChunkTypeHeader;
 	    else if(!strcmp(chunk_type_name, MidiChunkTypeNameTrack))
-		chunk_ptr->type = MidiChunkTypeTrack;
+		chunk->type = MidiChunkTypeTrack;
 	    else
-		chunk_ptr->type = MidiChunkTypeUnknown;
+		chunk->type = MidiChunkTypeUnknown;
 
 	    /* Chunk length. */
-	    chunk_ptr->len = chunk_len;
+	    chunk->len = chunk_len;
 
-	    /* Raw data buffer and length of it. */
-	    chunk_ptr->buf_len = buf_len;
-	    chunk_ptr->buf = buf_ptr;
+	    /* Raw data buffer and length of it (might be NULL). */
+	    chunk->buf_len = buf_len;
+	    chunk->buf = buf_ptr;
 
 
-
-	    /* If header chunk, parse raw data. */
-	    if(chunk_ptr->type == MidiChunkTypeHeader)
+	    /* Parse by chunk type. */
+	    /* Header chunk. */
+	    if(chunk->type == MidiChunkTypeHeader)
 	    {
 		if(buf_len >= 6)
 		{
+		    /* Update the header information. */
 		    md->format = (int16_t)(
-                        ((u_int16_t)buf_ptr[0] << 8) +
+			((u_int16_t)buf_ptr[0] << 8) +
 			(u_int16_t)buf_ptr[1]
 		    );
 
-                    md->tracks = (int16_t)(
-                        ((u_int16_t)buf_ptr[2] << 8) +
-                        (u_int16_t)buf_ptr[3]  
-                    );
+		    md->tracks = (int16_t)(
+			((u_int16_t)buf_ptr[2] << 8) +
+			(u_int16_t)buf_ptr[3]  
+		    );
 
-                    md->divisions = (int16_t)(
-                        ((u_int16_t)buf_ptr[4] << 8) +
-                        (u_int16_t)buf_ptr[5]
-                    );
+		    md->divisions = (int16_t)(
+			((u_int16_t)buf_ptr[4] << 8) +
+			(u_int16_t)buf_ptr[5]
+		    );
 		}
 	    }
+	    /* Track chunk. */
+	    else if(chunk->type == MidiChunkTypeTrack)
+	    {
 
+/* TODO */
 
-
-
-
+	    }
 
 
 	    /* Increment file position. */
 	    filepos += chunk_len;
-	    i = fseek(fp, filepos, SEEK_SET);
-	    if(i == -1)
+	    if(fseek(fp, filepos, SEEK_SET) == -1)
 		break;
 	}
 
 
-        /* Close file since we are returning MidiSuccess and the calling
+	/* Close file since we are returning MidiSuccess and the calling
 	 * function will not referance the given fp again.
 	 */
 /* Note, later on if we are reading the midi file, we should record
@@ -389,8 +380,7 @@ int MidiRead(const char *filename, FILE *fp, MidiDataStruct *md)
 void MidiDestroy(MidiDataStruct *md)
 {
 	int i, n;
-	MidiChunkStruct **chunk_ptr;
-	MidiEventStruct **event_ptr;
+	MidiChunkStruct *chunk;
 
 
 	if(md == NULL)
@@ -401,34 +391,25 @@ void MidiDestroy(MidiDataStruct *md)
 
 
 	/* Free each chunk. */
-	for(i = 0, chunk_ptr = md->chunk;
-            i < md->total_chunks;
-            i++, chunk_ptr++
-	)
+	for(i = 0; i < md->total_chunks; i++)
 	{
-	    if(*chunk_ptr == NULL)
+	    chunk = md->chunk[i];
+	    if(chunk == NULL)
 		continue;
 
 	    /* Free each event in the chunk. */
-	    for(n = 0, event_ptr = (*chunk_ptr)->event;
-                n < (*chunk_ptr)->total_events;
-                n++, event_ptr++
-	    )
-		free(*event_ptr);
-	    free((*chunk_ptr)->event);
+	    for(n = 0; n < chunk->total_events; n++)
+		free(chunk->event[n]);
+	    free(chunk->event);
 
 	    /* Free raw data buffer. */
-	    free((*chunk_ptr)->buf);
+	    free(chunk->buf);
 
 	    /* Free structure itself. */
-	    free(*chunk_ptr);
+	    free(chunk);
 	}
 
 	free(md->chunk);
 	md->chunk = NULL;
-
 	md->total_chunks = 0;
-
-
-	return;
 }
