@@ -1,10 +1,7 @@
 #ifndef MIDI_H
 #define MIDI_H
 
-#include <stdio.h>
 #include <sys/types.h>
-#include <sys/stat.h>
-
 
 /*
  *	Midi return error codes:
@@ -43,7 +40,7 @@
  */
 typedef struct {
 
-        int type;       /* One of MidiEventType*. */
+	int type;       /* One of MidiEventType*. */
 	int dtime;	/* Delta time. */
 
 } MidiEventStruct;
