@@ -28,6 +28,12 @@ pid_t MIDIIOWIsPlaying(MIDIAudio *midi_audio);
 void MIDIIOWShutdown(MIDIAudio *midi_audio);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Midi Play ID, for use with keeping track of the midi play
  *	process using the standard forking of the midi playing program
@@ -52,20 +58,20 @@ int MIDIIOWProcessExist(pid_t pid);
 #if !defined(HAVE_LIBKMID)
 int MIDIIOWProcessExist(pid_t pid)
 {
-        struct sched_param sp;
+	struct sched_param sp;
 
 
-        /* Cannot be 0 (because it means itself to sched_getparam()). */
-        if(pid == 0)
-            return(0);
+	/* Cannot be 0 (because it means itself to sched_getparam()). */
+	if(pid == 0)
+	    return(0);
 
-        if(sched_getparam(
-            pid,
-            &sp
-        ) == 0)
-            return(1);
-        else
-            return(0);
+	if(sched_getparam(
+	    pid,
+	    &sp
+	) == 0)
+	    return(1);
+	else
+	    return(0);
 }
 #endif  /* !defined(HAVE_LIBKMID) */
 
@@ -109,11 +115,11 @@ int MIDIIOWInit(MIDIAudio *midi_audio)
 
 #else	/* HAVE_LIBKMID */
 
-        /* Set lib data pointer to 1 just so that it's not
-         * checked to be NULL by other functions that use this
-         * value to determine if the library is initialized or not.
-         */
-        midi_audio->ptr = (void *)1;
+	/* Set lib data pointer to 1 just so that it's not
+	 * checked to be NULL by other functions that use this
+	 * value to determine if the library is initialized or not.
+	 */
+	midi_audio->ptr = (void *)1;
 
 #endif
 
@@ -132,8 +138,8 @@ pid_t MIDIIOWPlay(MIDIAudio *midi_audio, const char *path)
 	if(path == NULL)
 	    return(0);
 
-        if(midi_audio == NULL)
-            return(0);
+	if(midi_audio == NULL)
+	    return(0);
 
 #ifdef HAVE_LIBKMID
 
@@ -170,16 +176,16 @@ pid_t MIDIIOWPlay(MIDIAudio *midi_audio, const char *path)
 
 	    /* Allocate and format play command. */
 	    len = strlen(path) +
-                strlen(option.midi_play_cmd) + 256;
-            cmd = (char *)malloc((len + 1) * sizeof(char));
-            if(cmd == NULL)
+		strlen(option.midi_play_cmd) + 256;
+	    cmd = (char *)malloc((len + 1) * sizeof(char));
+	    if(cmd == NULL)
 		return(0);
 
 	    strcpy(cmd, option.midi_play_cmd);
-            substr(cmd, "%f", path);
+	    substr(cmd, "%f", path);
 
-            /* Execute command and record midi play pid. */
-            midi_play_pid = Exec(cmd);
+	    /* Execute command and record midi play pid. */
+	    midi_play_pid = Exec(cmd);
 	    if(midi_play_pid == 0)
 		return(0);
 
@@ -188,10 +194,10 @@ pid_t MIDIIOWPlay(MIDIAudio *midi_audio, const char *path)
 
 	    return(midi_play_pid);
 	}
-        else
-        {
-            return(0);
-        }
+	else
+	{
+	    return(0);
+	}
 
 #endif
 }
@@ -202,12 +208,12 @@ pid_t MIDIIOWPlay(MIDIAudio *midi_audio, const char *path)
 void MIDIIOWStop(MIDIAudio *midi_audio)
 {
        if(midi_audio == NULL)
-            return;
+	    return;
 
 #ifdef HAVE_LIBKMID
 
-        if(midi_audio->ptr != NULL)
-        {
+	if(midi_audio->ptr != NULL)
+	{
 	    /* Stop if currently playing. */
 	    kMidStop();
 	}
@@ -220,8 +226,8 @@ void MIDIIOWStop(MIDIAudio *midi_audio)
 	    if(midi_play_pid > 0)
 		kill(midi_play_pid, SIGINT);
 
-            /* Reset midi_play_pid. */
-            midi_play_pid = 0;
+	    /* Reset midi_play_pid. */
+	    midi_play_pid = 0;
 	}
 
 #endif
@@ -236,12 +242,12 @@ void MIDIIOWStop(MIDIAudio *midi_audio)
 pid_t MIDIIOWIsPlaying(MIDIAudio *midi_audio)
 {
        if(midi_audio == NULL)
-            return(0);
+	    return(0);
 
 #ifdef HAVE_LIBKMID
 
-        if(midi_audio->ptr != NULL)
-        {
+	if(midi_audio->ptr != NULL)
+	{
 	    int status = kMidIsPlaying();
 
 	    if(status)
@@ -257,24 +263,24 @@ pid_t MIDIIOWIsPlaying(MIDIAudio *midi_audio)
 #else   /* HAVE_LIBKMID */
 
 	if(midi_audio->ptr != NULL)
-        {
-            /*   Check if the midi play process is still running.
-             *   This will set midi_play_pid to 0 if the midi play
-             *   process no longer exists or leave midi_play_pid as
-             *   is if the midi play process is still active.
-             */
-            if(midi_play_pid > 0)
-            {
-                if(!MIDIIOWProcessExist(midi_play_pid))
-                    midi_play_pid = 0;
-            }
+	{
+	    /*   Check if the midi play process is still running.
+	     *   This will set midi_play_pid to 0 if the midi play
+	     *   process no longer exists or leave midi_play_pid as
+	     *   is if the midi play process is still active.
+	     */
+	    if(midi_play_pid > 0)
+	    {
+		if(!MIDIIOWProcessExist(midi_play_pid))
+		    midi_play_pid = 0;
+	    }
 
 	    return(midi_play_pid);
 	}
 	else
-        {
-            return(0);
-        }
+	{
+	    return(0);
+	}
 
 #endif
 }
@@ -291,7 +297,7 @@ void MIDIIOWShutdown(MIDIAudio *midi_audio)
 
 #ifdef HAVE_LIBKMID
 
-        if(midi_audio->ptr != NULL)
+	if(midi_audio->ptr != NULL)
 	{
 	    /* Stop any midi's still playing. */
 	    if(MIDIIOWIsPlaying(midi_audio))
@@ -311,21 +317,21 @@ void MIDIIOWShutdown(MIDIAudio *midi_audio)
 
 #else	/* HAVE_LIBKMID */
 
-        if(midi_audio->ptr != NULL)
-        {
+	if(midi_audio->ptr != NULL)
+	{
 	    /* Stop any midi's still playing. */
 	    if(midi_play_pid > 0)
 		MIDIIOWStop(midi_audio);
 
-            /* Reset midi_play_pid (though MIDIIOWStop() probably
+	    /* Reset midi_play_pid (though MIDIIOWStop() probably
 	     * already reset it).
 	     */
-            midi_play_pid = 0;
+	    midi_play_pid = 0;
 
 	    /* Reset pointer to external resources (never
-             * allcoated).
-             */
-            midi_audio->ptr = NULL;
+	     * allcoated).
+	     */
+	    midi_audio->ptr = NULL;
 	}
 
 #endif
