@@ -44,15 +44,21 @@ int MixerRCLoadFromFile(const char *filename, Recorder *recorder);
 int MixerRCSaveToFile(const char *filename, Recorder *recorder);
 
 
-#define MIN(a,b)        ((a) < (b) ? (a) : (b))
-#define MAX(a,b)        ((a) > (b) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
-
-
 extern int YAntiShift(int in);	/* In main.c */
 
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : 1)
+
+
 /*
  *	Loads configuration.
  *
@@ -75,7 +81,7 @@ int RCLoadFromFile(const char *filename)
 	SoundPath *sp_ptr;
 
 
-	/* Check if file exists. */
+	/* Check if file exists */
 	if(filename == NULL)
 	    return(-1);
 	if(stat(filename, &stat_buf))
@@ -84,7 +90,7 @@ int RCLoadFromFile(const char *filename)
 	    return(-1);
 	}
 
-	/* Open YIFF Sound Server configuration file. */
+	/* Open YIFF Sound Server configuration file */
 	fp = FOpen(filename, "rb");
 	if(fp == NULL)
 	{
@@ -97,10 +103,10 @@ int RCLoadFromFile(const char *filename)
 	 * contents of the configuration file to be loaded.
 	 */
 
-	/* Y Audio Modes. */	
+	/* Y Audio Modes */	
 	YModeDeleteAll();
 
-	/* Y Sound Paths. */
+	/* Y Sound Paths */
 	SoundPathDeleteAll();
 
 
@@ -111,29 +117,29 @@ int RCLoadFromFile(const char *filename)
  */
 #define DO_READ_LINE    \
 { \
- /* Free previous line and allocate/read next line. */ \
+ /* Free previous line and allocate/read next line */ \
  free(strptr); \
  strptr = FReadNextLineAlloc(fp, UNIXCFG_COMMENT_CHAR); \
  if(strptr == NULL) \
   break; \
  lines_read++; \
  \
- /* Fetch parameter. */ \
+ /* Fetch parameter */ \
  strptr2 = StringCfgParseParm(strptr); \
  if(strptr2 == NULL) \
   continue; \
  strncpy(parm, strptr2, CFG_PARAMETER_MAX); \
  parm[CFG_PARAMETER_MAX - 1] = '\0'; \
  \
- /* Fetch value. */ \
+ /* Fetch value */ \
  strptr2 = StringCfgParseValue(strptr); \
  if(strptr2 == NULL) \
-  strptr2 = "0";  /* Set it to "0" if NULL. */ \
+  strptr2 = "0";  /* Set it to "0" if NULL */ \
  strncpy(val, strptr2, CFG_VALUE_MAX); \
  val[CFG_VALUE_MAX - 1] = '\0'; \
 }
 
-	/* Begin reading file. */
+	/* Begin reading file */
 	strptr = NULL;
 	while(1)
 	{
@@ -150,18 +156,18 @@ int RCLoadFromFile(const char *filename)
 
 	    }
 
-	    /* Listening port number. */
+	    /* Listening port number */
 	    else if(!strcasecmp(parm, "Port"))
 	    {
 		option.port = atoi(val);
 	    }
-	    /* Refresh interval. */
+	    /* Refresh interval */
 	    else if(!strcasecmp(parm, "RefreshInterval"))
 	    {
 		option.refresh_int.ms = atol(val) / 1000;
 		option.refresh_int.us = atol(val) % 1000;
 	    }
-	    /* DSP device. */
+	    /* DSP device */
 	    else if(!strcasecmp(parm, "DSPDevice") ||
 		    !strcasecmp(parm, "Device")
 	    )
@@ -181,7 +187,7 @@ int RCLoadFromFile(const char *filename)
 		    );
 		}
 	    }
-	    /* Mixer device. */
+	    /* Mixer device */
 	    else if(!strcasecmp(parm, "MixerDevice") ||
 		    !strcasecmp(parm, "Mixer")
 	    )
@@ -202,17 +208,17 @@ int RCLoadFromFile(const char *filename)
 			);
 		}
 	    }
-	    /* MIDI player command. */
+	    /* MIDI player command */
 	    else if(!strcasecmp(parm, "MIDIPlayCommand"))
 	    {
 		free(option.midi_play_cmd);
 		option.midi_play_cmd = strdup(val);
 	    }
-	    /* ALSA MIDI device port. */
+	    /* ALSA MIDI device port */
 	    else if(!strcasecmp(parm, "MIDIDevicePort"))
 	    {
 #ifdef ALSA_RUN_CONFORM
-		/* If -1 then implies it is not set. */
+		/* If -1 then implies it is not set */
 		if(option.midi_device_number < 0)
 		{
 		    /* Was not previously set, so set it with the
@@ -244,7 +250,7 @@ int RCLoadFromFile(const char *filename)
 		    if(!strcasecmp(parm, "Name"))
 		    {
 			free(ymode_ptr->name);
-			ymode_ptr->name = StringCopyAlloc(val);
+			ymode_ptr->name = STRDUP(val);
 		    }
 		    /* Cycle */
 		    else if(!strcasecmp(parm, "Cycle"))
@@ -327,7 +333,7 @@ int RCLoadFromFile(const char *filename)
 			break;
 		    }
 
-		    /* Unknown parameter. */
+		    /* Unknown parameter */
 		    else
 		    { 
 			fprintf(stderr,
@@ -361,7 +367,7 @@ int RCLoadFromFile(const char *filename)
 		    if(!strcasecmp(parm, "Path"))
 		    {
 			free(sp_ptr->path);
-			sp_ptr->path = StringCopyAlloc(val);
+			sp_ptr->path = STRDUP(val);
 		    }
 		    /* EndYSoundPath */
 		    else if(!strcasecmp(parm, "EndYSoundPath") ||
@@ -370,7 +376,7 @@ int RCLoadFromFile(const char *filename)
 		    {
 			break;
 		    }
-		    /* Unknown parameter. */  
+		    /* Unknown parameter */  
 		    else
 		    {
 			fprintf(stderr,
@@ -384,7 +390,7 @@ int RCLoadFromFile(const char *filename)
 		}
 	    }
 
-	    /* Unknown parameter. */
+	    /* Unknown parameter */
 	    else
 	    {
 		fprintf(stderr, "%s: Line %i: Unknown parameter: %s\n",
@@ -397,7 +403,7 @@ int RCLoadFromFile(const char *filename)
 
 #undef DO_READ_LINE
 
-	/* Close the file. */
+	/* Close the file */
 	FClose(fp);
 
 
@@ -414,13 +420,13 @@ static void RCMixerParseMixerValueString(
 	Coefficient *value3, Coefficient *value4
 )
 {
-	/* Seek past spaces and get value 1. */
+	/* Seek past spaces and get value 1 */
 	while(ISBLANK(*s))
 	    s++;
 	if(value1 != NULL)
 	    *value1 = atof(s);
 
-	/* Seek to and get value 2. */
+	/* Seek to and get value 2 */
 	while(!ISBLANK(*s) && (*s != '\0'))
 	    s++;
 	while(ISBLANK(*s))
@@ -428,7 +434,7 @@ static void RCMixerParseMixerValueString(
 	if(value2 != NULL)
 	    *value2 = atof(s);
 
-	/* Seek to and get value 3. */
+	/* Seek to and get value 3 */
 	while(!ISBLANK(*s) && (*s != '\0'))
 	    s++;
 	while(ISBLANK(*s))
@@ -436,7 +442,7 @@ static void RCMixerParseMixerValueString(
 	if(value3 != NULL)
 	    *value3 = atof(s);
 
-	/* Seek to and get value 4. */
+	/* Seek to and get value 4 */
 	while(!ISBLANK(*s) && (*s != '\0'))
 	    s++;
 	while(ISBLANK(*s))
@@ -499,10 +505,10 @@ static mixer_device_fdata_struct **MixerRCLoadAllFromFile(
 	if(stat(filename, &stat_buf))
 	    return(NULL);
 
-	/* Reset total. */
+	/* Reset total */
 	(*total) = 0;
 
-	/* Open mixer device file for reading. */
+	/* Open mixer device file for reading */
 	fp = FOpen(filename, "rb");
 	if(fp == NULL)
 	    return(NULL);
@@ -514,29 +520,29 @@ static mixer_device_fdata_struct **MixerRCLoadAllFromFile(
  */
 #define DO_READ_LINE	\
 { \
- /* Free previous line and allocate/read next line. */ \
+ /* Free previous line and allocate/read next line */ \
  free(strptr); \
  strptr = FReadNextLineAlloc(fp, UNIXCFG_COMMENT_CHAR); \
  if(strptr == NULL) \
   break; \
  lines_read++; \
  \
- /* Fetch parameter. */ \
+ /* Fetch parameter */ \
  strptr2 = StringCfgParseParm(strptr); \
  if(strptr2 == NULL) \
   continue; \
  strncpy(parm, strptr2, CFG_PARAMETER_MAX); \
  parm[CFG_PARAMETER_MAX - 1] = '\0'; \
  \
- /* Fetch value. */ \
+ /* Fetch value */ \
  strptr2 = StringCfgParseValue(strptr); \
  if(strptr2 == NULL) \
-  strptr2 = "0";  /* Set it to "0" if NULL. */ \
+  strptr2 = "0";  /* Set it to "0" if NULL */ \
  strncpy(val, strptr2, CFG_VALUE_MAX); \
  val[CFG_VALUE_MAX - 1] = '\0'; \
 }
 
-	/* Begin reading file. */
+	/* Begin reading file */
 	strptr = NULL;
 	while(1)
 	{
@@ -545,7 +551,7 @@ static mixer_device_fdata_struct **MixerRCLoadAllFromFile(
 	    /* BeginMixer */
 	    if(!strcasecmp(parm, "BeginMixer"))
 	    {
-		/* Allocate a new mixer device structure. */
+		/* Allocate a new mixer device structure */
 		i = (*total);
 		(*total) = i + 1;
 		ptr = (mixer_device_fdata_struct **)realloc(
@@ -569,15 +575,15 @@ static mixer_device_fdata_struct **MixerRCLoadAllFromFile(
 		}
 		mdfd_ptr = ptr[i];
 
-		/* Record mixer device's name. */
-		mdfd_ptr->name = StringCopyAlloc(val);
+		/* Record mixer device's name */
+		mdfd_ptr->name = STRDUP(val);
 
 
 		while(1)
 		{
 		    DO_READ_LINE
 
-		    /* Go through mixer device channel names. */  
+		    /* Go through mixer device channel names */  
 		    for(n = 0; n < YTotalMixers; n++)
 		    {
 			if(!strcasecmp(parm, mixer_name[n]))
@@ -602,7 +608,7 @@ static mixer_device_fdata_struct **MixerRCLoadAllFromFile(
 		    }       
 		} 
 	    }
-	    /* Unknown parameter. */
+	    /* Unknown parameter */
 	    else
 	    {
 		fprintf(
@@ -617,7 +623,7 @@ static mixer_device_fdata_struct **MixerRCLoadAllFromFile(
 
 #undef DO_READ_LINE
 
-	/* Close mixer device data file. */
+	/* Close mixer device data file */
 	FClose(fp);
 
 	return(ptr);
@@ -652,11 +658,11 @@ int MixerRCLoadFromFile(const char *filename, Recorder *recorder)
 	this_mixer_dev_name = fname.mixer;
 	if(this_mixer_dev_name[0] == '\0')
 	{
-	    /* No mixer device to load. */
+	    /* No mixer device to load */
 	    return(0);
 	}
 
-	/* Load all mixer devices data from file. */
+	/* Load all mixer devices data from file */
 	ptr = MixerRCLoadAllFromFile(filename, &total);
 	if(ptr == NULL)
 	    total = 0;
@@ -665,7 +671,7 @@ int MixerRCLoadFromFile(const char *filename, Recorder *recorder)
 	if(total <= 0)
 	    return(-1);
 
-	/* Go through mixer device listing. */
+	/* Go through mixer device listing */
 	for(i = 0; i < total; i++)
 	{
 	    mdfd_ptr = ptr[i];
@@ -675,7 +681,7 @@ int MixerRCLoadFromFile(const char *filename, Recorder *recorder)
 	    if(mdfd_ptr->name == NULL)
 		continue;
 
-	    /* Match mixer device name. */
+	    /* Match mixer device name */
 	    if(!strcasecmp(mdfd_ptr->name, this_mixer_dev_name))
 	    {
 		/* This is the mixer device we're looking for, now go
@@ -683,7 +689,7 @@ int MixerRCLoadFromFile(const char *filename, Recorder *recorder)
 		 */
 		for(mixer_index = 0; mixer_index < YTotalMixers; mixer_index++)
 		{
-		    /* Set mixer values for our mixer. */
+		    /* Set mixer values for our mixer */
 		    YMixerSet(
 			recorder, mixer_index + YMixerCodeBaseOffset,
 			mdfd_ptr->val[mixer_index]
@@ -694,7 +700,7 @@ int MixerRCLoadFromFile(const char *filename, Recorder *recorder)
 	    }
 	}
 
-	/* Deallocate the loaded mixer data listing. */
+	/* Deallocate the loaded mixer data listing */
 	MixerFreeFData(ptr, total);
 
 	if(set_our_mixer)
@@ -739,11 +745,11 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 	this_mixer_dev_name = fname.mixer;
 	if(this_mixer_dev_name[0] == '\0')
 	{
-	    /* Mixer device name is empty string, nothing to save. */
+	    /* Mixer device name is empty string, nothing to save */
 	    return(0);
 	}
 
-	/* Load all mixer devices data from file. */
+	/* Load all mixer devices data from file */
 	ptr = MixerRCLoadAllFromFile(filename, &total);
 	if(ptr == NULL)
 	    total = 0;
@@ -761,7 +767,7 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 	    if(mdfd_ptr->name == NULL)
 		continue;
 
-	    /* Match mixer device name. */
+	    /* Match mixer device name */
 	    if(!strcasecmp(mdfd_ptr->name, this_mixer_dev_name))
 	    {
 		/* This is the mixer device we're looking for, now go
@@ -790,11 +796,11 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 	 */
 	if(!got_our_mixer)
 	{
-	    /* Sanitize total. */
+	    /* Sanitize total */
 	    if(total < 0)
 		total = 0;
 
-	    /* Allocate one more pointer. */
+	    /* Allocate one more pointer */
 	    i = total;
 	    total++;
 	    ptr = (mixer_device_fdata_struct **)realloc(
@@ -807,7 +813,7 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 	    }
 	    else
 	    {
-		/* Allocate our mixer device structure in the list. */
+		/* Allocate our mixer device structure in the list */
 		ptr[i] = (mixer_device_fdata_struct *)calloc(
 		    1,
 		    sizeof(mixer_device_fdata_struct)
@@ -817,7 +823,7 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 		{
 		    mdfd_ptr->name = strdup(this_mixer_dev_name);
 
-		    /* Go through mixer device channel settings. */
+		    /* Go through mixer device channel settings */
 		    for(mixer_index = 0; mixer_index < YTotalMixers; mixer_index++)
 		    {
 			/* Get current mixer values for our mixer, store
@@ -841,7 +847,7 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 	fp = FOpen(filename, "wb");
 	if(fp != NULL)
 	{
-	    /* Write commented heading. */
+	    /* Write commented heading */
 	    fprintf(fp,
 "# Mixer device channel settings.\n\
 # This file is automatically generated by the YIFF Sound Server.\n\
@@ -849,7 +855,7 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 #\n"
 	    );
 
-	    /* Write each mixer device channel values to file. */
+	    /* Write each mixer device channel values to file */
 	    for(i = 0; i < total; i++)
 	    {
 		mdfd_ptr = ptr[i];
@@ -863,7 +869,7 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 		    mdfd_ptr->name
 		);
 
-		/* Write each mixer channel values. */
+		/* Write each mixer channel values */
 		for(mixer_index = 0; mixer_index < YTotalMixers; mixer_index++)
 		{
 		    fprintf(fp, "    %s = %f %f %f %f\n",
@@ -882,12 +888,12 @@ int MixerRCSaveToFile(const char *filename, Recorder *recorder)
 		fprintf(fp, "EndMixer\n");
 	    }
 
-	    /* Close the file. */
+	    /* Close the file */
 	    FClose(fp);
 	    fp = NULL;
 	}
 
-	/* Deallocate loaded mixer device file data listing. */
+	/* Deallocate loaded mixer device file data listing */
 	MixerFreeFData(ptr, total);
 
 	return(0);
