@@ -15,6 +15,10 @@ int SoundPathAllocate(void);
 void SoundPathDelete(int n);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
 
 
 /*
@@ -22,15 +26,15 @@ void SoundPathDelete(int n);
  */
 int SoundPathIsAllocated(int n)
 {
-        if((n < 0) ||
-           (n >= total_soundpaths) ||
-           (soundpath == NULL)
-        )
-            return(0);
-        else if(soundpath[n] == NULL)
-            return(0);
-        else
-            return(1);
+	if((n < 0) ||
+	   (n >= total_soundpaths) ||
+	   (soundpath == NULL)
+	)
+	    return(0);
+	else if(soundpath[n] == NULL)
+	    return(0);
+	else
+	    return(1);
 }
 
 /*
@@ -39,12 +43,12 @@ int SoundPathIsAllocated(int n)
  */
 SoundPath *SoundPathGetPtr(int n)
 {
-        if((n < 0) ||
-           (n >= total_soundpaths) ||
-           (soundpath == NULL)
-        )
-            return(NULL);
-        else
+	if((n < 0) ||
+	   (n >= total_soundpaths) ||
+	   (soundpath == NULL)
+	)
+	    return(NULL);
+	else
 	    return(soundpath[n]);
 }
 
@@ -86,8 +90,8 @@ char *SoundPathCompletePath(const char *filename)
 
 	/* Check each sound path. */
 	for(i = 0, sp_ptr = soundpath;
-            i < total_soundpaths;
-            i++, sp_ptr++
+	    i < total_soundpaths;
+	    i++, sp_ptr++
 	)
 	{
 	    if(*sp_ptr == NULL)
@@ -123,48 +127,48 @@ char *SoundPathCompletePath(const char *filename)
  */
 int SoundPathAllocate(void)
 {
-        int i, n;
+	int i, n;
 
  
-        for(i = 0; i < total_soundpaths; i++)
-        {   
-            if(soundpath[i] == NULL)
-                break;
-        }
-        if(i < total_soundpaths)
-        {
-            n = i;
-        }
-        else
-        {
-            n = total_soundpaths;
-            total_soundpaths++;
+	for(i = 0; i < total_soundpaths; i++)
+	{   
+	    if(soundpath[i] == NULL)
+		break;
+	}
+	if(i < total_soundpaths)
+	{
+	    n = i;
+	}
+	else
+	{
+	    n = total_soundpaths;
+	    total_soundpaths++;
 
-            soundpath = (SoundPath **)realloc(
-                soundpath,
-                total_soundpaths * sizeof(SoundPath *)
-            );
-            if(soundpath == NULL)
-            {
-                total_soundpaths = 0;
-                return(-1);
-            }
-        }
+	    soundpath = (SoundPath **)realloc(
+		soundpath,
+		total_soundpaths * sizeof(SoundPath *)
+	    );
+	    if(soundpath == NULL)
+	    {
+		total_soundpaths = 0;
+		return(-1);
+	    }
+	}
 
-        soundpath[n] = (SoundPath *)calloc(1,
-            sizeof(SoundPath)
-        );
-        if(soundpath[n] == NULL)
-        {
-            return(-1);
-        }
+	soundpath[n] = (SoundPath *)calloc(1,
+	    sizeof(SoundPath)
+	);
+	if(soundpath[n] == NULL)
+	{
+	    return(-1);
+	}
  
 
-        /* Reset values. */
+	/* Reset values. */
 	soundpath[n]->path = NULL;
 
 
-        return(n);
+	return(n);
 }
 
 /*
@@ -185,7 +189,7 @@ void SoundPathDelete(int n)
 	/* Reset pointer in array to NULL to mark it as deleted. */
 	soundpath[n] = NULL;
 
-        return;
+	return;
 }
 
 /*
@@ -193,15 +197,15 @@ void SoundPathDelete(int n)
  */
 void SoundPathDeleteAll(void)
 {
-        int i;
+	int i;
 
-        for(i = 0; i < total_soundpaths; i++)
-            SoundPathDelete(i);
+	for(i = 0; i < total_soundpaths; i++)
+	    SoundPathDelete(i);
 
-        free(soundpath);
-        soundpath = NULL;
+	free(soundpath);
+	soundpath = NULL;
 
-        total_soundpaths = 0;
+	total_soundpaths = 0;
 
-        return;
+	return;
 }
