@@ -1,7 +1,8 @@
 #ifndef SOUNDPATHS_H
 #define SOUNDPATHS_H
 
-
+#include <sys/types.h>
+#include "ytypes.h"
 
 /*
  *	Sound path structure:
