@@ -6,8 +6,6 @@
 #ifndef VOC_H
 #define VOC_H
 
-#include <stdio.h>
-#include <sys/stat.h>
 #include <sys/types.h>
 
 
@@ -129,20 +127,20 @@ typedef struct {
 
 
 
-        /* Block specific info - VocBlockTypeSilence */
-        u_int16_t silence_length;
+	/* Block specific info - VocBlockTypeSilence */
+	u_int16_t silence_length;
 
 	/* Block specific info - VocBlockTypeMarker */
 	u_int16_t marker_num;
 
-        /* Block specific info - VocBlockTypeASCII */
+	/* Block specific info - VocBlockTypeASCII */
 	char *str;
 	unsigned int str_len;
 
 	/* Block specific info - VocBlockTypeRepeat */
 	u_int16_t repeat_count;
 
-        /* Block specific info - VocBlockTypeExtended */
+	/* Block specific info - VocBlockTypeExtended */
 	u_int16_t time_constant;
 	unsigned char pack;
 	unsigned char mode;	/* 0 = mono, 1 = stereo. */
@@ -157,8 +155,8 @@ typedef struct {
  */
 typedef struct {
 
-        /* File info. */
-        char *filename;
+	/* File info. */
+	char *filename;
 	FILE *fp;
 	off_t filesize;
 
@@ -176,13 +174,13 @@ typedef struct {
 	int total_datablocks;
 
 
-        /*
+	/*
 	 *   The actual data loaded by VocReadPartialData().
 	 *   It will be freed and reallocated per call to
 	 *   VocReadPartialData().
-         */
-        char *data;
-        off_t data_len;
+	 */
+	char *data;
+	off_t data_len;
 
 
 	/*
@@ -270,10 +268,10 @@ extern int VocReadHeader(
  *   automatically before loading is performed.
  */
 extern int VocReadPartialData(
-        voc_data_struct *vd,
+	voc_data_struct *vd,
 	off_t offset,
-        off_t max_chunk_size,
-        int read_opt		/* Reading format. */
+	off_t max_chunk_size,
+	int read_opt		/* Reading format. */
 );
 
 
