@@ -16,20 +16,26 @@ void YModeDeleteAll(void);
 void YModeReclaim(void);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Checks if mode n is allocated.
  */
 int YModeIsAllocated(int n)
 {
-        if((n < 0) ||
-           (n >= total_ymodes) ||
-           (ymode == NULL)
-        )
-            return(0);
-        else if(ymode[n] == NULL)
-            return(0);
-        else
-            return(1);
+	if((n < 0) ||
+	   (n >= total_ymodes) ||
+	   (ymode == NULL)
+	)
+	    return(0);
+	else if(ymode[n] == NULL)
+	    return(0);
+	else
+	    return(1);
 }
 
 /*
@@ -38,10 +44,10 @@ int YModeIsAllocated(int n)
  */
 YMode *YModeGetPtr(int n)
 {
-        if(YModeIsAllocated(n))
-            return(ymode[n]);
-        else
-            return(NULL);
+	if(YModeIsAllocated(n))
+	    return(ymode[n]);
+	else
+	    return(NULL);
 }
 
 
@@ -80,7 +86,7 @@ int YModeMatch(const char *name)
  */
 int YModeAllocate(const char *name)
 {
-        int i, n;
+	int i, n;
 	YMode *ymode_ptr;
 
 
@@ -89,44 +95,44 @@ int YModeAllocate(const char *name)
 	    total_ymodes = 0;
 
 	/* Look for available pointer. */
-        for(i = 0; i < total_ymodes; i++)
-        {   
-            if(ymode[i] == NULL)
-                break;
-        }
-        if(i < total_ymodes)
-        {
-            n = i;
-        }
-        else
-        {
-            n = total_ymodes;
-            total_ymodes = n + 1;
+	for(i = 0; i < total_ymodes; i++)
+	{   
+	    if(ymode[i] == NULL)
+		break;
+	}
+	if(i < total_ymodes)
+	{
+	    n = i;
+	}
+	else
+	{
+	    n = total_ymodes;
+	    total_ymodes = n + 1;
 
 	    /* Allocate more pointers. */
-            ymode = (YMode **)realloc(
-                ymode,
-                total_ymodes * sizeof(YMode *)
-            );
-            if(ymode == NULL)
-            {
-                total_ymodes = 0;
-                return(-1);
-            }
-        }
+	    ymode = (YMode **)realloc(
+		ymode,
+		total_ymodes * sizeof(YMode *)
+	    );
+	    if(ymode == NULL)
+	    {
+		total_ymodes = 0;
+		return(-1);
+	    }
+	}
 
 	/* Allocate new structure. */
-        ymode_ptr = (YMode *)calloc(1, sizeof(YMode));
+	ymode_ptr = (YMode *)calloc(1, sizeof(YMode));
 	ymode[n] = ymode_ptr;
-        if(ymode_ptr == NULL)
-            return(-1);
+	if(ymode_ptr == NULL)
+	    return(-1);
 
 	/* Reset values. */
 	YModeReset(n);
 
 	ymode_ptr->name = ((name == NULL) ? NULL : strdup(name));
 
-        return(n);
+	return(n);
 }
 
 
@@ -136,9 +142,9 @@ int YModeAllocate(const char *name)
  */
 void YModeReset(int n)
 {
-        YMode *ptr = YModeGetPtr(n);
-        if(ptr == NULL)  
-            return;
+	YMode *ptr = YModeGetPtr(n);
+	if(ptr == NULL)  
+	    return;
 
 	/* Free name. */
 	free(ptr->name);
@@ -148,25 +154,25 @@ void YModeReset(int n)
 	ptr->cycle.us = 0;
 
 	ptr->write_ahead.ms = 0;
-        ptr->write_ahead.us = 0;
+	ptr->write_ahead.us = 0;
 
-        ptr->sample_size = 8;
-        ptr->channels = 1;
-        ptr->sample_rate = 11025;
+	ptr->sample_size = 8;
+	ptr->channels = 1;
+	ptr->sample_rate = 11025;
 
 	ptr->bytes_per_second = 11025;
 
 #ifdef OSS_BUFFRAG
-        ptr->allow_fragments = True;
-        ptr->num_fragments = 0x02;
-        ptr->fragment_size = 0x0a;
+	ptr->allow_fragments = True;
+	ptr->num_fragments = 0x02;
+	ptr->fragment_size = 0x0a;
 #endif  /* OSS_BUFFRAG */
 
-        ptr->flip_stereo = False;
-        ptr->direction = AUDIO_DIRECTION_PLAY;
+	ptr->flip_stereo = False;
+	ptr->direction = AUDIO_DIRECTION_PLAY;
 
 
-        return;
+	return;
 }
 
 /*
@@ -174,16 +180,16 @@ void YModeReset(int n)
  */
 void YModeDelete(int n)
 {
-        if(YModeIsAllocated(n))  
-        {
-            /* Free allocated substructures. */
-            YModeReset(n);
+	if(YModeIsAllocated(n))  
+	{
+	    /* Free allocated substructures. */
+	    YModeReset(n);
 
-            free(ymode[n]);
-            ymode[n] = NULL;
-        }
+	    free(ymode[n]);
+	    ymode[n] = NULL;
+	}
 
-        return;
+	return;
 }
 
 /*
@@ -191,17 +197,17 @@ void YModeDelete(int n)
  */
 void YModeDeleteAll(void)
 {
-        int i;
+	int i;
 
-        for(i = 0; i < total_ymodes; i++)
-            YModeDelete(i);
+	for(i = 0; i < total_ymodes; i++)
+	    YModeDelete(i);
 
-        free(ymode);
-        ymode = NULL;
+	free(ymode);
+	ymode = NULL;
 
-        total_ymodes = 0;
+	total_ymodes = 0;
 
-        return;
+	return;
 }
 
 /*
