@@ -13,7 +13,7 @@ extern int errno;
 
 #include <netinet/in.h>
 #include <sys/socket.h>
-#include <arpa/inet.h>          /* For inet_ntoa. */
+#include <arpa/inet.h>          /* For inet_ntoa */
 #include <sys/ioctl.h>
 #include <fcntl.h>
 
@@ -49,6 +49,9 @@ static int YNetSendToConnection(
 	YConnectionNumber con_num, const char *buf, int len
 );
 
+void YShutdownSocket(int socket, int how, time_t timeout);
+void YCloseSocketWait(int socket, time_t timeout);
+
 int YNetSendAudioChangePreset(
 	YConnectionNumber con_num,
 	const char *audio_mode_name
@@ -194,10 +197,16 @@ static int YNetParse(
 int YNetRecv(YConnectionNumber con_num);;
 
 
-#define MIN(a,b)	((a) < (b) ? (a) : (b))
-#define MAX(a,b)	((a) > (b) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : 1)
 
 
 extern int YAntiShift(int in);   /* In main.c */
@@ -284,7 +293,7 @@ static int YNetSendToConnection(
 	struct timeval timeout;
 	fd_set writefds;
 	int bytes_sent;
-	YConnection *con = yconnection[con_num];	/* Assumed valid. */
+	YConnection *con = yconnection[con_num];	/* Assumed valid */
 	int s = con->socket;
 
 	timeout.tv_sec = 0;
@@ -301,6 +310,37 @@ static int YNetSendToConnection(
 }
 
 
+/*
+ *      Shuts down the socket.
+ */
+void YShutdownSocket(int socket, int how, time_t timeout)
+{
+        if(socket < 0)
+            return;
+
+        shutdown(socket, how);
+}
+
+/*
+ *	Calls recv() until it returns 0 and then closes the socket.
+ */
+void YCloseSocketWait(int socket, time_t timeout)
+{
+        char buf[1024];
+
+        if(socket < 0)
+            return;
+
+        while(recv(
+            socket,
+            buf, sizeof(buf),
+            MSG_NOSIGNAL
+        ) > 0);
+
+        close(socket);
+}
+
+
 /*
  *	Send Audio mode change.
  */
@@ -331,7 +371,7 @@ int YNetSendAudioChangePreset(
 	    audio_mode_name,
 	    name_len
 	);
-	/* Do not null terminate string. */
+	/* Do not null terminate string */
 
 	/* Since this is a variable length segment we need to
 	 * recalculate the segment length after the formatting
@@ -395,7 +435,7 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	/* Change mode values or change to preset mode? */
 	if(minor_op_code == YAudioChangeValues)
 	{
-	    /* Parse set Audio values. */
+	    /* Parse set Audio values */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u16_samplesize> <u16_channels> <u32_samplerate>
@@ -415,7 +455,7 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	    if(chunk_length < this_seg_len)
 		return(-1);
 
-	    /* Get Audio values. */
+	    /* Get Audio values */
 	    sample_size = CLIP(
 		ntohs(*(u_int16_t *)(&buf[8])), 8, 16
 	    );
@@ -439,22 +479,22 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	     */
 	    if(sample_rate == 0)
 	    {
-		/* Shell out the recorder. */
+		/* Shell out the recorder */
 		YSoundShellOut(recorder);
 
-		/* Send back shell out response. */
+		/* Send back shell out response */
 		YNetSendAudioChangeValues(
 		    con_num,
 		    sample_size,
 		    channels,
-		    0,		/* Sample rate should be 0. */
+		    0,		/* Sample rate should be 0 */
 		    direction,
 		    allow_fragmenting,
 		    num_fragments,
 		    fragment_size_bytes
 		);
 
-		/* Return now, do not delete playstacks or modify Audio. */
+		/* Return now, do not delete playstacks or modify Audio */
 		return(0);
 	    }
 
@@ -464,16 +504,16 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	    for(i = 0; i < total_playstacks; i++)
 		YiffDestroyPlaystack(i);
 
-	    /* Notify all connections about YSHM sound closing. */
+	    /* Notify all connections about YSHM sound closing */
 	    YNetDoNotifyAllYSHMSoundClose();
 
-	    /* Shutdown and delete the recorder. */
+	    /* Shutdown and delete the recorder */
 	    YSoundShutdown(recorder);
 	    free(recorder);
 	    recorder = NULL;
 
 
-	    /* Set new Audio values to option Audio values. */
+	    /* Set new Audio values to option Audio values */
 	    audio_ptr = &option.audio;
 	    audio_ptr->sample_size = sample_size;
 	    audio_ptr->channels = channels;
@@ -490,21 +530,21 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	    audio_ptr->direction = direction;
 
 
-	    /* Allocate recorder structure. */
+	    /* Allocate recorder structure */
 	    recorder = (Recorder *)calloc(1, sizeof(Recorder));
 	    if(recorder == NULL)
 		return(-1);
-	    /* Initialize recorder. */
+	    /* Initialize recorder */
 	    if(YSoundInit(recorder, &option.audio))
 	    {
-		/* Failed to initialize. */
+		/* Failed to initialize */
 
-		/* Shutdown and delete the recorder. */
+		/* Shutdown and delete the recorder */
 		YSoundShutdown(recorder);
 		free(recorder);
 		recorder = NULL;
 
-		/* Send back notification of initialization failure. */
+		/* Send back notification of initialization failure */
 		YNetSendAudioChangeValues(
 		    con_num,
 		    0, 0, 0,
@@ -520,7 +560,7 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	    YSoundSync(recorder, 0);
 
 
-	    /* Notify all connections about Audio values change. */
+	    /* Notify all connections about Audio values change */
 	    for(i = 0; i < total_yconnections; i++)
 	    {
 		con = yconnection[i];
@@ -541,7 +581,7 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	}
 	else
 	{
-	    /* Parse change preset Audio mode. */
+	    /* Parse change preset Audio mode */
 
 	    /*   <u32_cs> <u16_majop> <u16_minop>
 	     *   <...modename...>
@@ -611,25 +651,25 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 		    for(i = 0; i < total_playstacks; i++)
 			YiffDestroyPlaystack(i);
 
-		    /* Notify all connections about YSHM sound closing. */
+		    /* Notify all connections about YSHM sound closing */
 		    YNetDoNotifyAllYSHMSoundClose();
 
-		    /* Shutdown and delete the recorder. */
+		    /* Shutdown and delete the recorder */
 		    YSoundShutdown(recorder);
 		    free(recorder);
 		    recorder = NULL;
 
 
-		    /* Set option Audio values to new mode's values. */
+		    /* Set option Audio values to new mode's values */
 		    audio_ptr = &option.audio;
 
-		    /* Audio modes are always considered user set. */
+		    /* Audio modes are always considered user set */
 		    audio_ptr->cycle_set = CYCLE_SET_USER;
 
 		    audio_ptr->cycle.ms = ymode_ptr->cycle.ms;
 		    audio_ptr->cycle.us = ymode_ptr->cycle.us;
 
-		    /* Leave audio_ptr->compensated_cycle alone. */
+		    /* Leave audio_ptr->compensated_cycle alone */
 
 		    audio_ptr->write_ahead.ms = ymode_ptr->write_ahead.ms;
 		    audio_ptr->write_ahead.us = ymode_ptr->write_ahead.us;
@@ -648,16 +688,16 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 		    audio_ptr->direction = ymode_ptr->direction;
 
 
-		    /* Allocate recorder structure. */
+		    /* Allocate recorder structure */
 		    recorder = (Recorder *)calloc(1, sizeof(Recorder));
 		    if(recorder == NULL)
 			return(-1);
-		    /* Initialize recorder. */
+		    /* Initialize recorder */
 		    if(YSoundInit(recorder, audio_ptr))
 		    {
-			/* Failed to initialize. */
+			/* Failed to initialize */
 
-			/* Shutdown and delete the recorder. */
+			/* Shutdown and delete the recorder */
 			YSoundShutdown(recorder);
 			free(recorder);
 			recorder = NULL;
@@ -679,11 +719,11 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 		     * set this Audio.
 		     */
 		    free(recorder->audio.audio_mode_name);
-		    recorder->audio.audio_mode_name = StringCopyAlloc(
+		    recorder->audio.audio_mode_name = STRDUP(
 			ymode_ptr->name
 		    );
 
-		    /* Notify all connections of Audio mode change. */
+		    /* Notify all connections of Audio mode change */
 		    for(i = 0; i < total_yconnections; i++)
 		    {
 			con = yconnection[i];
@@ -696,12 +736,12 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 		/* Audio mode the same? */
 		else if(!mode_name_different)
 		{
-		    /* Send back fake success response. */
+		    /* Send back fake success response */
 		    YNetSendAudioChangePreset(con_num, mode_name);
 		}
 		else
 		{
-		    /* No such preset Audio mode. */
+		    /* No such preset Audio mode */
 
 		    /* Notify connection of Audio mode change
 		     * failure (send back empty Audio mode name).
@@ -711,7 +751,7 @@ int YNetParseAudioChange(YCNP_STD_INPUTS_PROTO)
 	    }
 	    else
 	    {
-		/* No mode name specified. */
+		/* No mode name specified */
 
 		/* Notify connection of Audio mode change
 		 * failure (send back empty Audio mode name).
@@ -803,7 +843,7 @@ int YNetParseServerStats(YCNP_STD_INPUTS_PROTO)
 {
 	if(minor_op_code == YServerStatsGet)
 	{
-	    /* Parse server stats get. */
+	    /* Parse server stats get */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -825,7 +865,7 @@ int YNetParseServerStats(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YServerStatsSet)
 	{
-	    /* Parse server stats set. */
+	    /* Parse server stats set */
  
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -850,7 +890,7 @@ int YNetSendCycleChange(YConnectionNumber con_num, long cycle_us)
 	char buf[this_seg_len];
 
 
-	/* Most UNIXes requires cycles > than 100 us. */
+	/* Most UNIXes requires cycles > than 100 us */
 	if(cycle_us < 100)
 	    cycle_us = 100;
 
@@ -880,19 +920,19 @@ int YNetParseCycleChange(YCNP_STD_INPUTS_PROTO)
 	    return(-1);
 
 	cycle_us = ntohl(*(u_int32_t *)(&buf[8]));
-	/* Most UNIXes requires this > than 100 us. */
+	/* Most UNIXes requires this > than 100 us */
 	if(cycle_us < 100)
 	    cycle_us = 100;
 
-	/* Set new cycle. */
+	/* Set new cycle */
 	if(recorder == NULL)
 	{
-	    /* Recorder not available, send error response. */
+	    /* Recorder not available, send error response */
 	    YNetSendCycleChange(con_num, 0);
 	}
 	else
 	{
-	    /* Set new cycle. */
+	    /* Set new cycle */
 	    if(recorder->audio.cycle_set == CYCLE_SET_USER)
 	    {
 		recorder->audio.cycle.ms = cycle_us / 1000;
@@ -914,7 +954,7 @@ int YNetParseCycleChange(YCNP_STD_INPUTS_PROTO)
 		    recorder->audio.write_ahead.us;
 
 
-		/* Notify all connections of cycle change. */
+		/* Notify all connections of cycle change */
 		for(i = 0; i < total_yconnections; i++)
 		{
 		    con = yconnection[i];
@@ -926,7 +966,7 @@ int YNetParseCycleChange(YCNP_STD_INPUTS_PROTO)
 	    }
 	    else
 	    {
-		/* Program or hardware set cycle. */
+		/* Program or hardware set cycle */
 		cycle_us = (recorder->audio.cycle.ms * 1000) +
 		    recorder->audio.cycle.us;
 
@@ -975,7 +1015,7 @@ int YNetParseDisconnect(YCNP_STD_INPUTS_PROTO)
 
 	reason = ntohs(*(u_int16_t *)(&buf[8]));
 
-	/* Mark currently handled connection number to be closed. */
+	/* Mark currently handled connection number to be closed */
 	close_this_connection = True;
 
 	return(0);
@@ -1055,7 +1095,7 @@ int YNetParseSetHost(YCNP_STD_INPUTS_PROTO)
 	    break;
 	}
 
-	/* Notify connection of host add or remove. */
+	/* Notify connection of host add or remove */
 	YNetSendSetHost(
 	    con_num,
 	    minor_op_code,
@@ -1144,7 +1184,7 @@ int YNetParseMixerDevice(YCNP_STD_INPUTS_PROTO)
 		    (Coefficient)ntohl(*(u_int32_t *)(&buf[22])) /
 		    (Coefficient)((u_int32_t)-1);
 
-	    /* Set mixer device. */
+	    /* Set mixer device */
 	    status = -1;
 	    if(recorder != NULL)
 	    {
@@ -1152,7 +1192,7 @@ int YNetParseMixerDevice(YCNP_STD_INPUTS_PROTO)
 	    }
 	    if(status < 0)
 	    {
-		/* Error setting mixer values, notify error. */
+		/* Error setting mixer values, notify error */
 		YNetSendSetMixerDevice(
 		    con_num, mixer_code,
 		    0.0, 0.0, 0.0, 0.0
@@ -1160,7 +1200,7 @@ int YNetParseMixerDevice(YCNP_STD_INPUTS_PROTO)
 	    }
 	    else
 	    {
-		/* Notify all connections about mixer channel change. */
+		/* Notify all connections about mixer channel change */
 		for(i = 0; i < total_yconnections; i++)
 		{
 		    con = yconnection[i];
@@ -1192,7 +1232,7 @@ int YNetParseMixerDevice(YCNP_STD_INPUTS_PROTO)
 
 	    mixer_code = ntohs(*(u_int16_t *)(&buf[8]));
 
-	    /* Get mixer channel device values. */
+	    /* Get mixer channel device values */
 	    status = -1;
 	    if(recorder != NULL)
 	    {
@@ -1202,7 +1242,7 @@ int YNetParseMixerDevice(YCNP_STD_INPUTS_PROTO)
 	    }
 	    if(status < 0)
 	    {
-		/* Error getting values, respond with 0 channel values. */
+		/* Error getting values, respond with 0 channel values */
 		YNetSendSetMixerDevice(
 		    con_num, mixer_code,
 		    0.0, 0.0, 0.0, 0.0
@@ -1246,7 +1286,7 @@ int YNetSendSoundObjectPlay(
 	const YDataLength this_seg_len = 8 + 8 + 8 + 8 + 4 + 4 + 4;
 	char buf[this_seg_len];
 
-	/* Set flags to match client side (see Y2/Ylib.h). */
+	/* Set flags to match client side (see Y2/Ylib.h) */
 	unsigned long flags =   (1 << 1) | (1 << 2) | (1 << 3) |
 				(1 << 4) | (1 << 5) | (1 << 6) |
 				(1 << 7);
@@ -1336,7 +1376,7 @@ int YNetParseSoundObjectPlay(YCNP_STD_INPUTS_PROTO)
 	}
 	else
 	{
-	    /* If path is not specified, then do not continue. */
+	    /* If path is not specified, then do not continue */
 	    YNetSendSoundObjectPlay(
 		con_num, YIDNULL,
 		0, 0, 0, 0,
@@ -1347,7 +1387,7 @@ int YNetParseSoundObjectPlay(YCNP_STD_INPUTS_PROTO)
 	}
 
 
-	/* Try to match correct complete path. */
+	/* Try to match correct complete path */
 	strptr = SoundPathCompletePath(path);
 	if(strptr == NULL)
 	{
@@ -1360,7 +1400,7 @@ int YNetParseSoundObjectPlay(YCNP_STD_INPUTS_PROTO)
 	    return(0);
 	}
 
-	/* Do not start playing if recorder is not initialized. */
+	/* Do not start playing if recorder is not initialized */
 	if(recorder == NULL)
 	{
 	    YNetSendSoundObjectPlay(
@@ -1372,22 +1412,22 @@ int YNetParseSoundObjectPlay(YCNP_STD_INPUTS_PROTO)
 	    return(0);
 	}
 
-	/* Create playstack. */
+	/* Create playstack */
 	volume.left = vol[0];
 	volume.right = vol[1];
 	volume.back_left = vol[2];
 	volume.back_right = vol[3];
 	YiffCreatePlaystack( 
-	    strptr,		/* Path. */
-	    con_num,		/* Owner. */
-	    yid,		/* YID. */
-	    pos,		/* Position. */
+	    strptr,		/* Path */
+	    con_num,		/* Owner */
+	    yid,		/* YID */
+	    pos,		/* Position */
 	    &volume,
 	    sample_rate,
-	    repeats		/* 0 means repeat forever. */
+	    repeats		/* 0 means repeat forever */
 	);
 
-	/* YiffCreatePlaystack() will send response. */
+	/* YiffCreatePlaystack() will send response */
 
 
 	return(0);
@@ -1432,7 +1472,7 @@ int YNetParseSoundObjectKill(YCNP_STD_INPUTS_PROTO)
 
 	yid = ntohl(*(u_int32_t *)(&buf[8])); 
 
-	/* Kill playstack. */
+	/* Kill playstack */
 	for(i = 0; i < total_playstacks; i++)
 	{
 	    ps = playstack[i];
@@ -1445,7 +1485,7 @@ int YNetParseSoundObjectKill(YCNP_STD_INPUTS_PROTO)
 	    if((ps->yid == YIDNULL) || (ps->yid != yid))
 		continue;
 
-	    /* Delete playstack and notify owner connection about it. */
+	    /* Delete playstack and notify owner connection about it */
 	    YiffDestroyPlaystack(i);
 	}
 
@@ -1495,7 +1535,7 @@ int YNetSendSoundObjectAttributes(
 		path,
 		path_len
 	    );
-	/* Do not null terminate string. */
+	/* Do not null terminate string */
 
 	/* Since this is a variable length segment we need to
 	 * recalculate the segment length after the formatting
@@ -1547,7 +1587,7 @@ int YNetParseSoundObjectAttributes(YCNP_STD_INPUTS_PROTO)
 	    }
 
 
-	    /* Try to match correct complete path. */
+	    /* Try to match correct complete path */
 	    strptr = SoundPathCompletePath(path);
 	    if(strptr == NULL)
 	    {
@@ -1575,10 +1615,10 @@ int YNetParseSoundObjectAttributes(YCNP_STD_INPUTS_PROTO)
 		af_data.entire_length = 0;
 	    }
 
-	    /* Send audio file data. */
+	    /* Send audio file data */
 	    YNetSendSoundObjectAttributes(
 		con_num,
-		path,		/* Send back original path. */
+		path,		/* Send back original path */
 		af_data.sndobj_format,
 		af_data.sample_size,
 		af_data.channels,
@@ -1586,7 +1626,7 @@ int YNetParseSoundObjectAttributes(YCNP_STD_INPUTS_PROTO)
 		af_data.entire_length
 	    );
 
-	    /* Close audio file. */
+	    /* Close audio file */
 	    AFWClose(
 		&af_data,
 		(recorder != NULL) ? &recorder->audio : NULL
@@ -1691,22 +1731,22 @@ int YNetParseSync(YCNP_STD_INPUTS_PROTO)
 
 	if(recorder != NULL)
 	{
-	    /* Recaliberate cycle if program calculates it. */
+	    /* Recaliberate cycle if program calculates it */
 	    if(recorder->audio.cycle_set == CYCLE_SET_PROGRAM)
 		YSoundCaliberateCycle(recorder);
 
-	    /* Set new write ahead. */
+	    /* Set new write ahead */
 	    if(cahead_us > 0)
 	    {
 		recorder->audio.write_ahead.ms = cahead_us / 1000;
 		recorder->audio.write_ahead.us = cahead_us % 1000;
 	    }
 
-	    /* Sync sound device. */
+	    /* Sync sound device */
 	    YSoundSync(recorder, 0);
 	}
 
-	/* Send sync comfermation. */
+	/* Send sync comfermation */
 	YNetSendSync(con_num, cahead_us);
 
 	return(0);
@@ -1738,7 +1778,7 @@ int YNetSendAudioStats(
 
 	if(audio == NULL)
 	{
-	    /* Send blank values (implying recorder not available). */
+	    /* Send blank values (implying recorder not available) */
 	    memset(buf, 0x00, this_seg_len * sizeof(char));
 
 	    *(u_int32_t *)(&buf[0]) = htonl((u_int32_t)this_seg_len);
@@ -1792,7 +1832,7 @@ int YNetSendAudioStats(
 
 	    name_len = MIN(strlen(audio_mode_name), YAudioNameMax);
 	    strncpy(&buf[48], audio_mode_name, name_len);
-	    /* Do not null terminate string. */
+	    /* Do not null terminate string */
 
 	    /* Since this is a variable length segment we need to
 	     * recalculate the segment length after the formatting
@@ -1877,7 +1917,7 @@ int YNetSendListAudioModes(
 	    audio_mode_name,
 	    name_len
 	);
-	/* Do not null terminate string. */
+	/* Do not null terminate string */
 
 	/* Since this is a variable length segment we need to
 	 * recalculate the segment length after the formatting
@@ -1895,7 +1935,7 @@ int YNetParseListAudioModes(YCNP_STD_INPUTS_PROTO)
 {
 	if(minor_op_code == YListAudioModesGet)
 	{
-	    /* Parse list audio modes get. */
+	    /* Parse list audio modes get */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -1907,7 +1947,7 @@ int YNetParseListAudioModes(YCNP_STD_INPUTS_PROTO)
 	    if(chunk_length < this_seg_len)
 		return(-1);
 
-	    /* Send list of preset audio modes. */
+	    /* Send list of preset audio modes */
 	    for(i = 0; i < total_ymodes; i++)
 	    {
 		m = ymode[i];
@@ -1937,7 +1977,7 @@ int YNetParseListAudioModes(YCNP_STD_INPUTS_PROTO)
 	    }
 
 
-	    /* End with an audio mode with no name (indicating end). */
+	    /* End with an audio mode with no name (indicating end) */
 	    YNetSendListAudioModes(
 		con_num,
 		"",
@@ -1972,12 +2012,12 @@ int YNetSendPlaySoundObjectValues(
 	const YDataLength this_seg_len = 8 + 8 + 8 + 8 + 4 + 4 + 4;
 	char buf[this_seg_len];
 
-	/* Set flags to match client side (see Y2/Ylib.h). */
+	/* Set flags to match client side (see Y2/Ylib.h) */
 	unsigned long flags =	(1 << 1) | (1 << 2) | (1 << 3) |
 				(1 << 4) | (1 << 5) | (1 << 6) |
 				(1 << 7); 
 
-	/* If no playstack is given then send error. */
+	/* If no playstack is given then send error */
 	if(ps_ptr == NULL)
 	{
 	    *(u_int32_t *)(&buf[0]) = htonl((u_int32_t)this_seg_len);
@@ -2030,7 +2070,7 @@ int YNetParsePlaySoundObjectValues(YCNP_STD_INPUTS_PROTO)
 {
 	if(minor_op_code == YSoundObjectPlayValuesGet)
 	{
-	    /* Parse play sound object values get. */
+	    /* Parse play sound object values get */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_yid>
@@ -2046,7 +2086,7 @@ int YNetParsePlaySoundObjectValues(YCNP_STD_INPUTS_PROTO)
 
 	    yid = (YID)ntohl(*(u_int32_t *)(&buf[8]));
 
-	    /* Check if yid exists. */
+	    /* Check if yid exists */
 	    for(i = 0; i < total_playstacks; i++)
 	    {
 		ps = playstack[i];
@@ -2060,7 +2100,7 @@ int YNetParsePlaySoundObjectValues(YCNP_STD_INPUTS_PROTO)
 
 		if(ps->yid == yid)
 		{
-		    /* Send playing sound object values. */
+		    /* Send playing sound object values */
 		    YNetSendPlaySoundObjectValues(con_num, ps);
 		    response_sent = True;
 		    break;
@@ -2071,7 +2111,7 @@ int YNetParsePlaySoundObjectValues(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YSoundObjectPlayValuesSet)
 	{
-	    /* Parse play sound object values set. */
+	    /* Parse play sound object values set */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_flags> <u32_yid>
@@ -2106,7 +2146,7 @@ int YNetParsePlaySoundObjectValues(YCNP_STD_INPUTS_PROTO)
 
 	    sample_rate = ntohl(*(u_int32_t *)(&buf[32]));
 
-	    /* Check if yid exists. */
+	    /* Check if yid exists */
 	    for(i = 0; i < total_playstacks; i++)
 	    {
 		ps = playstack[i];
@@ -2120,7 +2160,7 @@ int YNetParsePlaySoundObjectValues(YCNP_STD_INPUTS_PROTO)
 
 		if(ps->yid == yid)
 		{
-		    /* Set new values to play stack. */
+		    /* Set new values to play stack */
 
 		    /* Change position? */
 		    if(flags & (1 << 2))
@@ -2147,7 +2187,7 @@ int YNetParsePlaySoundObjectValues(YCNP_STD_INPUTS_PROTO)
 		    if(flags & (1 << 7))
 			ps->applied_sample_rate = (int)sample_rate;
 
-		    /* Send response of values set. */
+		    /* Send response of values set */
 		    YNetSendPlaySoundObjectValues(con_num, ps);
 		    break;
 		}
@@ -2197,7 +2237,7 @@ int YNetParseClientMessage(YCNP_STD_INPUTS_PROTO)
 {
 	if(minor_op_code == YClientMessageSend)
 	{
-	    /* Parse client message send. */
+	    /* Parse client message send */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_format> <u32_type>
@@ -2225,7 +2265,7 @@ int YNetParseClientMessage(YCNP_STD_INPUTS_PROTO)
 	    if(message_length > 0)
 		memcpy(message, &buf[17], message_length);
 
-	    /* Notify connections about client message. */
+	    /* Notify connections about client message */
 	    for(i = 0; i < total_yconnections; i++)
 	    {
 		con = yconnection[i];
@@ -2320,7 +2360,7 @@ int YNetParseYSHMSoundOpen(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YSHMSoundClose)
 	{
-	    /* Client should never tell the server to do this. */
+	    /* Client should never tell the server to do this */
 	}
 
 	return(0);
@@ -2433,7 +2473,7 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YAudioCDPlayTrack)
 	{
-	    /* Parse audio CD play track. */
+	    /* Parse audio CD play track */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     * <u32_track_number>
@@ -2452,10 +2492,10 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 		YConnection *con;
 		Audio *audio_ptr = &recorder->audio;
 
-		/* Play audio CD track. */
+		/* Play audio CD track */
 		AudioCDPlayTrack(audio_ptr->audiocd_context, track_number);
 
-		/* Notify all connections about play audio CD track. */
+		/* Notify all connections about play audio CD track */
 		for(i = 0; i < total_yconnections; i++)
 		{
 		    con = yconnection[i];
@@ -2468,7 +2508,7 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YAudioCDStop)
 	{
-	    /* Parse stop audio CD. */
+	    /* Parse stop audio CD */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -2483,10 +2523,10 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 		YConnection *con;
 		Audio *audio_ptr = &recorder->audio;
 
-		/* Stop audio CD. */
+		/* Stop audio CD */
 		AudioCDStop(audio_ptr->audiocd_context);
 
-		/* Notify all connections about stop audio CD. */
+		/* Notify all connections about stop audio CD */
 		for(i = 0; i < total_yconnections; i++)
 		{
 		    con = yconnection[i];
@@ -2499,7 +2539,7 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 	}
 	else if(minor_op_code == YAudioCDEject)
 	{
-	    /* Parse eject audio CD. */
+	    /* Parse eject audio CD */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -2514,10 +2554,10 @@ int YNetParseAudioCD(YCNP_STD_INPUTS_PROTO)
 		YConnection *con;
 		Audio *audio_ptr = &recorder->audio;
 
-		/* Eject audio CD. */
+		/* Eject audio CD */
 		AudioCDEject(audio_ptr->audiocd_context);
 
-		/* Notify all connections about eject audio CD. */
+		/* Notify all connections about eject audio CD */
 		for(i = 0; i < total_yconnections; i++)
 		{
 		    con = yconnection[i];
@@ -2567,7 +2607,7 @@ int YNetSendListAudioCDTracks(
 	    MIN(strlen(track_name), YAudioCDTrackNameMax - 1) : 0;
 	if(len > 0)
 	    strncpy(&buf[28], track_name, len);
-	/* Do not null terminate string. */
+	/* Do not null terminate string */
 
 	/* Since this is a variable length segment we need to
 	 * recalculate the segment length after the formatting
@@ -2586,7 +2626,7 @@ int YNetParseListAudioCDTracks(YCNP_STD_INPUTS_PROTO)
 {
 	if(minor_op_code == YAudioCDTracksListGet)
 	{
-	    /* Parse list audio CD tracks get. */
+	    /* Parse list audio CD tracks get */
 
 	    /* <u32_cs> <u16_majop> <u16_minop>
 	     */
@@ -2602,7 +2642,7 @@ int YNetParseListAudioCDTracks(YCNP_STD_INPUTS_PROTO)
 		int i, total;
 		AudioCDTrack **track, *t;
 
-		/* Get list of audio CD tracks. */
+		/* Get list of audio CD tracks */
 		track = AudioCDListTracks(
 		    audio_ptr->audiocd_context, &total
 		);
@@ -2612,14 +2652,14 @@ int YNetParseListAudioCDTracks(YCNP_STD_INPUTS_PROTO)
 		    if(t == NULL)
 			continue;
 
-		    /* Send this audio CD track. */
+		    /* Send this audio CD track */
 		    YNetSendListAudioCDTracks(
 			con_num, t->number, t->start_time, t->length, t->name
 		    );
 		}
 		AudioCDDeleteTracksList(track, total);
 	    }
-	    /* End the list by sending track 0 to indicate end. */
+	    /* End the list by sending track 0 to indicate end */
 	    YNetSendListAudioCDTracks(con_num, 0, 0, 0, NULL);
 	}
 	else if(minor_op_code == YAudioCDTracksListSet)
@@ -2649,7 +2689,7 @@ static int YNetParse(
 	YConnection *con;      
 
 
-	/* Connection assumed valid. */
+	/* Connection assumed valid */
 	con = yconnection[con_num];
 
 
@@ -2672,7 +2712,7 @@ static int YNetParse(
 	    break;
 
 	  case YListHosts:
-/* Work on this later. */
+/* Work on this later */
 	    break;
  
 	  case YMixerChannel:
@@ -2680,7 +2720,7 @@ static int YNetParse(
 	    break;
 	
 	  case YListMixers:
-/* Work on this later. */
+/* Work on this later */
 	    break; 
  
 	  case YSoundObjectPlay:
@@ -2769,14 +2809,14 @@ int YNetRecv(YConnectionNumber con_num)
 
 
 
-	/* Reset close connection marker. */
+	/* Reset close connection marker */
 	close_this_connection = False;
 
 
-	/* Connection is assumed valid and connected. */
+	/* Connection is assumed valid and connected */
 	con = yconnection[con_num];
 
-	/* Get connection's socket number. */
+	/* Get connection's socket number */
 	s = con->socket;
 
 
@@ -2796,17 +2836,18 @@ int YNetRecv(YConnectionNumber con_num)
 	     */
 	    con->buf_cont = 0;
 
-	    /* Disconnect and delete connection. */
+	    /* Disconnect and delete connection */
 	    if(con->socket > -1)
 	    {
-		close(con->socket);
+		YShutdownSocket(con->socket, SHUT_RDWR, 30l);
+		YCloseSocketWait(con->socket, 30l);
 		con->socket = -1;
 	    }
 	    YiffCloseConnection(con_num);
 
 	    fprintf(
 		stderr,
- "YNetRecv(): Connection %i: Contents overflowed buffer length %ld.\n",
+"YNetRecv(): Connection %i: Contents overflowed buffer length %ld.\n",
 		con_num,
 		con->buf_len
 	    );
@@ -2815,7 +2856,7 @@ int YNetRecv(YConnectionNumber con_num)
 	}
 
 
-	/* Do not block, check if there is any data to be read. */
+	/* Do not block, check if there is any data to be read */
 	timeout.tv_sec = 0;
 	timeout.tv_usec = 0;
 	FD_ZERO(&readfds);
@@ -2828,50 +2869,50 @@ int YNetRecv(YConnectionNumber con_num)
 	    return(0);
 
 
-	buf_ptr = &(con->buf[con->buf_cont]);
+	buf_ptr = con->buf + con->buf_cont;
 	bytes_read = recv(
 	    s,
 	    buf_ptr,
 	    con->buf_len - con->buf_cont,
-	    0
+	    MSG_NOSIGNAL
 	);
 	if(bytes_read == 0)
 	{
-	    /* Disconnect and delete connection. */
-	    if(con->socket > -1)
-	    {
-		close(con->socket);
-		con->socket = -1;
-	    }
+	    /* Disconnect and delete connection */
+            YShutdownSocket(s, SHUT_RDWR, 30l);
+	    close(s);
+	    con->socket = s = -1;
 	    YiffCloseConnection(con_num);
 
 	    return(0);
 	}
-	else if(bytes_read <= 0)
+	else if(bytes_read < 0)
 	{
-	    /* Handle error. */
-	    switch(errno)
+	    /* Handle error */
+	    const int error_code = errno;
+	    switch(error_code)
 	    {
 	      case EWOULDBLOCK:
+#if (EAGAIN != EWOULDBLOCK)
+	      case EAGAIN:
+#endif
 		break;
 
 	      case EINTR:
 		break;
 
 	      default:
-		/* Disconnect and delete connection. */
-		if(con->socket > -1)
-		{
-		    close(con->socket);
-		    con->socket = -1;
-		}
+		/* Disconnect and delete connection */
+                YShutdownSocket(s, SHUT_RDWR, 30l);
+                YCloseSocketWait(s, 30l);
+		con->socket = -1;
 		YiffCloseConnection(con_num);
 		break;   
 	    }
 	    return(0);
 	} 
 
-	/* Increment buffer contents. */
+	/* Increment buffer contents */
 	con->buf_cont += bytes_read;
 	if(con->buf_cont > con->buf_len)
 	    con->buf_cont = con->buf_len;
@@ -2896,7 +2937,7 @@ int YNetRecv(YConnectionNumber con_num)
 	    minor_op_code = ntohs(*((u_int16_t *)(&con->buf[6])));
 
 
-	    /* Specified chunk length must be 8 or greater. */
+	    /* Specified chunk length must be 8 or greater */
 	    if(chunk_length < 8)
 	    {
 		YNetPrintError(
@@ -2908,12 +2949,10 @@ int YNetRecv(YConnectionNumber con_num)
  "Recieved a segment with header specified chunk length less than 8 bytes"
 		); 
 
-		/* Disconnect and delete connection. */
-		if(con->socket > -1)
-		{
-		    close(con->socket);
-		    con->socket = -1;
-		}
+		/* Disconnect and delete connection */
+                YShutdownSocket(con->socket, SHUT_RDWR, 30l);
+                YCloseSocketWait(con->socket, 30l);
+		con->socket = -1;
 		YiffCloseConnection(con_num);
 
 		return(0);
@@ -2925,7 +2964,7 @@ int YNetRecv(YConnectionNumber con_num)
 	     */
 	    if((YDataLength)chunk_length > (YDataLength)con->buf_cont)
 		break;
-/*
+#if 0
 {
  printf("Server: %i %i %i: Recieved incomplete.\n",
   chunk_length, major_op_code, minor_op_code
@@ -2936,9 +2975,9 @@ else
  printf("Server: %i %i | %i %i: Recieved.\n",
   chunk_length, con->buf_cont, major_op_code, minor_op_code
  );
- */
+#endif
 
-	    /* Parse this segement and put data into event structure. */
+	    /* Parse this segement and put data into event structure */
 	    YNetParse(
 		con_num,
 		con->buf,
@@ -2948,32 +2987,30 @@ else
 	    );
 	    segments_handled++;
 
-	    /*   Stop parsing and close this connection? This would
-	     *   be said if the connection needed to be closed for some
-	     *   reason determined in a higher call to YNetParse()
-	     *   above.
+	    /* Stop parsing and close this connection? This would
+	     * be said if the connection needed to be closed for some
+	     * reason determined in a higher call to YNetParse()
+	     * above
 	     */
 	    if(close_this_connection)
 	    {
-		/* Disconnect and delete connection. */
-		if(con->socket > -1)
-		{
-		    close(con->socket);
-		    con->socket = -1;
-		}
+		/* Disconnect and delete connection */
+                YShutdownSocket(con->socket, SHUT_RDWR, 30l);
+                YCloseSocketWait(con->socket, 30l);
+		con->socket = -1;
 		YiffCloseConnection(con_num);
 
 		break;
 	    }
 
-	    /* Shift the buffer. */
+	    /* Shift the buffer */
 	    for(i = 0, n = chunk_length;
 		n < con->buf_cont;
 		i++, n++
 	    )
 		con->buf[i] = con->buf[n];
 
-	    /* Decrease buffer contents. */
+	    /* Decrease buffer contents */
 	    con->buf_cont = (YDataLength)con->buf_cont -
 		(YDataLength)chunk_length;
 	    if(con->buf_cont < 0)
