@@ -1,18 +1,25 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/ioctl.h>
 #include <sys/types.h>
+#include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <unistd.h>
 
-
-#ifdef __linux__
+#if defined(__linux__)
 # include <linux/soundcard.h>
-#endif	/* __linux__ */
+#elif defined(__FreeBSD__)
+# include <machine/soundcard.h>
+#endif
+
+#ifdef YSHM_SUPPORT
+# include "../include/shm.h"
+#endif
 
 #include "ytypes.h"
 #include "midiiow.h"
+#include "audiocd.h"
 #include "ysound.h"
 #include "options.h"
 
@@ -25,8 +32,10 @@ void YSoundSync(Recorder *recorder, int options);
 void YSoundShutdown(Recorder *recorder);
 
 
-#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
-#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
 
 
 /*
@@ -40,23 +49,26 @@ void YSoundShutdown(Recorder *recorder);
 int YSoundInit(Recorder *recorder, Audio *audio)
 {
 	int status;
-        Sound *sound_ptr;
-        Audio *audio_ptr;
+	Sound *sound_ptr;
+	Audio *audio_ptr;
 	MIDIAudio *midi_audio_ptr;
+#ifdef YSHM_SUPPORT
+	int shm_id;
+#endif
 #ifdef OSS_BUFFRAG
 	unsigned int fragment, num_fragments, fragment_size;
 	int buffer_size;
 #endif	/* OSS_BUFFRAG */
+/*	struct mixer_info mixer_info_buf; */
+	struct synth_info synth_info_buf;
 
 
-	if((recorder == NULL) ||
-	   (audio == NULL)
-	)
-            return(-1);
+	if((recorder == NULL) || (audio == NULL))
+	    return(-1);
 
-        /* Get pointers to substructures on recorder. */
-        sound_ptr = &recorder->sound;
-        audio_ptr = &recorder->audio;
+	/* Get pointers to substructures on recorder. */
+	sound_ptr = &recorder->sound;
+	audio_ptr = &recorder->audio;
 	midi_audio_ptr = &recorder->audio.midi_audio;
 
 	/* Reset recorder values. */
@@ -66,47 +78,49 @@ int YSoundInit(Recorder *recorder, Audio *audio)
 
 
 	/* Get values from input Audio structure. */
-        sound_ptr->buffer_length = 0;
-        sound_ptr->buffer_content_length = 0;
+	sound_ptr->buffer_length = 0;
+	sound_ptr->buffer_content_length = 0;
 
-        sound_ptr->device_buffer_length = 0;
-        sound_ptr->device_buffer_content_length = 0;
+	sound_ptr->device_buffer_length = 0;
+	sound_ptr->device_buffer_content_length = 0;
 
-        audio_ptr->cycle_set = audio->cycle_set;
+	audio_ptr->cycle_set = audio->cycle_set;
 
-        audio_ptr->cycle.ms = audio->cycle.ms;
-        audio_ptr->cycle.us = audio->cycle.us;
-        audio_ptr->compensated_cycle.ms = audio_ptr->cycle.ms;
-        audio_ptr->compensated_cycle.us = audio_ptr->cycle.us;
+	audio_ptr->cycle.ms = audio->cycle.ms;
+	audio_ptr->cycle.us = audio->cycle.us;
+	audio_ptr->compensated_cycle.ms = audio_ptr->cycle.ms;
+	audio_ptr->compensated_cycle.us = audio_ptr->cycle.us;
 
-        audio_ptr->write_ahead.ms = audio->write_ahead.ms;
-        audio_ptr->write_ahead.us = audio->write_ahead.us;
+	audio_ptr->write_ahead.ms = audio->write_ahead.ms;
+	audio_ptr->write_ahead.us = audio->write_ahead.us;
 
-        audio_ptr->cycle_ahead_left.ms = audio->write_ahead.ms;
-        audio_ptr->cycle_ahead_left.us = audio->write_ahead.us;
+	audio_ptr->cycle_ahead_left.ms = audio->write_ahead.ms;
+	audio_ptr->cycle_ahead_left.us = audio->write_ahead.us;
 
-        audio_ptr->cumulative_latency.ms = 0;
-        audio_ptr->cumulative_latency.us = 0;
-        
-        audio_ptr->sample_size = audio->sample_size;
-        audio_ptr->channels = audio->channels;  
-        audio_ptr->sample_rate = audio->sample_rate;
-        audio_ptr->bytes_per_second = audio->sample_rate *
-            MAX((audio->sample_size / 8), 1)
-        ;
+	audio_ptr->cumulative_latency.ms = 0;
+	audio_ptr->cumulative_latency.us = 0;
+	
+	audio_ptr->sample_size = audio->sample_size;
+	audio_ptr->channels = audio->channels;  
+	audio_ptr->sample_rate = audio->sample_rate;
+	audio_ptr->bytes_per_second = audio->sample_rate *
+	    MAX((audio->sample_size / 8), 1)
+	;
 
 #ifdef OSS_BUFFRAG
-        audio_ptr->allow_fragments = audio->allow_fragments;
-        audio_ptr->num_fragments = audio->num_fragments;  
-        audio_ptr->fragment_size = audio->fragment_size;  
+	audio_ptr->allow_fragments = audio->allow_fragments;
+	audio_ptr->num_fragments = audio->num_fragments;  
+	audio_ptr->fragment_size = audio->fragment_size;  
 #endif  /* OSS_BUFFRAG */
 
-        audio_ptr->flip_stereo = audio->flip_stereo;
+	audio_ptr->flip_stereo = audio->flip_stereo;
 
-        audio_ptr->direction = audio->direction;
+	audio_ptr->direction = audio->direction;
 	audio_ptr->audio_mode_name = NULL;
-        audio_ptr->fd = -1;
-        audio_ptr->mixer_fd = -1;
+	audio_ptr->fd = -1;
+	audio_ptr->mixer_fd = -1;
+
+	audio_ptr->sound_name = NULL;
 
 	audio_ptr->shelled_out = False;
 
@@ -114,7 +128,7 @@ int YSoundInit(Recorder *recorder, Audio *audio)
 	/* ******************************************************** */
 	/* Initialize MIDI IO resources. */
 #ifdef ALSA_RUN_CONFORM
-        midi_audio_ptr->midi_device_number = MAX(
+	midi_audio_ptr->midi_device_number = MAX(
 	    option.midi_device_number, 0
 	);
 #endif	/* ALSA_RUN_CONFORM */
@@ -124,7 +138,11 @@ int YSoundInit(Recorder *recorder, Audio *audio)
 	    return(-1);
 	}
 
-        /* ******************************************************** */
+	/* ******************************************************** */
+	/* Initialize audio CD context. */
+	audio_ptr->audiocd_context = AudioCDInit();
+
+	/* ******************************************************** */
 	/* Open audio device. */
 	audio_ptr->fd = open(
 	    fname.device,
@@ -132,7 +150,7 @@ int YSoundInit(Recorder *recorder, Audio *audio)
 		O_RDONLY : O_WRONLY
 	    )
 	);
-        if(audio_ptr->fd < 0)
+	if(audio_ptr->fd < 0)
 	{
 	    fprintf(
 		stderr,
@@ -150,12 +168,12 @@ int YSoundInit(Recorder *recorder, Audio *audio)
 	/* Open mixer. */
 	if(fname.mixer[0] != '\0')
 	{
-            audio_ptr->mixer_fd = open(
-                fname.mixer,
+	    audio_ptr->mixer_fd = open(
+		fname.mixer,
 	        O_RDWR
-            );
-            if(audio_ptr->mixer_fd < 0)
-            {
+	    );
+	    if(audio_ptr->mixer_fd < 0)
+	    {
 		/* Warn about failure to open mixer, do not fail
 		 * entire procedure.
 		 */
@@ -169,32 +187,32 @@ int YSoundInit(Recorder *recorder, Audio *audio)
 	{
 	    /* No mixer specified. */
 	    audio_ptr->mixer_fd = -1;
-        }
+	}
 
 
 #ifdef OSS_BUFFRAG
-        /*
-         * OSS ioctl() call SNDCTL_DSP_SETFRAGMENT:
-         *
-         * Accepts an int parameter which has format 0x00nn00ss where
-         * the nn is max number of buffer fragments (between 0x02 and 0xff)
-         * and the ss gives indirectly the size of a buffer fragment
-         * (fragment_size = (1 << ss)). Valid sizes are between
-         * (ss=0x07 -> 128 bytes and ss=0x11 (17 dec) -> 128k).
-         *
-         *      Linux documentation suggestion: 0x00020009
-         *      XBlast Sound Server: 0x0004000a
-         */
-        if(audio_ptr->allow_fragments)
-        {
+	/*
+	 * OSS ioctl() call SNDCTL_DSP_SETFRAGMENT:
+	 *
+	 * Accepts an int parameter which has format 0x00nn00ss where
+	 * the nn is max number of buffer fragments (between 0x02 and 0xff)
+	 * and the ss gives indirectly the size of a buffer fragment
+	 * (fragment_size = (1 << ss)). Valid sizes are between
+	 * (ss=0x07 -> 128 bytes and ss=0x11 (17 dec) -> 128k).
+	 *
+	 *      Linux documentation suggestion: 0x00020009
+	 *      XBlast Sound Server: 0x0004000a
+	 */
+	if(audio_ptr->allow_fragments)
+	{
 	    num_fragments = audio_ptr->num_fragments;
 	    fragment_size = audio_ptr->fragment_size;
 
 	    /* Pack fragment argument. */
-            fragment = (num_fragments << 16) | fragment_size;
+	    fragment = (num_fragments << 16) | fragment_size;
 
 	    /* Set new fragment parameters. */
-            status = ioctl(
+	    status = ioctl(
 		audio_ptr->fd,
 		SNDCTL_DSP_SETFRAGMENT,
 		&fragment
@@ -206,48 +224,48 @@ int YSoundInit(Recorder *recorder, Audio *audio)
 		    fname.device, fragment
 		);
 	    }
-        }
+	}
 #endif  /* OSS_BUFFRAG */ 
 
 
-        /* Set sample format (aka sample size or number of bits). */
-        if(ioctl(
+	/* Set sample format (aka sample size or number of bits). */
+	if(ioctl(
 	    audio_ptr->fd,
 	    SNDCTL_DSP_SAMPLESIZE,
 	    &audio_ptr->sample_size
 	) == -1)
-        {
-            fprintf(stderr,
-                "%s: Warning: Cannot set sample size to %i bits.\n",
-                fname.device, audio_ptr->sample_size
-            );
-        }
+	{
+	    fprintf(stderr,
+		"%s: Warning: Cannot set sample size to %i bits.\n",
+		fname.device, audio_ptr->sample_size
+	    );
+	}
 
 	/* Set channels (1 or 2, mono or stereo respectivly). */
 	if(ioctl(
-            audio_ptr->fd,
+	    audio_ptr->fd,
 	    SNDCTL_DSP_CHANNELS,
 	    &audio_ptr->channels
 	) == -1)
 	{
-            fprintf(stderr,
-                "%s: Warning: Cannot set channels to %i.\n",
-                fname.device, audio_ptr->channels
-            );
+	    fprintf(stderr,
+		"%s: Warning: Cannot set channels to %i.\n",
+		fname.device, audio_ptr->channels
+	    );
 	}
 
-        /* Set sample rate. */
-        if(ioctl(
-            audio_ptr->fd,
-            SNDCTL_DSP_SPEED,   /* aka SOUND_PCM_WRITE_RATE. */
-            &audio_ptr->sample_rate
-        ) == -1)
-        {
-            fprintf(stderr,
-                "%s: Warning: Cannot set sample rate to %i Hz.\n",
-                fname.device, audio_ptr->sample_rate
-            );
-        }
+	/* Set sample rate. */
+	if(ioctl(
+	    audio_ptr->fd,
+	    SNDCTL_DSP_SPEED,   /* aka SOUND_PCM_WRITE_RATE. */
+	    &audio_ptr->sample_rate
+	) == -1)
+	{
+	    fprintf(stderr,
+		"%s: Warning: Cannot set sample rate to %i Hz.\n",
+		fname.device, audio_ptr->sample_rate
+	    );
+	}
 
 
 /* Query audio format. */
@@ -257,29 +275,28 @@ printf("Format: %i\n", status);
  */
 
 #ifdef OSS_BUFFRAG
-        /*
-         * OSS requires exact audio buffer segment size (because
-	 * of fragmented buffers).
+	/* OSS requires exact audio buffer segment size (because of the
+	 * fragmented buffers).
 	 *
-         * All write()s to the device must have a buffer of exactly this
-         * size.   SNDCTL_DSP_GETBLKSIZE must be called after
+	 * All write()'s to the device must have a buffer of exactly
+	 * this size.  SNDCTL_DSP_GETBLKSIZE must be called after
 	 * SNDCTL_DSP_SETFRAGMENT.
-         */
-        status = ioctl(
+	 */
+	status = ioctl(
 	    audio_ptr->fd,
 	    SNDCTL_DSP_GETBLKSIZE,
 	    &buffer_size
 	);
 	if(status == -1)
 	{
-            fprintf(stderr,
-                "%s: Warning: Cannot get buffer size.\n",
-                fname.device
-            );
+	    fprintf(stderr,
+		"%s: Warning: Cannot get buffer size.\n",
+		fname.device
+	    );
 	}
 
-        sound_ptr->buffer_length = buffer_size;
-        sound_ptr->device_buffer_length = buffer_size;
+	sound_ptr->buffer_length = buffer_size;
+	sound_ptr->device_buffer_length = buffer_size;
 
 
 	/*   Calculate theoretical and compensated cycle.
@@ -289,26 +306,26 @@ printf("Format: %i\n", status);
 	 */
 	if(audio_ptr->cycle_set == CYCLE_SET_HARDWARE)
 	{
-            audio_ptr->cycle.ms =
-                (int)sound_ptr->buffer_length *
-                1000 / (int)audio_ptr->sample_rate /
+	    audio_ptr->cycle.ms =
+		(int)sound_ptr->buffer_length *
+		1000 / (int)audio_ptr->sample_rate /
 	        MAX(((int)audio_ptr->sample_size / 8), 1);
-            audio_ptr->cycle.us =
-                (double)sound_ptr->buffer_length /
-                (double)audio_ptr->sample_rate * 1000000 /
-                MAX(((int)audio_ptr->sample_size / 8), 1);
+	    audio_ptr->cycle.us =
+		(double)sound_ptr->buffer_length /
+		(double)audio_ptr->sample_rate * 1000000 /
+		MAX(((int)audio_ptr->sample_size / 8), 1);
 	    audio_ptr->cycle.us = audio_ptr->cycle.us -
 	        (audio_ptr->cycle.ms * 1000);
 
 	    /* For now, compensated is the same as theoretical. */
-            audio_ptr->compensated_cycle.ms = audio_ptr->cycle.ms;
-            audio_ptr->compensated_cycle.us = audio_ptr->cycle.us;
+	    audio_ptr->compensated_cycle.ms = audio_ptr->cycle.ms;
+	    audio_ptr->compensated_cycle.us = audio_ptr->cycle.us;
 	}
 
 	/* Not sure what this is... divides fragment segments? */
 /*
-        status = 4;
-        ioctl(audio_ptr->fd, SOUND_PCM_SUBDIVIDE, &status);
+	status = 4;
+	ioctl(audio_ptr->fd, SOUND_PCM_SUBDIVIDE, &status);
  */
 
 #endif	/* OSS_BUFFRAG */
@@ -316,26 +333,57 @@ printf("Format: %i\n", status);
 
 
 	/* ********************************************************** */
-        /* Allocate buffers. */
+	/* Allocate "midway" Sound buffer. */
+#ifdef YSHM_SUPPORT
+	sound_ptr->buffer = (SoundBuffer *)SHMNew(
+	    sound_ptr->buffer_length * sizeof(SoundBuffer),
+	    &shm_id
+	);
+	sound_ptr->buffer_shm_id = shm_id;
+#else
 	sound_ptr->buffer = (SoundBuffer *)calloc(
 	    sound_ptr->buffer_length,
 	    sizeof(SoundBuffer)
 	);
+#endif	/* YSHM_SUPPORT */
 	if(sound_ptr->buffer == NULL)
 	{
-            YSoundShutdown(recorder);
+	    YSoundShutdown(recorder);
 	    return(-1);
 	}
 
-        sound_ptr->device_buffer = (SoundBuffer *)calloc(  
-            sound_ptr->device_buffer_length,
-            sizeof(SoundBuffer)
-        );
-        if(sound_ptr->device_buffer == NULL)
-        {
-            YSoundShutdown(recorder);
-            return(-1);
-        }
+	/* Allocate Sound buffer shared with the actual DSP device. */
+	sound_ptr->device_buffer = (SoundBuffer *)calloc(  
+	    sound_ptr->device_buffer_length,
+	    sizeof(SoundBuffer)
+	);
+	if(sound_ptr->device_buffer == NULL)
+	{
+	    YSoundShutdown(recorder);
+	    return(-1);
+	}
+
+
+	/* Get sound name. */
+/*
+	status = ioctl(
+	    audio_ptr->fd, SOUND_MIXER_INFO, &mixer_info_buf
+	);
+	if(status != -1)
+	{
+	    free(audio_ptr->sound_name);
+	    audio_ptr->sound_name = strdup(mixer_info_buf.name);
+	}
+ */
+	synth_info_buf.device = 0;
+	status = ioctl(
+	    audio_ptr->fd, SNDCTL_SYNTH_INFO, &synth_info_buf
+	);
+	if(status != -1)
+	{
+	    free(audio_ptr->sound_name);
+	    audio_ptr->sound_name = strdup(synth_info_buf.name);
+	}
 
 
 	/* Caliberate cycle (only if cycle is to be set by program). */
@@ -359,7 +407,7 @@ fprintf(stderr, "Channels: %i  Bits: %i  Sample Rate: %i\n",
 */
 
 
-        return(0);
+	return(0);
 }
 
 /*
@@ -414,8 +462,8 @@ void YSoundCaliberateCycle(Recorder *recorder)
 	int i, fd;
 	time_t prev_delta_u, delta_u;
 
-        Sound *sound_ptr;
-        Audio *audio_ptr;
+	Sound *sound_ptr;
+	Audio *audio_ptr;
 	YTime start_time, end_time;
 
 	SoundBuffer *buf;
@@ -425,9 +473,9 @@ void YSoundCaliberateCycle(Recorder *recorder)
 	if(recorder == NULL)
 	    return;
 
-        /* Get pointers to substructures. */
-        sound_ptr = &recorder->sound; 
-        audio_ptr = &recorder->audio; 
+	/* Get pointers to substructures. */
+	sound_ptr = &recorder->sound; 
+	audio_ptr = &recorder->audio; 
 
 	/* Not allow program to set cycle? */
 	if(audio_ptr->cycle_set != CYCLE_SET_PROGRAM)
@@ -453,31 +501,31 @@ void YSoundCaliberateCycle(Recorder *recorder)
 	/*   Sync in case audio is still playing.  Otherwise
 	 *   the average cycle calculated is garbage.
 	 */
-        ioctl(recorder->audio.fd, SNDCTL_DSP_SYNC, 0);
+	ioctl(recorder->audio.fd, SNDCTL_DSP_SYNC, 0);
 
 	/*   Write and sync a couple of times, get average cycle
 	 *   value.
 	 */
-        GetCurrentTime(&start_time);
-        write(fd, buf, buf_len);
-        ioctl(recorder->audio.fd, SNDCTL_DSP_SYNC, 0);
-        GetCurrentTime(&end_time);
+	GetCurrentTime(&start_time);
+	write(fd, buf, buf_len);
+	ioctl(recorder->audio.fd, SNDCTL_DSP_SYNC, 0);
+	GetCurrentTime(&end_time);
 
-        delta_u = MAX(((end_time.ms * 1000) + end_time.us) -
-                      ((start_time.ms * 1000) + start_time.us), 0
-                  );
+	delta_u = MAX(((end_time.ms * 1000) + end_time.us) -
+		      ((start_time.ms * 1000) + start_time.us), 0
+		  );
 	prev_delta_u = delta_u;
 
 	for(i = 0; i < TOTAL_SYNC_PASSES; i++)
 	{
 	    GetCurrentTime(&start_time);
-            write(fd, buf, buf_len);
-            ioctl(recorder->audio.fd, SNDCTL_DSP_SYNC, 0);
+	    write(fd, buf, buf_len);
+	    ioctl(recorder->audio.fd, SNDCTL_DSP_SYNC, 0);
 	    GetCurrentTime(&end_time);
 
 	    delta_u = MAX(((end_time.ms * 1000) + end_time.us) -
-                          ((start_time.ms * 1000) + start_time.us), 0
-                      );
+			  ((start_time.ms * 1000) + start_time.us), 0
+		      );
 
 	    /* Average it. */
 	    delta_u = (prev_delta_u + delta_u) / 2;
@@ -487,11 +535,8 @@ void YSoundCaliberateCycle(Recorder *recorder)
 	audio_ptr->cycle.ms = delta_u / 1000;
 	audio_ptr->cycle.us = delta_u % 1000;
 
-        audio_ptr->compensated_cycle.ms = audio_ptr->cycle.ms;
-        audio_ptr->compensated_cycle.us = audio_ptr->cycle.us;
-
-
-	return;
+	audio_ptr->compensated_cycle.ms = audio_ptr->cycle.ms;
+	audio_ptr->compensated_cycle.us = audio_ptr->cycle.us;
 }
 
 
@@ -504,15 +549,15 @@ int YSoundPlayBuffer(Recorder *recorder)
 {
 	int bytes_written;
 	Sound *sound_ptr;
-        Audio *audio_ptr;
+	Audio *audio_ptr;
 
 
-        if(recorder == NULL)
-            return(-1);
+	if(recorder == NULL)
+	    return(-1);
 
-        /* Get pointers to substructures. */
-        sound_ptr = &recorder->sound;
-        audio_ptr = &recorder->audio;
+	/* Get pointers to substructures. */
+	sound_ptr = &recorder->sound;
+	audio_ptr = &recorder->audio;
 
 
 	/* Check if DSP device is opened. If it is not, then still
@@ -524,15 +569,15 @@ int YSoundPlayBuffer(Recorder *recorder)
 
 	/* Make sure buffers are allocated. */
 	if((sound_ptr->buffer == NULL) ||
-           (sound_ptr->device_buffer == NULL)
+	   (sound_ptr->device_buffer == NULL)
 	)
 	    return(-1);
 
 	/* **************************************************** */
 	/* Copy buffer to device_buffer. */
 
-        memcpy(
-            sound_ptr->device_buffer,		/* target. */
+	memcpy(
+	    sound_ptr->device_buffer,		/* target. */
 	    sound_ptr->buffer,			/* source. */
 	    MIN(sound_ptr->buffer_length,
 	        sound_ptr->device_buffer_length
@@ -548,7 +593,7 @@ int YSoundPlayBuffer(Recorder *recorder)
 
 
 	/* Clear midway buffer. */
-        memset(
+	memset(
 	    sound_ptr->buffer,
 	    (SoundBuffer)0x00,
 	    sound_ptr->buffer_length
@@ -567,8 +612,8 @@ void YSoundSync(Recorder *recorder, int options)
 	Audio *audio_ptr;
 
 
-        if(recorder == NULL)
-            return;
+	if(recorder == NULL)
+	    return;
 
 	audio_ptr = &recorder->audio;
 
@@ -576,17 +621,17 @@ void YSoundSync(Recorder *recorder, int options)
 	/* Tell DSP device to sync if it's opened. */
 	if(audio_ptr->fd > -1)
 	{
-            /* Sync and end any current playback or recording for
+	    /* Sync and end any current playback or recording for
 	     * the DSP device.
 	     */
-            ioctl(audio_ptr->fd, SNDCTL_DSP_SYNC, 0);
+	    ioctl(audio_ptr->fd, SNDCTL_DSP_SYNC, 0);
 	}
 
 	/* Reset cycle ahead time, so writes to the DSP
 	 * device are performed more frequently for a while.
 	 */
-        audio_ptr->cycle_ahead_left.ms = audio_ptr->write_ahead.ms;
-        audio_ptr->cycle_ahead_left.us = audio_ptr->write_ahead.us;
+	audio_ptr->cycle_ahead_left.ms = audio_ptr->write_ahead.ms;
+	audio_ptr->cycle_ahead_left.us = audio_ptr->write_ahead.us;
 
 /*
 fprintf(stderr,
@@ -595,8 +640,6 @@ fprintf(stderr,
  audio_ptr->cycle_ahead_left.us)
 );
  */
-
-	return;
 }
 
 /*
@@ -623,60 +666,68 @@ void YSoundShutdown(Recorder *recorder)
 	/* Shutdown MIDI IO resources. */
 	MIDIIOWShutdown(midi_audio_ptr);
 
+	/* Shutdown audio CD context. */
+	AudioCDShutdown(audio_ptr->audiocd_context);
+	audio_ptr->audiocd_context = NULL;
+
 
 	/* Close recorder's audio device as needed. */
-        if(audio_ptr->fd > -1)
+	if(audio_ptr->fd > -1)
 	{
-            /* Wait for sound to finish playing. */
-            ioctl(audio_ptr->fd, SNDCTL_DSP_SYNC, 0);
+	    /* Wait for sound to finish playing. */
+	    ioctl(audio_ptr->fd, SNDCTL_DSP_SYNC, 0);
 
-            close(audio_ptr->fd);
-            audio_ptr->fd = -1;
+	    close(audio_ptr->fd);
+	    audio_ptr->fd = -1;
 	}
 
 	/* Close recorder's mixer as needed. */
 	if(audio_ptr->mixer_fd > -1)
 	{
-            close(audio_ptr->mixer_fd);
-            audio_ptr->mixer_fd = -1;
+	    close(audio_ptr->mixer_fd);
+	    audio_ptr->mixer_fd = -1;
 	}
 
 
 	/* Free allocated substructures. */
+#ifdef YSHM_SUPPORT
+	SHMUnref(sound_ptr->buffer);
+#else
 	free(sound_ptr->buffer);
+#endif
 	sound_ptr->buffer = NULL;
 	sound_ptr->buffer_length = 0;
 	sound_ptr->buffer_content_length = 0;
 
-        free(sound_ptr->buffer);
-        sound_ptr->device_buffer = NULL;
-        sound_ptr->device_buffer_length = 0;
-        sound_ptr->device_buffer_content_length = 0;
+	free(sound_ptr->device_buffer);
+	sound_ptr->device_buffer = NULL;
+	sound_ptr->device_buffer_length = 0;
+	sound_ptr->device_buffer_content_length = 0;
 
 	memset(&audio_ptr->cycle, 0, sizeof(YDeltaTime));
-        memset(&audio_ptr->compensated_cycle, 0, sizeof(YDeltaTime));
+	memset(&audio_ptr->compensated_cycle, 0, sizeof(YDeltaTime));
 
-        memset(&audio_ptr->write_ahead, 0, sizeof(YDeltaTime));
+	memset(&audio_ptr->write_ahead, 0, sizeof(YDeltaTime));
 	memset(&audio_ptr->cycle_ahead_left, 0, sizeof(YDeltaTime));
-        memset(&audio_ptr->cumulative_latency, 0, sizeof(YDeltaTime));
+	memset(&audio_ptr->cumulative_latency, 0, sizeof(YDeltaTime));
 
 	audio_ptr->sample_size = 0;
-        audio_ptr->channels = 0;
-        audio_ptr->sample_rate = 0;
-        audio_ptr->bytes_per_second = 0;
+	audio_ptr->channels = 0;
+	audio_ptr->sample_rate = 0;
+	audio_ptr->bytes_per_second = 0;
 
 #ifdef OSS_BUFFRAG
-        audio_ptr->allow_fragments = False;
-        audio_ptr->num_fragments = 0;
-        audio_ptr->fragment_size = 0;
+	audio_ptr->allow_fragments = False;
+	audio_ptr->num_fragments = 0;
+	audio_ptr->fragment_size = 0;
 #endif /* OSS_BUFFRAG */
 
-        audio_ptr->flip_stereo = False;
+	audio_ptr->flip_stereo = False;
 	free(audio_ptr->audio_mode_name);
 	audio_ptr->audio_mode_name = NULL;
 	audio_ptr->fd = -1;
 	audio_ptr->mixer_fd = -1;
-
-
-	return;
+	free(audio_ptr->sound_name);
+	audio_ptr->sound_name = NULL;
+	audio_ptr->shelled_out = False;
 }
