@@ -1,6 +1,16 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 
+/*
+ *      Languages (define only one):
+ */
+#define PROG_LANGUAGE_ENGLISH   1
+/* #define PROG_LANGUAGE_SPANISH        2 */
+/* #define PROG_LANGUAGE_FRENCH         3 */
+/* *incomplete* #define PROG_LANGUAGE_GERMAN    4 */
+/* *incomplete* #define PROG_LANGUAGE_ITALIAN   5 */
+/* *incomplete* #define PROG_LANGUAGE_NORWEGIAN 6 */
+/* *incomplete* #define PROG_LANGUAGE_PORTUGUESE        7 */
 
 /*
  *	Default YIFF Sound Server configuration file:
