@@ -5,21 +5,16 @@
 #ifndef PSTEPPER_H
 #define PSTEPPER_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
-#ifndef gbool
-# define gbool	gboolean
-#endif
-
 
 /*
  *	Page stepper structure:
  */
 typedef struct {
 
-	gbool initialized;
-	gbool map_state;
+	gboolean initialized;
+	gboolean map_state;
 
 	GtkAccelGroup *accelgrp;
 
@@ -34,7 +29,7 @@ typedef struct {
 	gint total_pages;
 
 	/* Array of page and nariative client set toplevel widgets.
-	 * Allocation size of array indicated by total_pages.
+	 * Allocation size of array indicated by total_pages
 	 */
 	GtkWidget **page;
 	GtkWidget **nariative_strip;
@@ -46,26 +41,26 @@ typedef struct {
 
 	/* Array of callback function pointers which correspond to
 	 * each page. Callback inputs are; page stepper pointer,
-	 * prev page, new page, client data.
+	 * prev page, new page, client data
 	 * void (*page_cb)(gpointer, gint, gint, gpointer)
 	 */
 	void **page_cb;
 
-	/* Exit client data and callback. */
+	/* Exit client data and callback */
 	gpointer exit_client_data;
 	void (*exit_cb)(gpointer, gint, gpointer);
 
-	/* Finish client data and callback. */
+	/* Finish client data and callback */
 	gpointer finish_client_data;
         void (*finish_cb)(gpointer, gint, gpointer);
 
-	/* Label text used for back/exit button. */
+	/* Label text used for back/exit button */
 	gchar *back_text, *exit_text;
 
-	/* Label text used for next/finish button. */
+	/* Label text used for next/finish button */
 	gchar *next_text, *finish_text;
 
-	/* Back/exit and next/finish buttons. */
+	/* Back/exit and next/finish buttons */
 	GtkWidget *back_btn, *back_btn_label;
 	GtkWidget *next_btn, *next_btn_label;
 
@@ -76,7 +71,7 @@ extern pstepper_struct *PStepperCreate(
 	gchar *title,
 	const gchar *back_text, const gchar *exit_text,
 	const gchar *next_text, const gchar *finish_text,
-	gint width, gint height,		/* Can be 0. */
+	gint width, gint height,		/* Can be 0 */
 	gpointer exit_client_data,
 	void (*exit_cb)(gpointer, gint, gpointer),
 	gpointer finish_client_data,
@@ -90,7 +85,7 @@ extern gint PStepperAppend(
 );
 extern void PStepperChangePage(
 	pstepper_struct *ps, gint page_num,
-        gbool report_change
+        gboolean report_change
 );
 extern gint PStepperGetPage(pstepper_struct *ps);
 extern void PStepperMap(pstepper_struct *ps);
