@@ -1,13 +1,12 @@
 /*
-                      YIFF Configuration Wizard
+                         YIFF Configuration Wizard
 
-        Copyright (C) 1997-2003 WolfPack Entertainment
+               Copyright (C) 1997-2004 WolfPack Entertainment
  */
 
 #ifndef YC_H
 #define YC_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
 #include "../include/Y2/Y.h"
@@ -16,27 +15,23 @@
 #include "fb.h"
 #include "pstepper.h"
 
-#ifndef gbool
-# define gbool	boolean
-#endif
-
 
 /*
  *	Program name and version:
  */
 #define PROG_NAME	"YIFF Configuration Wizard"
-#define PROG_VERSION	"2.14.2"
+#define PROG_VERSION	"2.14.5"
 
 #define PROG_VERSION_MAJOR	2
 #define PROG_VERSION_MINOR	14
-#define PROG_VERSION_RELEASE	2
+#define PROG_VERSION_RELEASE	5
 
 
 /*
  *      Program copyright:
  */
 #define PROG_COPYRIGHT  "\
-Copyright (C) 1997-2003 WolfPack Entertainment.\n\
+Copyright (C) 1997-2005 WolfPack Entertainment.\n\
 This program is protected by international copyright laws and treaties,\n\
 distribution and/or modification of this software in violation of the\n\
 GNU Public License is strictly prohibited. Violators will be prosecuted\n\
@@ -114,18 +109,18 @@ typedef struct {
 
 	gchar *name;
 
-	gint sample_rate;		/* In Hz. */
-	gint channels;			/* 1 or 2. */
-        gint sample_size;		/* 8 or 16. */
-        gint fragment_size_bytes;	/* In bytes. */
+	gint sample_rate;		/* In Hz */
+	gint channels;			/* 1 or 2 */
+        gint sample_size;		/* 8 or 16 */
+        gint fragment_size_bytes;	/* In bytes */
 	gint direction;
-	gbool allow_fragmenting;	/* True if fragmenting allowed. */
-	gint num_fragments;		/* Number of fragments. */
+	gboolean allow_fragmenting;	/* True if fragmenting allowed */
+	gint num_fragments;		/* Number of fragments */
 
-	gbool flip_stereo;
+	gboolean flip_stereo;
 
-	glong cycle_us;			/* In microseconds. */
-        glong write_ahead_us;		/* In microseconds. */
+	glong cycle_us;			/* In microseconds */
+        glong write_ahead_us;		/* In microseconds */
 
 } yc_ymode_data_struct;
 
@@ -134,12 +129,12 @@ typedef struct {
  *	Page numbers, these must be from 0 to one less than YC_PAGES_MAX:
  */
 #define YC_PAGE_NUM_WELCOME		0
-#define YC_PAGE_NUM_LOCATIONS		1	/* Paths, address, port... */
-#define YC_PAGE_NUM_YMODES		2	/* Y Audio modes. */
-#define YC_PAGE_NUM_TIMINGS		3	/* Ie refresh interval. */
+#define YC_PAGE_NUM_LOCATIONS		1	/* Paths, address, port.. */
+#define YC_PAGE_NUM_YMODES		2	/* Y Audio modes */
+#define YC_PAGE_NUM_TIMINGS		3	/* Ie refresh interval */
 #define YC_PAGE_NUM_MIDI		4
-#define YC_PAGE_NUM_YSOUNDPATHS		5	/* YSound paths. */
-#define YC_PAGE_NUM_CONFERM		6	/* Confermations page. */
+#define YC_PAGE_NUM_YSOUNDPATHS		5	/* YSound paths */
+#define YC_PAGE_NUM_CONFERM		6	/* Confermations page */
 #define YC_PAGE_NUM_FINISHED		7
 
 /*
@@ -153,42 +148,44 @@ typedef struct {
  */
 typedef struct {
 
-	gbool initialized;
-	gbool show_tool_tips;
-	gbool has_changes;
+	GtkWidget *toplevel;
 
-	/* Connection to Y sound server. */
+	gboolean initialized;
+	gboolean show_tool_tips;
+	gboolean has_changes;
+
+	/* Connection to Y sound server */
 	YConnection *recorder;
 
-	/* Default file browser file extension types list. */
+	/* Default file browser file extension types list */
 	fb_type_struct **ftype;
 	gint total_ftypes;
 
-	/* Page stepper widget. */
+	/* Page stepper widget */
 	pstepper_struct *ps;
 
 
-	/* These are the widgets for each nariative strip. */
+	/* These are the widgets for each nariative strip */
 
-	/* ...none for now. */
+	/* ...none for now */
 
 
-	/* These are the widgets for each page. */
-	/* On page YC_PAGE_NUM_WELCOME... */
-	/* On page YC_PAGE_NUM_LOCATIONS... */
+	/* These are the widgets for each page */
+	/* On page YC_PAGE_NUM_WELCOME.. */
+	/* On page YC_PAGE_NUM_LOCATIONS.. */
 	GtkWidget *yiff_configuration_file_entry;
-	GtkWidget *yiff_configuration_file_browse;	/* Browse button. */
+	GtkWidget *yiff_configuration_file_browse;	/* Browse button */
 	GtkWidget *yiff_program_entry;
-	GtkWidget *yiff_program_browse;			/* Browse button. */
+	GtkWidget *yiff_program_browse;			/* Browse button */
 	GtkWidget *dsp_device_entry;
-	GtkWidget *dsp_device_browse;			/* Browse button. */
+	GtkWidget *dsp_device_browse;			/* Browse button */
 	GtkWidget *mixer_device_entry;
-	GtkWidget *mixer_device_browse;			/* Browse button. */
+	GtkWidget *mixer_device_browse;			/* Browse button */
 	GtkWidget *address_entry;
 	GtkWidget *port_entry;
 	GtkWidget *yiff_start_toggle;		/* Start yiff server? */
-	/* On page YC_PAGE_NUM_YMODES... */
-	GtkWidget *ymodes_clist;	/* Loaded Y modes stored here. */
+	/* On page YC_PAGE_NUM_YMODES.. */
+	GtkWidget *ymodes_clist;	/* Loaded Y modes stored here */
 	GtkWidget *ymodes_menu;
         GtkWidget *ymodes_menu_add;
         GtkWidget *ymodes_menu_edit;
@@ -198,24 +195,24 @@ typedef struct {
 	GtkWidget *ymode_remove_btn;
 	GtkWidget *ymode_shift_up_btn;
 	GtkWidget *ymode_shift_down_btn;
-	GtkWidget *ymode_sample_rate_combo;	/* In Hz. */
-	GtkWidget *ymode_fragment_size_combo;	/* In bytes. */
+	GtkWidget *ymode_sample_rate_combo;	/* In Hz */
+	GtkWidget *ymode_fragment_size_combo;	/* In bytes */
         GtkWidget *ymode_channels1_radio;
 	GtkWidget *ymode_channels2_radio;
 	GtkWidget *ymode_sample_size8_radio;
 	GtkWidget *ymode_sample_size16_radio;
-	GtkWidget *ymode_cycle_spin;		/* In microseconds. */
+	GtkWidget *ymode_cycle_spin;		/* In microseconds */
 	GtkWidget *ymode_calculate_cycle_btn;
 	GtkWidget *ymode_apply_to_yiff_btn;
-	GtkWidget *ymode_play_btn;		/* Play a DSP sound. */
-	/* On page YC_PAGE_NUM_TIMINGS... */
-	GtkWidget *sound_refresh_spin;		/* In microseconds. */
-	/* On page YC_PAGE_NUM_MIDI... */
-	GtkWidget *midi_play_cmd_entry;		/* Command to play midi. */
-	GtkWidget *midi_play_cmd_browse;	/* Browse button. */
-	GtkWidget *alsa_midi_port_entry;	/* MIDI port number (ALSA only). */
-	/* On page YC_PAGE_NUM_YSOUNDPATHS... */
-	GtkWidget *ysound_paths_clist;		/* YSound paths stored here. */
+	GtkWidget *ymode_play_btn;		/* Play a DSP sound */
+	/* On page YC_PAGE_NUM_TIMINGS.. */
+	GtkWidget *sound_refresh_spin;		/* In microseconds */
+	/* On page YC_PAGE_NUM_MIDI.. */
+	GtkWidget *midi_play_cmd_entry;		/* Command to play midi */
+	GtkWidget *midi_play_cmd_browse;	/* Browse button */
+	GtkWidget *alsa_midi_port_entry;	/* MIDI port number (ALSA only) */
+	/* On page YC_PAGE_NUM_YSOUNDPATHS.. */
+	GtkWidget *ysound_paths_clist;		/* YSound paths stored here */
 	GtkWidget *ysound_paths_menu;
 	GtkWidget *ysound_paths_menu_add;
 	GtkWidget *ysound_paths_menu_edit;
@@ -225,20 +222,20 @@ typedef struct {
 	GtkWidget *ysound_paths_remove_btn;
 	GtkWidget *ysound_paths_shift_up_btn;
 	GtkWidget *ysound_paths_shift_down_btn;
-	/* On page YC_PAGE_NUM_CONFERM... */
+	/* On page YC_PAGE_NUM_CONFERM.. */
 	GtkWidget *conferm_items_clist;
 	GtkWidget *conferm_verbose_toggle;
 	GtkWidget *start_script_entry;
 	GtkWidget *start_script_browse;
 
 
-	/* Currently selected ymode item (row) number. */
+	/* Currently selected ymode item (row) number */
 	gint selected_ymode;
 
-	/* Currently selected ysound path item (row) number. */
+	/* Currently selected ysound path item (row) number */
 	gint selected_ysound_path;
 
-	/* Sound object currently being played (can be NULL). */
+	/* Sound object currently being played (can be NULL) */
 	YID current_sound_play;
 
 
@@ -263,8 +260,8 @@ extern gint YCManage(gpointer data);
 extern void YCShutdown(yc_core_struct *core_ptr);
 
 /* In yc.c */
-extern int YCCreate(
-	yc_struct *yc,
+extern gint YCCreate(
+	yc_struct *yc, gint argc, gchar **argv,
 	yc_styles_struct *styles, yc_pixmaps_struct *pixmaps
 );
 extern void YCYModesListDeleteAll(yc_struct *yc);
@@ -285,10 +282,10 @@ extern gint YCWidgetExposeCB(
         GtkWidget *widget, GdkEventExpose *event, gpointer data
 );
 
-extern void YCBrowseConfigurationFileCB(void *widget, void *data);
-extern void YCBrowseYIFFProgramCB(void *widget, void *data);
-extern void YCBrowseDSPDeviceCB(void *widget, void *data);
-extern void YCBrowseMixerDeviceCB(void *widget, void *data);
+extern void YCBrowseConfigurationFileCB(GtkWidget *widget, gpointer data);
+extern void YCBrowseYIFFProgramCB(GtkWidget *widget, gpointer data);
+extern void YCBrowseDSPDeviceCB(GtkWidget *widget, gpointer data);
+extern void YCBrowseMixerDeviceCB(GtkWidget *widget, gpointer data);
 
 extern gint YCYModesListMenuMapCB(
         GtkWidget *widget, GdkEvent *event, gpointer data
@@ -304,7 +301,7 @@ extern void YCYModeValuesApplyToYCB(GtkWidget *widget, gpointer data);
 extern void YCYModePlayCB(GtkWidget *widget, gpointer data);
 extern void YCRefreshIntSpinChangeCB(GtkWidget *widget, gpointer data);
 
-extern void YCBrowseMIDIPlayCmdCB(void *widget, void *data);
+extern void YCBrowseMIDIPlayCmdCB(GtkWidget *widget, gpointer data);
 
 extern gint YCYSoundPathsMenuMapCB(
         GtkWidget *widget, GdkEvent *event, gpointer data
@@ -320,14 +317,14 @@ extern void YCConfermationListSelectCB(
         GdkEventButton *event, gpointer data
 );
 extern void YCConfermVerboseToggleCB(GtkWidget *widget, gpointer data);
-extern void YCBrowseStartScriptCB(void *widget, void *data);
+extern void YCBrowseStartScriptCB(GtkWidget *widget, gpointer data);
 
 
 /* In ycfile.c */
-extern int YCLoadConfiguration(yc_struct *yc, const char *filename);
-extern int YCSaveConfiguration(yc_struct *yc, const char *filename);
+extern gint YCLoadConfiguration(yc_struct *yc, const gchar *filename);
+extern gint YCSaveConfiguration(yc_struct *yc, const gchar *filename);
 
-extern int YCSaveStartScript(yc_struct *yc, const char *filename);
+extern gint YCSaveStartScript(yc_struct *yc, const gchar *filename);
 
 
 /* In ycpagechange.c */
@@ -345,11 +342,11 @@ extern void YCYModeSetToWidgets(yc_struct *yc, yc_ymode_data_struct *buf);
 
 extern void YCConfermListRefresh(yc_struct *yc);
 
-extern int YCCheckInstallation(
+extern gint YCCheckInstallation(
         yc_struct *yc,
         const gchar *configuration_file,
         const gchar *yiff_program,
-        gbool report_problems
+        gboolean report_problems
 );
 
 
