@@ -2,8 +2,6 @@
 #include <malloc.h>
 #include <string.h>
 #include <stdlib.h>
-
-#include <sys/types.h>
 #include <sys/stat.h>
 
 #include <gtk/gtk.h>
@@ -24,11 +22,11 @@
 #include "config.h"
 
 
-int YCLoadConfiguration(yc_struct *yc, const char *filename);
+gint YCLoadConfiguration(yc_struct *yc, const gchar *filename);
 static void writehseparator(FILE *fp, int columns);
-int YCSaveConfiguration(yc_struct *yc, const char *filename);
+gint YCSaveConfiguration(yc_struct *yc, const gchar *filename);
 
-int YCSaveStartScript(yc_struct *yc, const char *filename);
+gint YCSaveStartScript(yc_struct *yc, const gchar *filename);
 
 
 #define MIN(a,b)        (((a) < (b)) ? (a) : (b))
@@ -45,14 +43,14 @@ int YCSaveStartScript(yc_struct *yc, const char *filename);
  *	-2   Minor file format inconsistancy.
  *      -3   Permission denied.
  */
-int YCLoadConfiguration(yc_struct *yc, const char *filename)
+gint YCLoadConfiguration(yc_struct *yc, const gchar *filename)
 {
-	char *strptr, *strptr2;
+	gchar *strptr, *strptr2;
 	FILE *fp;
 
-	int lines_read = 0;
-	char parm[CFG_PARAMETER_MAX];
-	char val[CFG_VALUE_MAX];
+	gint lines_read = 0;
+	gchar parm[CFG_PARAMETER_MAX];
+	gchar val[CFG_VALUE_MAX];
 
 	GtkWidget *w;
 	GtkCList *clist;
@@ -431,7 +429,7 @@ int YCLoadConfiguration(yc_struct *yc, const char *filename)
  */
 static void writehseparator(FILE *fp, int columns)
 {
-	int i;
+	gint i;
 
 	if(fp == NULL)
 	    return;
@@ -442,8 +440,6 @@ static void writehseparator(FILE *fp, int columns)
 	for(i = 0; i < columns; i++)
 	    fputc('#', fp);
 	fputc('\n', fp);
-
-	return;
 }
 
 /*
@@ -456,16 +452,13 @@ static void writehseparator(FILE *fp, int columns)
  *	-2   Value inconsistancy.
  *	-3   Permission denied.
  */
-int YCSaveConfiguration(yc_struct *yc, const char *filename)
+gint YCSaveConfiguration(yc_struct *yc, const gchar *filename)
 {
-	int i;
+	gint i, columns = 80;
 	FILE *fp;
 	GtkWidget *w;
 	GtkCList *clist;
 
-	int columns = 80;
-
-
 	if((yc == NULL) || (filename == NULL))
 	    return(-1);
 
