@@ -1,8 +1,5 @@
-#include <stdio.h>
-#include <malloc.h>
-#include <string.h>
 #include <stdlib.h>
-#include <sys/types.h>
+#include <string.h>
 #include <sys/stat.h>
 
 #include <gtk/gtk.h>
@@ -13,7 +10,6 @@
 #include "cdialog.h"
 
 #include "yc.h"
-
 #include "config.h"
 
 
@@ -34,7 +30,6 @@ void YCPageChange(yc_struct *yc, gint prev_page, gint new_page)
 {
 	GtkWidget *w;
 
-
 	if(yc == NULL)
 	    return;
 
@@ -46,7 +41,7 @@ void YCPageChange(yc_struct *yc, gint prev_page, gint new_page)
 
 	}
 	/* ******************************************************** */
-	/* Locations page. */
+	/* Locations page */
 	else if(new_page == YC_PAGE_NUM_LOCATIONS)
 	{
 	    /* Backward page change? */
@@ -60,7 +55,7 @@ void YCPageChange(yc_struct *yc, gint prev_page, gint new_page)
 	    }
 	}
 	/* ******************************************************** */
-	/* YModes page. */
+	/* YModes page */
 	else if(new_page == YC_PAGE_NUM_YMODES)
 	{
 	    /* Forward page change? */
@@ -79,7 +74,7 @@ void YCPageChange(yc_struct *yc, gint prev_page, gint new_page)
 			*mixer_device,
 			*address_str,
 			*port_str;
-		gbool configuration_load_succ = FALSE;
+		gboolean configuration_load_succ = FALSE;
 
 
 		/* Check installation with respect to the path values
@@ -87,9 +82,9 @@ void YCPageChange(yc_struct *yc, gint prev_page, gint new_page)
 		 */
 		YCCheckInstallation(
 		    yc,
-		    NULL,	/* YIFF configuration file location. */
-		    NULL,	/* YIFF program location. */
-		    TRUE	/* Report problems. */
+		    NULL,	/* YIFF configuration file location */
+		    NULL,	/* YIFF program location */
+		    TRUE	/* Report problems */
 		);
 
 
@@ -97,54 +92,54 @@ void YCPageChange(yc_struct *yc, gint prev_page, gint new_page)
 		 * preserve them after the configuration is loaded.
 		 */
 
-		/* YIFF Sound Server configuration file. */
+		/* YIFF Sound Server configuration file */
 		w = yc->yiff_configuration_file_entry;
 		if(w == NULL)
 		    strptr = NULL;
 		else
 		    strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		configuration_file = ((strptr == NULL) ?
-		    NULL : strdup(strptr)
+		    NULL : g_strdup(strptr)
 		);
 
-		/* DSP device path. */
+		/* DSP device path */
 		w = yc->dsp_device_entry;
 		if(w == NULL)
 		    strptr = NULL;
 		else
 		    strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		dsp_device = ((strptr == NULL) ?
-		    NULL : strdup(strptr)
+		    NULL : g_strdup(strptr)
 		);
 
-		/* Mixer device path. */
+		/* Mixer device path */
 		w = yc->mixer_device_entry;
 		if(w == NULL)
 		    strptr = NULL;
 		else
 		    strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		mixer_device = ((strptr == NULL) ?
-		    NULL : strdup(strptr)
+		    NULL : g_strdup(strptr)
 		);
 
-		/* Address (as a string). */
+		/* Address (as a string) */
 		w = yc->address_entry;
 		if(w == NULL)
 		    strptr = NULL;
 		else
 		    strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		address_str = ((strptr == NULL) ?
-		    NULL : strdup(strptr)
+		    NULL : g_strdup(strptr)
 		);
 
-		/* Port number (as a string). */
+		/* Port number (as a string) */
 		w = yc->port_entry;
 		if(w == NULL)
 		    strptr = NULL;
 		else
 		    strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		port_str = ((strptr == NULL) ?
-		    NULL : strdup(strptr)
+		    NULL : g_strdup(strptr)
 		);
 
 
@@ -159,80 +154,68 @@ void YCPageChange(yc_struct *yc, gint prev_page, gint new_page)
 		    if(stat(configuration_file, &stat_buf))
 		    {
 			/* No such file, prompt to create new one? */
-			char *buf;
-			int len;
-
-
-			len = strlen(configuration_file);
-			buf = (char *)malloc((len + 256) * sizeof(char));
-			if(buf != NULL)
-			{
-			    sprintf(
-				buf,
-"Configuration file '%s' does not exist,\n\
-create a new one?",
-				configuration_file
-			    );
-			    status = CDialogGetResponse(
-"Create new configuration file?",
-				buf,
+			gchar *buf = g_strdup_printf(
+"Create new configuration file:\n\
+\n\
+    %s\n",
+			    configuration_file
+			);
+			CDialogSetTransientFor(yc->toplevel);
+			status = CDialogGetResponse(
+"Create New Configuration File",
+			    buf,
 "The specified YIFF Sound Server configuration file\n\
 does not exist, you are being asked if you want to\n\
 create a new configuration file in the specified\n\
 location. If you feel that the given location is\n\
 incorrect, then say 'No' and click on 'Back' then\n\
 enter the correct location.",
-				CDIALOG_ICON_QUESTION,
-				CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO |
-				CDIALOG_BTNFLAG_HELP,
-				CDIALOG_BTNFLAG_YES
-			    );
+			    CDIALOG_ICON_QUESTION,
+			    CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO |
+			    CDIALOG_BTNFLAG_HELP,
+			    CDIALOG_BTNFLAG_YES
+			);
+			CDialogSetTransientFor(NULL);
 
-			    /* Free message buffer. */
-			    free(buf);
-			    buf = NULL;
+			g_free(buf);
 
-			    /* Check response. */
- 			    switch(status)
-			    {
-			      case CDIALOG_RESPONSE_YES:
-			      case CDIALOG_RESPONSE_YES_TO_ALL:
-			      case CDIALOG_RESPONSE_OK:
-				/* Response was yes, so consider the
-				 * new configuration file created
-				 * and mark its success.
-				 */
-				configuration_load_succ = TRUE;
-				break;
-
-			      default:
-				break;
-			    }
+ 			switch(status)
+			{
+			  case CDIALOG_RESPONSE_YES:
+			  case CDIALOG_RESPONSE_YES_TO_ALL:
+			  case CDIALOG_RESPONSE_OK:
+			    /* Response was yes, so consider the
+			     * new configuration file created
+			     * and mark its success
+			     */
+			    configuration_load_succ = TRUE;
+			    break;
 			}
 		    }
 		    else
 		    {
-			/* Exists, check if its valid and writeable. */
+			/* Exists, check if its valid and writeable */
 
 			if(S_ISDIR(stat_buf.st_mode))
 			{
-			    /* Its a directory! */
+			    CDialogSetTransientFor(yc->toplevel);
 			    CDialogGetResponse(
-"Location is a directory!",
-"Specified location for the configuration file\n\
-is a directory.",
+"Invalid Location",
+"The specified location for the configuration file\n\
+is a directory.\n",
 "The specified location for the YIFF Sound Server\n\
 configuration file is a directory. This location\n\
 can neither be loaded nor saved. Please specify\n\
 a path to a file within a directory.",
-				CDIALOG_ICON_ERROR,
+				CDIALOG_ICON_WARNING,
 				CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 				CDIALOG_BTNFLAG_OK
 			    );
+			    CDialogSetTransientFor(NULL);
 			}
 			else
 			{
-			    /* Exists and is valid to load, so load it. */
+			    /* Exists and is valid to load, so load it */
 			    YCLoadConfiguration(yc, configuration_file);
 
 			    configuration_load_succ = TRUE;
@@ -240,27 +223,27 @@ a path to a file within a directory.",
 		    }
 		}
 
-		/* Restore values. */
+		/* Restore values */
 
-		/* DSP device. */
+		/* DSP device */
 		strptr = dsp_device;
 		w = yc->dsp_device_entry;
 		if((w != NULL) && (strptr != NULL))
 		    gtk_entry_set_text(GTK_ENTRY(w), strptr);
 
-		/* Mixer device. */
+		/* Mixer device */
 		strptr = mixer_device;
 		w = yc->mixer_device_entry;
 		if((w != NULL) && (strptr != NULL))
 		    gtk_entry_set_text(GTK_ENTRY(w), strptr);
 
-		/* Address. */
+		/* Address */
 		strptr = address_str;
 		w = yc->address_entry;
 		if((w != NULL) && (strptr != NULL))
 		    gtk_entry_set_text(GTK_ENTRY(w), strptr);
 
-		/* Port. */
+		/* Port */
 		strptr = port_str;
 		w = yc->port_entry;
 		if((w != NULL) && (strptr != NULL))
@@ -278,37 +261,38 @@ a path to a file within a directory.",
 		else
 		{
 		    /* Print warning about configuration file not able
-		     * to be loaded.
+		     * to be loaded
 		     */
+		    CDialogSetTransientFor(yc->toplevel);
 		    CDialogGetResponse(
-"Cannot load configuration!",
-"Could not load the YIFF Sound Server\n\
-configuration file.",
+"Unable Open Configuration",
+"Unable to open the YIFF Sound Server configuration file.",
 "The YIFF Sound Server configuration file could not\n\
 be loaded at the specified location. Please go 'Back'\n\
 and check the given location for the YIFF Sound\n\
 Server configuration file.",
-			CDIALOG_ICON_ERROR,
+			CDIALOG_ICON_WARNING,
 			CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 			CDIALOG_BTNFLAG_OK
 		    );
+		    CDialogSetTransientFor(NULL);
 		}
 
 
-		/* Deallocate coppied values. */
-		free(configuration_file);
+		/* Delete coppied values */
+		g_free(configuration_file);
 		configuration_file = NULL;
 
-		free(dsp_device);
+		g_free(dsp_device);
 		dsp_device = NULL;
 
-		free(mixer_device);
+		g_free(mixer_device);
 		mixer_device = NULL;
 
-		free(address_str);
+		g_free(address_str);
 		address_str = NULL;
 
-		free(port_str);
+		g_free(port_str);
 		port_str = NULL;
 
 
@@ -324,10 +308,10 @@ Server configuration file.",
 		    gchar *strptr;
 
 
-		    /* Begin setting up start argument. */
+		    /* Begin setting up start argument */
 		    (*start_arg) = '\0';
 
-		    /* Program location. */
+		    /* Program location */
 		    w = yc->yiff_program_entry;
 		    strptr = ((w == NULL) ?
 			NULL : gtk_entry_get_text(GTK_ENTRY(w))
@@ -337,11 +321,11 @@ Server configuration file.",
 		    else
 			strncat(start_arg, strptr, 768);
 
-		    /* Space. */
+		    /* Space */
 		    strcat(start_arg, " ");
 		    w = yc->yiff_configuration_file_entry;
 
-		    /* First argument is configuration file location. */
+		    /* First argument is configuration file location */
 		    w = yc->yiff_configuration_file_entry;
 		    strptr = ((w == NULL) ?
 			NULL : gtk_entry_get_text(GTK_ENTRY(w))
@@ -357,7 +341,7 @@ Server configuration file.",
 		     */
 		    (*con_arg) = '\0';
 
-		    /* Address. */
+		    /* Address */
 		    w = yc->address_entry;
 		    strptr = ((w == NULL) ?
 			NULL : gtk_entry_get_text(GTK_ENTRY(w))
@@ -367,10 +351,10 @@ Server configuration file.",
 		    else
 			strncat(con_arg, strptr, 512);
 
-		    /* Deliminator. */
+		    /* Deliminator */
 		    strcat(con_arg, ":");
 
-		    /* Port. */
+		    /* Port */
 		    w = yc->port_entry;
 		    strptr = ((w == NULL) ?
 			NULL : gtk_entry_get_text(GTK_ENTRY(w))
@@ -381,27 +365,28 @@ Server configuration file.",
 			strncat(con_arg, strptr, 80);
 
 
-		    /* Close connection just in case. */
+		    /* Close connection just in case */
 		    YCloseConnection(yc->recorder, False);
 		    yc->recorder = NULL;
 
 
-		    /* Rewrite YIFF Sound Server configuration file. */
+		    /* Rewrite YIFF Sound Server configuration file */
 
 
 
 
 
-		    /* Open connection. */
+		    /* Open connection */
 		    yc->recorder = YOpenConnection(
 	                start_arg,
 			con_arg
 		    );
 		    if(yc->recorder == NULL)
 		    {
-			/* Could not start up Y server. */
+			/* Could not start up Y server */
+			CDialogSetTransientFor(yc->toplevel);
 			CDialogGetResponse(
-			    "Could not start Y Sound Server",
+"Unable To Start Y Sound Server",
 "Unable to start the Y Sound Server, please verify\n\
 that YIFF has been installed properly and the specified\n\
 locations are correct.",
@@ -412,10 +397,11 @@ for the locations are correct and that the YIFF\n\
 Sound Server has been installed properly. Also\n\
 check to make sure dependant resources (ie sound\n\
 drivers) have been set up properly.",
-			    CDIALOG_ICON_ERROR,
+			    CDIALOG_ICON_WARNING,
 			    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 			    CDIALOG_BTNFLAG_OK
 			);
+			CDialogSetTransientFor(NULL);
 		    }
 		    else
 		    {
@@ -429,7 +415,7 @@ drivers) have been set up properly.",
 
 		}
 
-		/* Update sensitivity of apply audio values button. */
+		/* Update sensitivity of apply audio values button */
 		w = yc->ymode_apply_to_yiff_btn;
 		if(w != NULL)
 		{
@@ -438,7 +424,7 @@ drivers) have been set up properly.",
 			(yc->recorder == NULL) ? FALSE : TRUE
 		    );
 		}
-		/* Update sensitivity of play button. */
+		/* Update sensitivity of play button */
 		w = yc->ymode_play_btn;
 		if(w != NULL)
 		{
@@ -450,7 +436,7 @@ drivers) have been set up properly.",
 	    }
 	}
 	/* ******************************************************** */
-	/* Timings page. */
+	/* Timings page */
 	else if(new_page == YC_PAGE_NUM_TIMINGS)
 	{
 	    /* Forward page change? */
@@ -468,7 +454,7 @@ drivers) have been set up properly.",
 			yc_ymode_data_struct *ymode_data_ptr = (yc_ymode_data_struct *)
 			    gtk_clist_get_row_data(clist, selected_row);
 
-			/* Apply values. */
+			/* Apply values */
 			YCYModeFetchFromWidgets(
 			    yc, ymode_data_ptr
 			);
@@ -477,8 +463,9 @@ drivers) have been set up properly.",
 		    /* Atleast one Y Audio Mode exist? */
 		    if(clist->rows <= 0)
 		    {
+			CDialogSetTransientFor(yc->toplevel);
 			CDialogGetResponse(
-			    "No Y Audio Modes defined!",
+			    "No Y Audio Modes Defined",
 "You should have atleast one preset Y Audio Mode defined,\n\
 preferably by the name of 'Default'. You are strongly\n\
 encuraged to go 'Back' and define atleast one preset Y Audio\n\
@@ -488,11 +475,12 @@ Mode.",
 			    CDIALOG_BTNFLAG_OK,
 			    CDIALOG_BTNFLAG_OK
 			);
+			CDialogSetTransientFor(NULL);
 		    }
 		    else
 		    {
 			/* Else check if first Y Audio Mode name
-			 * is named 'Default'.
+			 * is named 'Default'
 			 */
 			gchar *strptr = NULL;
 
@@ -504,8 +492,9 @@ Mode.",
 			    "Default"
 			))
 			{
+			    CDialogSetTransientFor(yc->toplevel);
 			    CDialogGetResponse(
-				"Default Y Audio Mode not first item!",
+"Default Y Audio Mode Not First Item",
 "The first Preset Y Audio Mode name should be named\n\
 'Default', this is to ensure that Y client programs\n\
 which expect this standard can run properly. You\n\
@@ -516,6 +505,7 @@ should go 'Back' and name the first listed Y Audio Mode\n\
 				CDIALOG_BTNFLAG_OK,
 				CDIALOG_BTNFLAG_OK
 			    );
+			    CDialogSetTransientFor(NULL);
 			}
 		    }
 
@@ -524,14 +514,14 @@ should go 'Back' and name the first listed Y Audio Mode\n\
 	    }
 	}
 	/* ******************************************************** */
-	/* MIDI page. */
+	/* MIDI page */
 	else if(new_page == YC_PAGE_NUM_MIDI)
 	{
 
 
 	}
 	/* ******************************************************** */
-	/* YSound paths page. */
+	/* YSound paths page */
 	else if(new_page == YC_PAGE_NUM_YSOUNDPATHS)
 	{
 	    /* Forward page change? */
@@ -549,15 +539,16 @@ should go 'Back' and name the first listed Y Audio Mode\n\
 		else
 		    strptr = gtk_entry_get_text(GTK_ENTRY(w));
 
-		/* Check if we got a string and that it is not empty. */
+		/* Check if we got a string and that it is not empty */
 		if((strptr == NULL) ? 0 : (*strptr) != '\0')
 		{
-		    /* Look for atleast one occurance of the sub string. */
+		    /* Look for atleast one occurance of the sub string */
 		    if(strstr(strptr, "%f") == NULL)
 		    {
-			/* Substitution string not found, print warning. */
+			/* Substitution string not found, print warning */
+			CDialogSetTransientFor(yc->toplevel);
 			CDialogGetResponse(
-"Missing substitution!",
+"Missing Substitution",
 "MIDI player command string is missing a \"%f\"\n\
 substitution. You should go 'Back' and correct this.",
 "The MIDI player command string is missing a \"%f\"\n\
@@ -569,6 +560,7 @@ player may not function properly.",
 			    CDIALOG_BTNFLAG_OK,
 			    CDIALOG_BTNFLAG_OK
 			);
+			CDialogSetTransientFor(NULL);
 		    }
 		}
 
@@ -576,13 +568,13 @@ player may not function properly.",
 
 	}
 	/* ******************************************************** */
-	/* Conferm finish page. */
+	/* Conferm finish page */
 	else if(new_page == YC_PAGE_NUM_CONFERM)
 	{
 	    /* Forward page change? */
 	    if(prev_page == (new_page - 1))
 	    {
-		/* Update confermation clist. */
+		/* Update confermation clist */
 		YCConfermListRefresh(yc);
 	    }
 	}
