@@ -1,13 +1,9 @@
-#include <stdio.h>
-#include <malloc.h>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 #include <errno.h>
 extern int errno;
-#include <unistd.h>		/* For access(). */
-#include <sys/types.h>
+#include <unistd.h>		/* For access() */
 #include <sys/stat.h>
-
 #include <gtk/gtk.h>
 
 #include "../include/Y2/Y.h"
@@ -21,7 +17,6 @@ extern int errno;
 #include "cdialog.h"
 
 #include "yc.h"
-
 #include "config.h"
 
 
@@ -33,11 +28,11 @@ void YCYModeSetToWidgets(yc_struct *yc, yc_ymode_data_struct *buf);
 
 void YCConfermListRefresh(yc_struct *yc);
 
-int YCCheckInstallation(
+gint YCCheckInstallation(
 	yc_struct *yc,
 	const gchar *configuration_file,
 	const gchar *yiff_program,
-	gbool report_problems
+	gboolean report_problems
 );
 
 
@@ -90,14 +85,14 @@ void YCYModeFetchFromWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 	if((yc == NULL) || (buf == NULL))
 	    return;
 
-	/* Sample rate. */
+	/* Sample rate */
 	w = yc->ymode_sample_rate_combo;
 	if(w != NULL)
 	{
 	    entry = (GtkEntry *)GTK_COMBO(w)->entry;
 	    if(entry != NULL)
 	    {
-		/* Get sample rate in Hz. */
+		/* Get sample rate in Hz */
 		strptr = gtk_entry_get_text(entry);
 		if(strptr != NULL)
 		    buf->sample_rate = MAX(
@@ -106,14 +101,14 @@ void YCYModeFetchFromWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 	    }
 	}
 
-	/* Fragment size in bytes. */
+	/* Fragment size in bytes */
 	w = yc->ymode_fragment_size_combo;
 	if(w != NULL)
 	{
 	    entry = (GtkEntry *)GTK_COMBO(w)->entry;
 	    if(entry != NULL)
 	    {
-		/* Get fragment buffer size in bytes. */
+		/* Get fragment buffer size in bytes */
 		strptr = gtk_entry_get_text(entry);
 		if(strptr != NULL)
 		    buf->fragment_size_bytes = MAX(
@@ -122,7 +117,7 @@ void YCYModeFetchFromWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 	    }
 	}
 
-	/* Channels. */
+	/* Channels */
 	w = yc->ymode_channels1_radio;
 	if(w != NULL)
 	{
@@ -136,7 +131,7 @@ void YCYModeFetchFromWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 		buf->channels = 2;
 	}
 
-	/* Sample size. */
+	/* Sample size */
 	w = yc->ymode_sample_size8_radio;
 	if(w != NULL)
 	{
@@ -150,23 +145,23 @@ void YCYModeFetchFromWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 		buf->sample_size = 16;
 	}
 
-	/* Cycle. */
+	/* Cycle */
 	w = yc->ymode_cycle_spin;
 	if(w != NULL)
 	{
-	    /* Get cycle in microseconds. */
+	    /* Get cycle in microseconds */
 	    buf->cycle_us = MAX(
 		gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(w)), 100
 	    );
 	}
 
-	/* Calculate cycle ahead as 1.5 times the cycle. */
+	/* Calculate cycle ahead as 1.5 times the cycle */
 	buf->write_ahead_us = 1.5 * buf->cycle_us;
 
-	/* Leave direction (play/record) alone. */
+	/* Leave direction (play/record) alone */
 /*	yc->direction; */
 
-	/* Leave fragmenting alone. */
+	/* Leave fragmenting alone */
 /*	yc->allow_fragmenting = TRUE; */
 
 	/* Set default number of fragments to 2 (one for current and
@@ -194,7 +189,7 @@ void YCYModeSetToWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 	if((yc == NULL) || (buf == NULL))
 	    return;
 
-	/* Sample rate. */
+	/* Sample rate */
 	w = yc->ymode_sample_rate_combo;
 	if(w != NULL)
 	{
@@ -206,7 +201,7 @@ void YCYModeSetToWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 	    }
 	}
 
-	/* Fragment size in bytes. */
+	/* Fragment size in bytes */
 	w = yc->ymode_fragment_size_combo;
 	if(w != NULL)
 	{
@@ -218,7 +213,7 @@ void YCYModeSetToWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 	    }
 	}
 
-	/* Channels. */
+	/* Channels */
 	switch(buf->channels)
 	{
 	  case 2:
@@ -240,7 +235,7 @@ void YCYModeSetToWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 	    break;
 	}
 
-	/* Sample size. */
+	/* Sample size */
 	switch(buf->sample_size)
 	{
 	  case 16:
@@ -262,7 +257,7 @@ void YCYModeSetToWidgets(yc_struct *yc, yc_ymode_data_struct *buf)
 	    break;
 	}
 
-	/* Cycle. */
+	/* Cycle */
 	w = yc->ymode_cycle_spin;
 	if(w != NULL)
 	    gtk_spin_button_set_value(
@@ -285,7 +280,7 @@ void YCConfermListRefresh(yc_struct *yc)
 	gchar *buf;
 	const gchar *parm, *val;
 	gint len_parm, len_val;
-	gbool show_cfgfmt_parms = FALSE;
+	gboolean show_cfgfmt_parms = FALSE;
 
 
 	if(yc == NULL)
@@ -303,7 +298,7 @@ void YCConfermListRefresh(yc_struct *yc)
 	gtk_clist_freeze(clist);
 	gtk_clist_clear(clist);
 
-/* Adds entry widget w values to clist, based on parm and val. */
+/* Adds entry widget w values to clist, based on parm and val */
 #define DO_ADD_ITEM_FROM_ENTRY	\
 if(w != NULL) \
 { \
@@ -320,7 +315,7 @@ if(w != NULL) \
  } \
 }
 
-/* Adds entry widget w values to clist, based on parm and val. */
+/* Adds entry widget w values to clist, based on parm and val */
 #define DO_ADD_ITEM_FROM_SPIN	\
 if(w != NULL) \
 { \
@@ -343,44 +338,44 @@ if(w != NULL) \
 }
 
 
-	/* Configuration file path. */
+	/* Configuration file path */
 	w = yc->yiff_configuration_file_entry;
 	parm = ((show_cfgfmt_parms) ?
 	    "YIFFConfigurationFile" : "YIFF configuration file"
 	);
 	DO_ADD_ITEM_FROM_ENTRY
 
-	/* YIFF program path. */
+	/* YIFF program path */
 	w = yc->yiff_program_entry;
 	parm = ((show_cfgfmt_parms) ?
 	    "YIFFProgram" : "YIFF program" 
 	);
 	DO_ADD_ITEM_FROM_ENTRY
 
-	/* DSP device. */
+	/* DSP device */
 	w = yc->dsp_device_entry;
 	parm = ((show_cfgfmt_parms) ?
 	    "DSPDevice" : "DSP device" 
 	);
 	DO_ADD_ITEM_FROM_ENTRY
 
-	/* Mixer device. */
+	/* Mixer device */
 	w = yc->mixer_device_entry;
 	parm = ((show_cfgfmt_parms) ?
 	    "MixerDevice" : "Mixer device"
 	);
 	DO_ADD_ITEM_FROM_ENTRY
 
-	/* Listening port number. */
+	/* Listening port number */
 	w = yc->port_entry;
 	parm = ((show_cfgfmt_parms) ?
 	    "Port" : "Listening port number"
 	);
 	DO_ADD_ITEM_FROM_ENTRY
 
-/* Leave out Y Audio Modes for now. */
+/* Leave out Y Audio Modes for now */
 
-	/* Refresh interval. */
+	/* Refresh interval */
 	w = yc->sound_refresh_spin;
 	parm = ((show_cfgfmt_parms) ?
 	    "RefreshInterval" : "Refresh interval (us)"
@@ -388,21 +383,21 @@ if(w != NULL) \
 	DO_ADD_ITEM_FROM_SPIN
 
 
-	/* MIDI play command. */
+	/* MIDI play command */
 	w = yc->midi_play_cmd_entry;
 	parm = ((show_cfgfmt_parms) ?
 	    "MIDIPlayCommand" : "MIDI player command"
 	);
 	DO_ADD_ITEM_FROM_ENTRY
 
-	/* ALSA MIDI device port number. */
+	/* ALSA MIDI device port number */
 	w = yc->alsa_midi_port_entry;
 	parm = ((show_cfgfmt_parms) ?
 	    "MIDIDevicePort" : "ALSA MIDI device port number"
 	);
 	DO_ADD_ITEM_FROM_ENTRY
 
-/* Leave out Y Sound Paths for now. */
+/* Leave out Y Sound Paths for now */
 
 
 
@@ -432,35 +427,34 @@ if(w != NULL) \
  *	-2  Missing or bad compoent (minor, may still be able to run).
  *	-3  Missing or bad compoent (critical, cannot run at all).
  */
-int YCCheckInstallation(
+gint YCCheckInstallation(
 	yc_struct *yc,
 	const gchar *configuration_file,
 	const gchar *yiff_program,
-	gbool report_problems
+	gboolean report_problems
 )
 {
 	GtkWidget *w;
-	const char	*mesg_title,
+	const gchar	*mesg_title,
 			*mesg_body,
 			*mesg_details;
-	gbool path_exists;
+	gboolean path_exists;
 	struct stat stat_buf;
 
-
 	if(yc == NULL)
 	    return(-1);
 
 	/* ********************************************************** */
-	/* Get values as needed. */
+	/* Get values as needed */
 
-	/* YIFF Sound Server configuration file. */
+	/* YIFF Sound Server configuration file */
 	if(configuration_file == NULL)
 	{
 	    w = yc->yiff_configuration_file_entry;
 	    configuration_file = gtk_entry_get_text(GTK_ENTRY(w));
 	}
 
-	/* YIFF Sound Server program file. */
+	/* YIFF Sound Server program file */
 	if(yiff_program == NULL)
 	{
 	    w = yc->yiff_program_entry;
@@ -468,45 +462,46 @@ int YCCheckInstallation(
 	}
 
 	/* ********************************************************** */
-	/* Got values, but note they still may be NULL. */
+	/* Got values, but note they still may be NULL */
 
-/* Maps cdialog with the messages from mesg_title, mesg_body, and
- * mesg_details.
- */
-#define DO_NOTIFY_ERROR	\
-{ \
- CDialogGetResponse( \
-  mesg_title, mesg_body, mesg_details, \
-  CDIALOG_ICON_ERROR, \
-  CDIALOG_BTNFLAG_OK | ((mesg_details == NULL) ? 0 : CDIALOG_BTNFLAG_HELP), \
-  CDIALOG_BTNFLAG_OK \
- ); \
+#define DO_NOTIFY_ERROR	{			\
+ CDialogSetTransientFor(yc->toplevel);		\
+ CDialogGetResponse(				\
+  mesg_title, mesg_body, mesg_details,		\
+  CDIALOG_ICON_ERROR,				\
+  CDIALOG_BTNFLAG_OK |				\
+  ((mesg_details != NULL) ? CDIALOG_BTNFLAG_HELP : 0), \
+  CDIALOG_BTNFLAG_OK				\
+ );						\
+ CDialogSetTransientFor(NULL);			\
 }
-#define DO_NOTIFY_WARNING	\
-{ \
- CDialogGetResponse( \
-  mesg_title, mesg_body, mesg_details, \
-  CDIALOG_ICON_WARNING, \
-  CDIALOG_BTNFLAG_OK | ((mesg_details == NULL) ? 0 : CDIALOG_BTNFLAG_HELP), \
-  CDIALOG_BTNFLAG_OK \
- ); \
+#define DO_NOTIFY_WARNING	{		\
+ CDialogSetTransientFor(yc->toplevel);		\
+ CDialogGetResponse(				\
+  mesg_title, mesg_body, mesg_details,		\
+  CDIALOG_ICON_WARNING,				\
+  CDIALOG_BTNFLAG_OK |				\
+  ((mesg_details != NULL) ? CDIALOG_BTNFLAG_HELP : 0), \
+  CDIALOG_BTNFLAG_OK				\
+ );						\
+ CDialogSetTransientFor(NULL);			\
 }
 
-	/* YIFF Sound Server configuration file. */
+	/* YIFF Sound Server configuration file */
 	if(configuration_file != NULL)
 	{
 	    path_exists = FALSE;
-	    if((*configuration_file) == '\0')
+	    if(*configuration_file == '\0')
 	    {
 		if(report_problems)
 		{
 		    mesg_title =
-"Configuration file value empty!";
+"Configuration File Not Set";
 		    mesg_body =
-"Specified location of the YIFF Sound Server configuration\n\
-file is an empty string.";
+"The location for the YIFF Sound Server configuration file\n\
+has not been set.\n";
 		    mesg_details = NULL;
-		    DO_NOTIFY_ERROR
+		    DO_NOTIFY_WARNING
 		}
 		return(-2);
 	    }
@@ -515,15 +510,15 @@ file is an empty string.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Configuration file not absolute path!";
+"Invalid Configuration File";
 		    mesg_body =
-"Specified path of the YIFF Sound Server configuration\n\
-file is not an absolute path.";
+"The specified path of the YIFF Sound Server configuration\n\
+file is not an absolute path.\n";
 		    mesg_details =
 "The path to the configruation file needs to be an\n\
 absolute path to ensure that the YIFF Sound Server\n\
 can find it.";
-		    DO_NOTIFY_ERROR
+		    DO_NOTIFY_WARNING
 		}
 		return(-2);
 	    }
@@ -533,7 +528,7 @@ can find it.";
 		{
 		  case ENOENT:
 		    /* Skip this, if no configuration file is found then
-		     * user will be prompted to create a new one.
+		     * user will be prompted to create a new one
 		     */
 		    break;
 
@@ -541,16 +536,16 @@ can find it.";
 		    if(report_problems)
 		    {
 		        mesg_title =
-"Configuration file not accessable!";
+"Configuration File Not Accessable";
 			mesg_body =
-"Specified location of the YIFF Sound Server configuration\n\
+"The specified location of the YIFF Sound Server configuration\n\
 file is not accessable, permission was denied when checking\n\
-for its existance.";
+for its existance.\n";
 			mesg_details =
 "You may need to run \"chmod\" from a prompt and change\n\
 the permissions on the parent directory or run this\n\
 program with a higher permission level (using \"su\").";
-			DO_NOTIFY_ERROR
+			DO_NOTIFY_WARNING
 		    }
 		    return(-3);
 		    break;
@@ -559,12 +554,12 @@ program with a higher permission level (using \"su\").";
 		    if(report_problems)
 		    {
 		        mesg_title =
-"Configuration file check error!";
+"Configuration File Warning";
 			mesg_body =
 "Error encountered when checking for existance\n\
-of the YIFF Sound Server configuration file.";
+of the YIFF Sound Server configuration file.\n";
 			mesg_details = NULL;
-			DO_NOTIFY_ERROR
+			DO_NOTIFY_WARNING
 		    }
 		    return(-3);
 		    break;
@@ -572,7 +567,7 @@ of the YIFF Sound Server configuration file.";
 	    }
 	    else
 	    {
-		/* Successfully stat() path, mark path_exists as TRUE. */ 
+		/* Successfully stat() path, mark path_exists as TRUE */ 
 		path_exists = TRUE;
 	    }
 
@@ -582,10 +577,10 @@ of the YIFF Sound Server configuration file.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Configuration file cannot be a directory!";
+"Invalid Configuration File";
 		    mesg_body =
-"Specified path to the YIFF Sound Server configuration\n\
-file reffers to a directory.";
+"The specified path to the YIFF Sound Server configuration\n\
+file refers to a directory.\n";
 		    mesg_details = NULL;
 		    DO_NOTIFY_ERROR
 		}
@@ -597,10 +592,10 @@ file reffers to a directory.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Configuration file is not a file!";
+"Invalid Configuration File";
 		    mesg_body =
-"Specified path to the YIFF Sound Server configuration\n\
-file is not a regular file.";
+"The specified path to the YIFF Sound Server configuration\n\
+file was not a file.\n";
 		    mesg_details = NULL;
 		    DO_NOTIFY_ERROR
 		}
@@ -612,7 +607,7 @@ file is not a regular file.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Configuration file is not readable!";
+"Configuration File Not Readable";
 		    mesg_body =
 "Current permission settings on the YIFF Sound Server\n\
 configuration file prevent it from being readable to\n\
@@ -622,9 +617,9 @@ higher permission level.";
 "You may need to run \"chmod\" from a prompt and change\n\
 the permissions on the parent directory or run this\n\
 program with a higher permission level (using \"su\").";
-		    DO_NOTIFY_ERROR
+		    DO_NOTIFY_WARNING
 		}
-		/* Do not return. */
+		/* Do not return */
 	    }
 	    /* Is it writeable? */
 	    if(path_exists && access(configuration_file, W_OK))
@@ -632,38 +627,35 @@ program with a higher permission level (using \"su\").";
 		if(report_problems)
 		{
 		    mesg_title =
-"Configuration file is not writeable!";
+"Configuration File Not Writeable";
 		    mesg_body =
-"Current permission settings on the YIFF Sound Server\n\
+"The current permission settings on the YIFF Sound Server\n\
 configuration file prevent it from being writeable with\n\
 this program. You may need to run this program with a\n\
-higher permission level (exit this program and use 'su'\n\
-to gain root privlages and then run this program).";
-		    mesg_details =
-"You may need to run \"chmod\" from a prompt and change\n\
-the permissions on the parent directory or run this\n\
-program with a higher permission level (using \"su\").";
-		    DO_NOTIFY_ERROR
+higher permission (exit this program and run \"su\" to\n\
+gain root privileges and then run this program again).\n";
+		    mesg_details = NULL;
+		    DO_NOTIFY_WARNING
 		}
-		/* Do not return. */
+		/* Do not return */
 	    }
-	}	/* YIFF Sound Server configuration file. */
+	}	/* YIFF Sound Server configuration file */
 
-	/* YIFF program. */
+	/* YIFF program */
 	if(yiff_program != NULL)
 	{
 	    path_exists = FALSE;
-	    if((*yiff_program) == '\0')
+	    if(*yiff_program == '\0')
 	    {
 		if(report_problems)
 		{
 		    mesg_title =
-"YIFF program file value empty!";
+"YIFF Program Not Set";
 		    mesg_body =
-"Specified location of the YIFF Sound Server program\n\
-file is an empty string.";
+"The location of the YIFF Sound Server program has not\n\
+been set.\n";
 		    mesg_details = NULL;
-		    DO_NOTIFY_ERROR
+		    DO_NOTIFY_WARNING
 		}
 		return(-2);
 	    }
@@ -672,12 +664,12 @@ file is an empty string.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Program file not absolute path!";
+"Invalid YIFF Program";
 		    mesg_body =
-"Specified path of the YIFF Sound Server program\n\
-file is not an absolute path.";
+"The specified path of the YIFF Sound Server program was\n\
+not an absolute path.\n";
 		    mesg_details = NULL;
-		    DO_NOTIFY_ERROR
+		    DO_NOTIFY_WARNING
 		}
 		return(-2);
 	    }
@@ -689,7 +681,7 @@ file is not an absolute path.";
 		    {
 		      case ENOENT:
 			mesg_title =
-"Program file not found!";
+"YIFF Program Not Found";
 			mesg_body =
 "YIFF Sound Server program file not found.";
 			mesg_details = NULL;
@@ -697,33 +689,33 @@ file is not an absolute path.";
 
 		      case EACCES:
 			mesg_title =
-"Program file not accessable!";
+"YIFF Program Not Accessable";
 			mesg_body =
-"Specified location of the YIFF Sound Server program\n\
-file is not accessable, permission was denied when checking\n\
-for its existance.";
+"The specified location of the YIFF Sound Server program\n\
+was not accessable, permission was denied when checking\n\
+for its existance.\n";
 			mesg_details =
 "You may need to run \"chmod\" from a prompt and change\n\
 the permissions on the parent directory or run this\n\
-program with a higher permission level (using \"su\").";
+program with a higher permission level (using \"su\").\n";
 			break;
 
 		      default:
 			mesg_title =
-"Program file check error!";
+"YIFF Program Warning";
 			mesg_body =
-"Error encountered when checking for existance\n\
-of the YIFF Sound Server program file.";
+"Error encountered when checking for existance of the\n\
+YIFF Sound Server program.\n";
 			mesg_details = NULL;
 			break;
 		    }
-		    DO_NOTIFY_ERROR
+		    DO_NOTIFY_WARNING
 		}
 		return(-3);
 	    }
 	    else
 	    {
-		/* Successfully stat() path, mark path_exists as TRUE. */
+		/* Successfully stat() path, mark path_exists as TRUE */
 		path_exists = TRUE;
 	    }
 
@@ -733,10 +725,10 @@ of the YIFF Sound Server program file.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Program file cannot be a directory!";
+"Invalid YIFF Program";
 		    mesg_body =
-"Specified path to the YIFF Sound Server program\n\
-file reffers to a directory.";
+"The specified path to the YIFF Sound Server program refers\n\
+to a directory.\n";
 		    mesg_details = NULL;
 		    DO_NOTIFY_ERROR
 		}
@@ -748,10 +740,10 @@ file reffers to a directory.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Program file is not a file!";
+"Invalid YIFF Program";
 		    mesg_body =
-"Specified path to the YIFF Sound Server program\n\
-file is not a regular file.";
+"The specified path to the YIFF Sound Server program was\n\
+not a file.\n";
 		    mesg_details = NULL;
 		    DO_NOTIFY_ERROR
 		}
@@ -766,16 +758,16 @@ file is not a regular file.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Program file is set setuid!";
+"YIFF Program Permissions Warning";
 		    mesg_body =
-"YIFF Sound Server program file has the setuid and/or\n\
-setgid bit set, it does not need it and may pose a\n\
+"The YIFF Sound Server program file has setuid and/or\n\
+setgid permissions set, it does not need them and may pose a\n\
 security risk. You are advised to remove the setuid\n\
-and/or setgid bits from the program file's permissions.";
+and/or setgid from the permissions.\n";
 		    mesg_details = NULL;
 		    DO_NOTIFY_WARNING
 		}
-		/* Do not return. */
+		/* Do not return */
 	    }
 	    /* Is it executeable? */
 	    if(path_exists && access(yiff_program, X_OK))
@@ -783,19 +775,19 @@ and/or setgid bits from the program file's permissions.";
 		if(report_problems)
 		{
 		    mesg_title =
-"Program file not executeable!";
+"YIFF Program Permissions Warning";
 		    mesg_body =
-"YIFF Sound Server program file permissions do not\n\
-allow it to be executeable.";
+"The YIFF Sound Server program permissions do not allow\n\
+it to be executeable.\n";
 		    mesg_details =
 "You may need to run \"chmod\" from a prompt and change\n\
 the permissions on the YIFF Sound Server program file\n\
 to \"755\".";
-		    DO_NOTIFY_ERROR
+		    DO_NOTIFY_WARNING
 		}
 		return(-3);
 	    }
-	}	/* YIFF program. */
+	}	/* YIFF program */
 
 
 
