@@ -42,7 +42,7 @@ int main(int argc, char *argv[])
 	if(con == NULL)
 	{
 		/* Connect failed. */
-		fprintf(stderr, "Cannot connect to Y server.\n");
+		fprintf(stderr, "Unable to connect to the Y server.\n");
 		return(1);
 	}
 
